# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/clients/v1/clients.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/clients/v1/clients.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtars/clients/v1/clients.proto\x12\x0ftars.clients.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\x84\x01\n\x11\x45nterpriseContext\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x02 \x01(\tR\x0bworkspaceId\x12+\n\x11organization_unit\x18\x03 \x01(\tR\x10organizationUnit\"\xbd\x04\n\tClientKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06prefix\x18\x03 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x04 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x05 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x06 \x01(\tR\tkeySuffix\x12\x1b\n\tis_active\x18\x07 \x01(\x08R\x08isActive\x12\x1d\n\nis_deleted\x18\x08 \x01(\x08R\tisDeleted\x12\x36\n\x05state\x18\t \x01(\x0e\x32 .tars.clients.v1.KeyVersionStateR\x05state\x12O\n\x13rotation_disable_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x11rotationDisableAt\x88\x01\x01\x12O\n\x13rotation_destroy_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x11rotationDestroyAt\x88\x01\x01\x12\x42\n\x0c\x64\x65stroyed_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\x0b\x64\x65stroyedAt\x88\x01\x01\x42\x16\n\x14_rotation_disable_atB\x16\n\x14_rotation_destroy_atB\x0f\n\r_destroyed_at\"\xb7\x01\n\x06\x43lient\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x14\n\x05title\x18\x04 \x01(\tR\x05title\x12\x1f\n\x0b\x63ustomer_id\x18\x05 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x06 \x01(\tR\tprojectId\x12.\n\x04keys\x18\x03 \x03(\x0b\x32\x1a.tars.clients.v1.ClientKeyR\x04keys\"\xf8\x01\n\x1a\x43reateClientWithKeyRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x14\n\x05title\x18\x03 \x01(\tR\x05title\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12Q\n\x12\x65nterprise_context\x18\x06 \x01(\x0b\x32\".tars.clients.v1.EnterpriseContextR\x11\x65nterpriseContextJ\x04\x08\x05\x10\x06R\x10user_key_address\"\xe6\x01\n\x1b\x43reateClientWithKeyResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12 \n\x0c\x61pi_key_once\x18\x03 \x01(\tR\napiKeyOnce\x12\x16\n\x06prefix\x18\x04 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x05 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x06 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x07 \x01(\tR\tkeySuffix\"\x95\x01\n\x15\x41\x64\x64KeyToClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12\x1a\n\x06key_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x05keyId\"2\n\x16\x41\x64\x64KeyToClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\x8e\x04\n\x18RotateKeyInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12(\n\x10user_key_address\x18\x04 \x01(\tR\x0euserKeyAddress\x12\x19\n\x08key_name\x18\x05 \x01(\tR\x07keyName\x12Q\n\x12\x65nterprise_context\x18\x06 \x01(\x0b\x32\".tars.clients.v1.EnterpriseContextR\x11\x65nterpriseContext\x12\x1c\n\nold_key_id\x18\x07 \x01(\tR\x08oldKeyId\x12G\n\x12old_key_disable_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0foldKeyDisableAt\x12G\n\x12old_key_destroy_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0foldKeyDestroyAt\x12#\n\rdisable_after\x18\n \x01(\tR\x0c\x64isableAfter\x12#\n\rdestroy_after\x18\x0b \x01(\tR\x0c\x64\x65stroyAfter\"\xa3\x02\n\x19RotateKeyInClientResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12 \n\x0c\x61pi_key_once\x18\x03 \x01(\tR\napiKeyOnce\x12\x16\n\x06prefix\x18\x04 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x05 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x06 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x07 \x01(\tR\tkeySuffix\x12=\n\x1bold_key_lifecycle_scheduled\x18\x08 \x01(\x08R\x18oldKeyLifecycleScheduled\"\xaa\x01\n DisableKeyVersionInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\"=\n!DisableKeyVersionInClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xa9\x01\n\x1f\x45nableKeyVersionInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\"<\n EnableKeyVersionInClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xaa\x01\n DestroyKeyVersionInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\"=\n!DestroyKeyVersionInClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xba\x03\n EmergencyRevokeKeyVersionRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\x12\x31\n\x14generate_replacement\x18\x05 \x01(\x08R\x13generateReplacement\x12\x30\n\x14replacement_key_name\x18\x06 \x01(\tR\x12replacementKeyName\x12?\n\x1creplacement_user_key_address\x18\x07 \x01(\tR\x19replacementUserKeyAddress\x12h\n\x1ereplacement_enterprise_context\x18\x08 \x01(\x0b\x32\".tars.clients.v1.EnterpriseContextR\x1creplacementEnterpriseContext\"\xa0\x01\n!EmergencyRevokeKeyVersionResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12Q\n\x0breplacement\x18\x02 \x01(\x0b\x32*.tars.clients.v1.RotateKeyInClientResponseH\x00R\x0breplacement\x88\x01\x01\x42\x0e\n\x0c_replacement\"t\n\x10GetClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\"D\n\x11GetClientResponse\x12/\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.tars.clients.v1.ClientR\x06\x63lient\"T\n\x12ListClientsRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\"H\n\x13ListClientsResponse\x12\x31\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x17.tars.clients.v1.ClientR\x07\x63lients\"\x97\x01\n\x18UpdateClientTitleRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12\x19\n\x05title\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x05title\"L\n\x19UpdateClientTitleResponse\x12/\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.tars.clients.v1.ClientR\x06\x63lient*\x94\x01\n\x0fKeyVersionState\x12!\n\x1dKEY_VERSION_STATE_UNSPECIFIED\x10\x00\x12\x1d\n\x19KEY_VERSION_STATE_ENABLED\x10\x01\x12\x1e\n\x1aKEY_VERSION_STATE_DISABLED\x10\x02\x12\x1f\n\x1bKEY_VERSION_STATE_DESTROYED\x10\x03\x32\xce\x15\n\x0e\x43lientsService\x12\xf1\x01\n\x13\x43reateClientWithKey\x12+.tars.clients.v1.CreateClientWithKeyRequest\x1a,.tars.clients.v1.CreateClientWithKeyResponse\"\x7f\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x11:\x07\x63lients:\x06\x63reate\xa2\xb5\x18\x0f\x43reate a client\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id}/projects/{project_id}/clients:\x01*\x12\xd4\x01\n\x0bListClients\x12#.tars.clients.v1.ListClientsRequest\x1a$.tars.clients.v1.ListClientsResponse\"z\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0f:\x07\x63lients:\x04list\xa2\xb5\x18\x0cList clients\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02;\x12\x39/v1/customers/{customer_id}/projects/{project_id}/clients\x12\xda\x01\n\tGetClient\x12!.tars.clients.v1.GetClientRequest\x1a\".tars.clients.v1.GetClientResponse\"\x85\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0e:\x07\x63lients:\x03get\xa2\xb5\x18\x0cGet a client\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02G\x12\x45/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}\x12\xf8\x01\n\x11UpdateClientTitle\x12).tars.clients.v1.UpdateClientTitleRequest\x1a*.tars.clients.v1.UpdateClientTitleResponse\"\x8b\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x11:\x07\x63lients:\x06update\xa2\xb5\x18\x0fUpdate a client\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02J2E/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}:\x01*\x12\xfd\x01\n\x0e\x41\x64\x64KeyToClient\x12&.tars.clients.v1.AddKeyToClientRequest\x1a\'.tars.clients.v1.AddKeyToClientResponse\"\x99\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x14:\x07\x63lients:\x04keys:\x03\x61\x64\x64\xa2\xb5\x18\x18\x41ttach a key to a client\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02O\"J/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys:\x01*\x12\x8b\x02\n\x11RotateKeyInClient\x12).tars.clients.v1.RotateKeyInClientRequest\x1a*.tars.clients.v1.RotateKeyInClientResponse\"\x9e\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x07\x63lients:\x04keys:\x06rotate\xa2\xb5\x18\x13Rotate a client key\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02V\"Q/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/rotate:\x01*\x12\xbc\x02\n\x19\x44isableKeyVersionInClient\x12\x31.tars.clients.v1.DisableKeyVersionInClientRequest\x1a\x32.tars.clients.v1.DisableKeyVersionInClientResponse\"\xb7\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x18:\x07\x63lients:\x04keys:\x07\x64isable\xa2\xb5\x18\x1c\x44isable a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02\x65\"`/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/disable:\x01*\x12\xb6\x02\n\x18\x45nableKeyVersionInClient\x12\x30.tars.clients.v1.EnableKeyVersionInClientRequest\x1a\x31.tars.clients.v1.EnableKeyVersionInClientResponse\"\xb4\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x07\x63lients:\x04keys:\x06\x65nable\xa2\xb5\x18\x1b\x45nable a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02\x64\"_/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/enable:\x01*\x12\xb1\x02\n\x19\x44\x65stroyKeyVersionInClient\x12\x31.tars.clients.v1.DestroyKeyVersionInClientRequest\x1a\x32.tars.clients.v1.DestroyKeyVersionInClientResponse\"\xac\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x18:\x07\x63lients:\x04keys:\x07\x64\x65stroy\xa2\xb5\x18\x1c\x44\x65stroy a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02Z*X/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}\x12\xde\x02\n\x19\x45mergencyRevokeKeyVersion\x12\x31.tars.clients.v1.EmergencyRevokeKeyVersionRequest\x1a\x32.tars.clients.v1.EmergencyRevokeKeyVersionResponse\"\xd9\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18!:\x07\x63lients:\x04keys:\x10\x65mergency-revoke\xa2\xb5\x18%Emergency-revoke a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02n\"i/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/emergency-revoke:\x01*B\xbc\x01\n\x13\x63om.tars.clients.v1B\x0c\x43lientsProtoP\x01Z9github.com/tetrateio/fraser/api/tars/clients/v1;clientsv1\xa2\x02\x03TCX\xaa\x02\x0fTars.Clients.V1\xca\x02\x0fTars\\Clients\\V1\xe2\x02\x1bTars\\Clients\\V1\\GPBMetadata\xea\x02\x11Tars::Clients::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.clients.v1.clients_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.clients.v1B\014ClientsProtoP\001Z9github.com/tetrateio/fraser/api/tars/clients/v1;clientsv1\242\002\003TCX\252\002\017Tars.Clients.V1\312\002\017Tars\\Clients\\V1\342\002\033Tars\\Clients\\V1\\GPBMetadata\352\002\021Tars::Clients::V1'
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['key_id']._serialized_options = b'\340A\002'
  _globals['_ROTATEKEYINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ROTATEKEYINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_GETCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_GETCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['title']._serialized_options = b'\340A\002'
  _globals['_CLIENTSSERVICE'].methods_by_name['CreateClientWithKey']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['CreateClientWithKey']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\021:\007clients:\006create\242\265\030\017Create a client\252\265\030\007Clients\202\323\344\223\002>\"9/v1/customers/{customer_id}/projects/{project_id}/clients:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['ListClients']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\017:\007clients:\004list\242\265\030\014List clients\252\265\030\007Clients\202\323\344\223\002;\0229/v1/customers/{customer_id}/projects/{project_id}/clients'
  _globals['_CLIENTSSERVICE'].methods_by_name['GetClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['GetClient']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\016:\007clients:\003get\242\265\030\014Get a client\252\265\030\007Clients\202\323\344\223\002G\022E/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}'
  _globals['_CLIENTSSERVICE'].methods_by_name['UpdateClientTitle']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['UpdateClientTitle']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\021:\007clients:\006update\242\265\030\017Update a client\252\265\030\007Clients\202\323\344\223\002J2E/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['AddKeyToClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['AddKeyToClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\024:\007clients:\004keys:\003add\242\265\030\030Attach a key to a client\252\265\030\004Keys\202\323\344\223\002O\"J/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['RotateKeyInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['RotateKeyInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\007clients:\004keys:\006rotate\242\265\030\023Rotate a client key\252\265\030\004Keys\202\323\344\223\002V\"Q/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/rotate:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['DisableKeyVersionInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['DisableKeyVersionInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\030:\007clients:\004keys:\007disable\242\265\030\034Disable a client key version\252\265\030\004Keys\202\323\344\223\002e\"`/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/disable:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['EnableKeyVersionInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['EnableKeyVersionInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\007clients:\004keys:\006enable\242\265\030\033Enable a client key version\252\265\030\004Keys\202\323\344\223\002d\"_/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/enable:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['DestroyKeyVersionInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['DestroyKeyVersionInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\030:\007clients:\004keys:\007destroy\242\265\030\034Destroy a client key version\252\265\030\004Keys\202\323\344\223\002Z*X/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}'
  _globals['_CLIENTSSERVICE'].methods_by_name['EmergencyRevokeKeyVersion']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['EmergencyRevokeKeyVersion']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030!:\007clients:\004keys:\020emergency-revoke\242\265\030%Emergency-revoke a client key version\252\265\030\004Keys\202\323\344\223\002n\"i/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/emergency-revoke:\001*'
  _globals['_KEYVERSIONSTATE']._serialized_start=4530
  _globals['_KEYVERSIONSTATE']._serialized_end=4678
  _globals['_ENTERPRISECONTEXT']._serialized_start=228
  _globals['_ENTERPRISECONTEXT']._serialized_end=360
  _globals['_CLIENTKEY']._serialized_start=363
  _globals['_CLIENTKEY']._serialized_end=936
  _globals['_CLIENT']._serialized_start=939
  _globals['_CLIENT']._serialized_end=1122
  _globals['_CREATECLIENTWITHKEYREQUEST']._serialized_start=1125
  _globals['_CREATECLIENTWITHKEYREQUEST']._serialized_end=1373
  _globals['_CREATECLIENTWITHKEYRESPONSE']._serialized_start=1376
  _globals['_CREATECLIENTWITHKEYRESPONSE']._serialized_end=1606
  _globals['_ADDKEYTOCLIENTREQUEST']._serialized_start=1609
  _globals['_ADDKEYTOCLIENTREQUEST']._serialized_end=1758
  _globals['_ADDKEYTOCLIENTRESPONSE']._serialized_start=1760
  _globals['_ADDKEYTOCLIENTRESPONSE']._serialized_end=1810
  _globals['_ROTATEKEYINCLIENTREQUEST']._serialized_start=1813
  _globals['_ROTATEKEYINCLIENTREQUEST']._serialized_end=2339
  _globals['_ROTATEKEYINCLIENTRESPONSE']._serialized_start=2342
  _globals['_ROTATEKEYINCLIENTRESPONSE']._serialized_end=2633
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST']._serialized_start=2636
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST']._serialized_end=2806
  _globals['_DISABLEKEYVERSIONINCLIENTRESPONSE']._serialized_start=2808
  _globals['_DISABLEKEYVERSIONINCLIENTRESPONSE']._serialized_end=2869
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST']._serialized_start=2872
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST']._serialized_end=3041
  _globals['_ENABLEKEYVERSIONINCLIENTRESPONSE']._serialized_start=3043
  _globals['_ENABLEKEYVERSIONINCLIENTRESPONSE']._serialized_end=3103
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST']._serialized_start=3106
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST']._serialized_end=3276
  _globals['_DESTROYKEYVERSIONINCLIENTRESPONSE']._serialized_start=3278
  _globals['_DESTROYKEYVERSIONINCLIENTRESPONSE']._serialized_end=3339
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST']._serialized_start=3342
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST']._serialized_end=3784
  _globals['_EMERGENCYREVOKEKEYVERSIONRESPONSE']._serialized_start=3787
  _globals['_EMERGENCYREVOKEKEYVERSIONRESPONSE']._serialized_end=3947
  _globals['_GETCLIENTREQUEST']._serialized_start=3949
  _globals['_GETCLIENTREQUEST']._serialized_end=4065
  _globals['_GETCLIENTRESPONSE']._serialized_start=4067
  _globals['_GETCLIENTRESPONSE']._serialized_end=4135
  _globals['_LISTCLIENTSREQUEST']._serialized_start=4137
  _globals['_LISTCLIENTSREQUEST']._serialized_end=4221
  _globals['_LISTCLIENTSRESPONSE']._serialized_start=4223
  _globals['_LISTCLIENTSRESPONSE']._serialized_end=4295
  _globals['_UPDATECLIENTTITLEREQUEST']._serialized_start=4298
  _globals['_UPDATECLIENTTITLEREQUEST']._serialized_end=4449
  _globals['_UPDATECLIENTTITLERESPONSE']._serialized_start=4451
  _globals['_UPDATECLIENTTITLERESPONSE']._serialized_end=4527
  _globals['_CLIENTSSERVICE']._serialized_start=4681
  _globals['_CLIENTSSERVICE']._serialized_end=7447
# @@protoc_insertion_point(module_scope)
