# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/common/v1/types.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1atars/common/v1/types.proto\x12\x0etars.common.v1\x1a\x1fgoogle/api/field_behavior.proto\"|\n\x0bPageRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x03 \x01(\tR\x06\x66ilter\x12\x19\n\x08order_by\x18\x04 \x01(\tR\x07orderBy\";\n\x0cPageResponse\x12+\n\x0fnext_page_token\x18\x01 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\"+\n\x0eIdempotencyKey\x12\x19\n\x05value\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05value\"\xf7\x02\n\x07Problem\x12\x17\n\x04type\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04type\x12\x19\n\x05title\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05title\x12\x1b\n\x06status\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x06status\x12\x1b\n\x06\x64\x65tail\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x06\x64\x65tail\x12\x1f\n\x08instance\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08instance\x12\x1b\n\x06reason\x18\n \x01(\tB\x03\xe0\x41\x03R\x06reason\x12\x1b\n\x06\x64omain\x18\x0b \x01(\tB\x03\xe0\x41\x03R\x06\x64omain\x12\x46\n\x08metadata\x18\x0c \x03(\x0b\x32%.tars.common.v1.Problem.MetadataEntryB\x03\xe0\x41\x03R\x08metadata\x12\x1e\n\x08trace_id\x18\r \x01(\tB\x03\xe0\x41\x03R\x07traceId\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xd4\x03\n\x08IdPrefix\x12\x19\n\x15ID_PREFIX_UNSPECIFIED\x10\x00\x12\x16\n\x12ID_PREFIX_CUSTOMER\x10\x01\x12\x15\n\x11ID_PREFIX_PROJECT\x10\x02\x12\x17\n\x13ID_PREFIX_DATAPLANE\x10\x03\x12\x15\n\x11ID_PREFIX_API_KEY\x10\x04\x12\x17\n\x13ID_PREFIX_OPERATION\x10\x05\x12\x16\n\x12ID_PREFIX_IDENTITY\x10\x06\x12\x14\n\x10ID_PREFIX_BUDGET\x10\x07\x12\x16\n\x12ID_PREFIX_BYOK_KEY\x10\x08\x12\x15\n\x11ID_PREFIX_GATEWAY\x10\t\x12!\n\x1dID_PREFIX_PROJECT_GATEWAY_MAP\x10\n\x12\"\n\x1eID_PREFIX_DATAPLANE_CREDENTIAL\x10\x0b\x12\x16\n\x12ID_PREFIX_PROVIDER\x10\x0c\x12\x13\n\x0fID_PREFIX_MODEL\x10\r\x12\x1a\n\x16ID_PREFIX_BILLING_PLAN\x10\x0e\x12\x1a\n\x16ID_PREFIX_USAGE_RECORD\x10\x0f\x12\x15\n\x11ID_PREFIX_SESSION\x10\x10\x12\x15\n\x11ID_PREFIX_WEBHOOK\x10\x11\x42\xb3\x01\n\x12\x63om.tars.common.v1B\nTypesProtoP\x01Z7github.com/tetrateio/fraser/api/tars/common/v1;commonv1\xa2\x02\x03TCX\xaa\x02\x0eTars.Common.V1\xca\x02\x0eTars\\Common\\V1\xe2\x02\x1aTars\\Common\\V1\\GPBMetadata\xea\x02\x10Tars::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.common.v1B\nTypesProtoP\001Z7github.com/tetrateio/fraser/api/tars/common/v1;commonv1\242\002\003TCX\252\002\016Tars.Common.V1\312\002\016Tars\\Common\\V1\342\002\032Tars\\Common\\V1\\GPBMetadata\352\002\020Tars::Common::V1'
  _globals['_PAGERESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_PAGERESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _globals['_IDEMPOTENCYKEY'].fields_by_name['value']._loaded_options = None
  _globals['_IDEMPOTENCYKEY'].fields_by_name['value']._serialized_options = b'\340A\002'
  _globals['_PROBLEM_METADATAENTRY']._loaded_options = None
  _globals['_PROBLEM_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_PROBLEM'].fields_by_name['type']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['type']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['title']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['title']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['status']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['status']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['detail']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['detail']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['instance']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['instance']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['reason']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['reason']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['domain']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['domain']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['metadata']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['metadata']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['trace_id']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['trace_id']._serialized_options = b'\340A\003'
  _globals['_IDPREFIX']._serialized_start=690
  _globals['_IDPREFIX']._serialized_end=1158
  _globals['_PAGEREQUEST']._serialized_start=79
  _globals['_PAGEREQUEST']._serialized_end=203
  _globals['_PAGERESPONSE']._serialized_start=205
  _globals['_PAGERESPONSE']._serialized_end=264
  _globals['_IDEMPOTENCYKEY']._serialized_start=266
  _globals['_IDEMPOTENCYKEY']._serialized_end=309
  _globals['_PROBLEM']._serialized_start=312
  _globals['_PROBLEM']._serialized_end=687
  _globals['_PROBLEM_METADATAENTRY']._serialized_start=628
  _globals['_PROBLEM_METADATAENTRY']._serialized_end=687
# @@protoc_insertion_point(module_scope)
