# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/auth/v1/auth_options.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/auth/v1/auth_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/auth/v1/auth_options.proto\x12\x0ctars.auth.v1\x1a google/protobuf/descriptor.proto\"\\\n\x0b\x41uthOptions\x12\x35\n\nauth_types\x18\x01 \x03(\x0e\x32\x16.tars.auth.v1.AuthTypeR\tauthTypes\x12\x16\n\x06scopes\x18\x02 \x03(\tR\x06scopes*u\n\x08\x41uthType\x12\x19\n\x15\x41UTH_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x41UTH_TYPE_API_KEY\x10\x01\x12\x1d\n\x19\x41UTH_TYPE_SERVICE_ACCOUNT\x10\x02\x12\x18\n\x14\x41UTH_TYPE_USER_TOKEN\x10\x03:O\n\x04\x61uth\x12\x1e.google.protobuf.MethodOptions\x18\xd1\x86\x03 \x01(\x0b\x32\x19.tars.auth.v1.AuthOptionsR\x04\x61uth:I\n\x10project_id_field\x12\x1d.google.protobuf.FieldOptions\x18\xd7\x86\x03 \x01(\x08R\x0eprojectIdField:K\n\x11\x63ustomer_id_field\x12\x1d.google.protobuf.FieldOptions\x18\xd8\x86\x03 \x01(\x08R\x0f\x63ustomerIdFieldBv\n\x10\x63om.tars.auth.v1B\x10\x41uthOptionsProtoP\x01\xa2\x02\x03TAX\xaa\x02\x0cTars.Auth.V1\xca\x02\x0cTars\\Auth\\V1\xe2\x02\x18Tars\\Auth\\V1\\GPBMetadata\xea\x02\x0eTars::Auth::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.auth.v1.auth_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.tars.auth.v1B\020AuthOptionsProtoP\001\242\002\003TAX\252\002\014Tars.Auth.V1\312\002\014Tars\\Auth\\V1\342\002\030Tars\\Auth\\V1\\GPBMetadata\352\002\016Tars::Auth::V1'
  _globals['_AUTHTYPE']._serialized_start=177
  _globals['_AUTHTYPE']._serialized_end=294
  _globals['_AUTHOPTIONS']._serialized_start=83
  _globals['_AUTHOPTIONS']._serialized_end=175
# @@protoc_insertion_point(module_scope)
