from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetJWKSRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetJWKSResponse(_message.Message):
    __slots__ = ("keys",)
    KEYS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedCompositeFieldContainer[JWK]
    def __init__(self, keys: _Optional[_Iterable[_Union[JWK, _Mapping]]] = ...) -> None: ...

class JWK(_message.Message):
    __slots__ = ("kid", "kty", "alg", "use", "crv", "x", "y")
    KID_FIELD_NUMBER: _ClassVar[int]
    KTY_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    CRV_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    kid: str
    kty: str
    alg: str
    use: str
    crv: str
    x: str
    y: str
    def __init__(self, kid: _Optional[str] = ..., kty: _Optional[str] = ..., alg: _Optional[str] = ..., use: _Optional[str] = ..., crv: _Optional[str] = ..., x: _Optional[str] = ..., y: _Optional[str] = ...) -> None: ...
