# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/registry/v1/registry.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/registry/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/registry/v1/registry.proto\x12\x10tars.registry.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"\xc6\x05\n\x1dRegisterServiceAccountRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12*\n\x0c\x63lient_email\x18\x03 \x01(\tB\x07\xbaH\x04r\x02`\x01R\x0b\x63lientEmail\x12\x30\n\x0eprivate_key_id\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x0cprivateKeyId\x12\"\n\x06issuer\x18\x05 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\x06issuer\x12&\n\x08\x61udience\x18\x06 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\x08\x61udience\x12(\n\x08jwks_uri\x18\x07 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x00R\x07jwksUri\x88\x01\x01\x12\x31\n\x06scopes\x18\x08 \x03(\tB\x19\xbaH\x16\x92\x01\x13\x10\n\"\x0fr\r\x18\x32\x32\t^[a-z_]+$R\x06scopes\x12\x41\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\texpiresAt\x12\x46\n\x0bpublic_keys\x18\n \x03(\x0b\x32\x1b.tars.registry.v1.PublicKeyB\x08\xbaH\x05\x92\x01\x02\x08\x01R\npublicKeys\x12\x1f\n\x08\x63hecksum\x18\x0b \x01(\tH\x01R\x08\x63hecksum\x88\x01\x01\x12\x32\n\x12\x63hecksum_algorithm\x18\x0c \x01(\tH\x02R\x11\x63hecksumAlgorithm\x88\x01\x01\x42\x0b\n\t_jwks_uriB\x0b\n\t_checksumB\x15\n\x13_checksum_algorithm\"\x85\x01\n\x1eRegisterServiceAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"i\n\x1bRevokeServiceAccountRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x02id\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"\x83\x01\n\x1cRevokeServiceAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"4\n\x18GetServiceAccountRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x02id\"j\n\x19GetServiceAccountResponse\x12M\n\x0fservice_account\x18\x01 \x01(\x0b\x32$.tars.registry.v1.ServiceAccountInfoR\x0eserviceAccount\"\xde\x01\n\x1bLookupServiceAccountRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12\x30\n\x0eprivate_key_id\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x0cprivateKeyId\"m\n\x1cLookupServiceAccountResponse\x12M\n\x0fservice_account\x18\x01 \x01(\x0b\x32$.tars.registry.v1.ServiceAccountInfoR\x0eserviceAccount\"\xef\x02\n\x1aListServiceAccountsRequest\x12N\n\x0b\x63ustomer_id\x18\x01 \x01(\tB(\xbaH%r#\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$H\x00R\ncustomerId\x88\x01\x01\x12\x43\n\x0cworkspace_id\x18\x02 \x01(\tB\x1b\xbaH\x18r\x16\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$H\x01R\x0bworkspaceId\x88\x01\x01\x12,\n\x0finclude_revoked\x18\x03 \x01(\x08H\x02R\x0eincludeRevoked\x88\x01\x01\x12&\n\tpage_size\x18\x04 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64(\x01R\x08pageSize\x12\"\n\npage_token\x18\x05 \x01(\tH\x03R\tpageToken\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0f\n\r_workspace_idB\x12\n\x10_include_revokedB\r\n\x0b_page_token\"\xd0\x01\n\x1bListServiceAccountsResponse\x12O\n\x10service_accounts\x18\x01 \x03(\x0b\x32$.tars.registry.v1.ServiceAccountInfoR\x0fserviceAccounts\x12+\n\x0fnext_page_token\x18\x02 \x01(\tH\x00R\rnextPageToken\x88\x01\x01\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCountB\x12\n\x10_next_page_token\"\\\n\"GetServiceAccountPublicKeysRequest\x12\x36\n\x12service_account_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x10serviceAccountId\"c\n#GetServiceAccountPublicKeysResponse\x12<\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x1b.tars.registry.v1.PublicKeyR\npublicKeys\"\xa7\x05\n\x12ServiceAccountInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x03 \x01(\tR\x0bworkspaceId\x12!\n\x0c\x63lient_email\x18\x04 \x01(\tR\x0b\x63lientEmail\x12$\n\x0eprivate_key_id\x18\x05 \x01(\tR\x0cprivateKeyId\x12\x16\n\x06issuer\x18\x06 \x01(\tR\x06issuer\x12\x1a\n\x08\x61udience\x18\x07 \x01(\tR\x08\x61udience\x12\x1e\n\x08jwks_uri\x18\x08 \x01(\tH\x00R\x07jwksUri\x88\x01\x01\x12\x16\n\x06scopes\x18\t \x03(\tR\x06scopes\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12>\n\nrevoked_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\trevokedAt\x88\x01\x01\x12*\n\x0erevoked_reason\x18\r \x01(\tH\x02R\rrevokedReason\x88\x01\x01\x12\x1f\n\x08\x63hecksum\x18\x0e \x01(\tH\x03R\x08\x63hecksum\x88\x01\x01\x12\x32\n\x12\x63hecksum_algorithm\x18\x0f \x01(\tH\x04R\x11\x63hecksumAlgorithm\x88\x01\x01\x42\x0b\n\t_jwks_uriB\r\n\x0b_revoked_atB\x11\n\x0f_revoked_reasonB\x0b\n\t_checksumB\x15\n\x13_checksum_algorithm\"\xd7\x01\n\tPublicKey\x12\x1c\n\x03kid\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x03kid\x12,\n\x03\x61lg\x18\x02 \x01(\tB\x1a\xbaH\x17r\x15R\x05\x45S256R\x05\x45S384R\x05\x45S512R\x03\x61lg\x12!\n\x03use\x18\x03 \x01(\tB\x0f\xbaH\x0cr\nR\x03sigR\x03\x65ncR\x03use\x12 \n\x07key_pem\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06keyPem\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xc5\x02\n\x1f\x43reateRegistryCredentialRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12,\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64\x65scription\x12>\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\texpiresAt\x88\x01\x01\x12\x16\n\x06scopes\x18\x05 \x03(\tR\x06scopesB\r\n\x0b_expires_at\"\xbf\x01\n CreateRegistryCredentialResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x18\n\x07message\x18\x05 \x01(\tR\x07message\"\xf3\x02\n\x1eListRegistryCredentialsRequest\x12N\n\x0b\x63ustomer_id\x18\x01 \x01(\tB(\xbaH%r#\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$H\x00R\ncustomerId\x88\x01\x01\x12\x43\n\x0cworkspace_id\x18\x02 \x01(\tB\x1b\xbaH\x18r\x16\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$H\x01R\x0bworkspaceId\x88\x01\x01\x12,\n\x0finclude_revoked\x18\x03 \x01(\x08H\x02R\x0eincludeRevoked\x88\x01\x01\x12&\n\tpage_size\x18\x04 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64(\x01R\x08pageSize\x12\"\n\npage_token\x18\x05 \x01(\tH\x03R\tpageToken\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0f\n\r_workspace_idB\x12\n\x10_include_revokedB\r\n\x0b_page_token\"\xcf\x01\n\x1fListRegistryCredentialsResponse\x12J\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.tars.registry.v1.RegistryCredentialInfoR\x0b\x63redentials\x12+\n\x0fnext_page_token\x18\x02 \x01(\tH\x00R\rnextPageToken\x88\x01\x01\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCountB\x12\n\x10_next_page_token\"m\n\x1fRevokeRegistryCredentialRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x02id\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"\x87\x01\n RevokeRegistryCredentialResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"\x80\x05\n\x16RegistryCredentialInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x03 \x01(\tR\x0bworkspaceId\x12\x1a\n\x08username\x18\x04 \x01(\tR\x08username\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06scopes\x18\x06 \x03(\tR\x06scopes\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1d\n\ncreated_by\x18\x08 \x01(\tR\tcreatedBy\x12>\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\texpiresAt\x88\x01\x01\x12\x41\n\x0clast_used_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\nlastUsedAt\x88\x01\x01\x12>\n\nrevoked_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\trevokedAt\x88\x01\x01\x12*\n\x0erevoked_reason\x18\x0c \x01(\tH\x03R\rrevokedReason\x88\x01\x01\x12\"\n\nrevoked_by\x18\r \x01(\tH\x04R\trevokedBy\x88\x01\x01\x42\r\n\x0b_expires_atB\x0f\n\r_last_used_atB\r\n\x0b_revoked_atB\x11\n\x0f_revoked_reasonB\r\n\x0b_revoked_by\"\r\n\x0bPingRequest\"b\n\x0cPingResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp2\xc7\x0e\n\x0fRegistryService\x12\xb3\x01\n\x16RegisterServiceAccount\x12/.tars.registry.v1.RegisterServiceAccountRequest\x1a\x30.tars.registry.v1.RegisterServiceAccountResponse\"6\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\"\"\x1d/registry/v1/service-accounts:\x01*\x12\xb9\x01\n\x14RevokeServiceAccount\x12-.tars.registry.v1.RevokeServiceAccountRequest\x1a..tars.registry.v1.RevokeServiceAccountResponse\"B\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02.\")/registry/v1/service-accounts/{id}:revoke:\x01*\x12\xa9\x01\n\x11GetServiceAccount\x12*.tars.registry.v1.GetServiceAccountRequest\x1a+.tars.registry.v1.GetServiceAccountResponse\";\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02$\x12\"/registry/v1/service-accounts/{id}\x12\xdb\x01\n\x14LookupServiceAccount\x12-.tars.registry.v1.LookupServiceAccountRequest\x1a..tars.registry.v1.LookupServiceAccountResponse\"d\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02M\x12K/registry/v1/service-accounts/{customer_id}/{workspace_id}/{private_key_id}\x12\xaa\x01\n\x13ListServiceAccounts\x12,.tars.registry.v1.ListServiceAccountsRequest\x1a-.tars.registry.v1.ListServiceAccountsResponse\"6\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x1f\x12\x1d/registry/v1/service-accounts\x12\xe3\x01\n\x1bGetServiceAccountPublicKeys\x12\x34.tars.registry.v1.GetServiceAccountPublicKeysRequest\x1a\x35.tars.registry.v1.GetServiceAccountPublicKeysResponse\"W\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02@\x12>/registry/v1/service-accounts/{service_account_id}/public-keys\x12\xb4\x01\n\x18\x43reateRegistryCredential\x12\x31.tars.registry.v1.CreateRegistryCredentialRequest\x1a\x32.tars.registry.v1.CreateRegistryCredentialResponse\"1\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x1d\"\x18/registry/v1/credentials:\x01*\x12\xb1\x01\n\x17ListRegistryCredentials\x12\x30.tars.registry.v1.ListRegistryCredentialsRequest\x1a\x31.tars.registry.v1.ListRegistryCredentialsResponse\"1\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x1a\x12\x18/registry/v1/credentials\x12\xc0\x01\n\x18RevokeRegistryCredential\x12\x31.tars.registry.v1.RevokeRegistryCredentialRequest\x1a\x32.tars.registry.v1.RevokeRegistryCredentialResponse\"=\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02)\"$/registry/v1/credentials/{id}:revoke:\x01*\x12q\n\x04Ping\x12\x1d.tars.registry.v1.PingRequest\x1a\x1e.tars.registry.v1.PingResponse\"*\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x13\x12\x11/registry/v1/ping\x1a\x04\xa0\xb5\x18\x01\x42\x87\x01\n\x14\x63om.tars.registry.v1B\rRegistryProtoP\x01\xa2\x02\x03TRX\xaa\x02\x10Tars.Registry.V1\xca\x02\x10Tars\\Registry\\V1\xe2\x02\x1cTars\\Registry\\V1\\GPBMetadata\xea\x02\x12Tars::Registry::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.registry.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.registry.v1B\rRegistryProtoP\001\242\002\003TRX\252\002\020Tars.Registry.V1\312\002\020Tars\\Registry\\V1\342\002\034Tars\\Registry\\V1\\GPBMetadata\352\002\022Tars::Registry::V1'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['client_email']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['client_email']._serialized_options = b'\272H\004r\002`\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['issuer']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['issuer']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['audience']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['audience']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['jwks_uri']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['jwks_uri']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['scopes']._serialized_options = b'\272H\026\222\001\023\020\n\"\017r\r\03022\t^[a-z_]+$'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['expires_at']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['expires_at']._serialized_options = b'\272H\003\310\001\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['public_keys']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['public_keys']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_GETSERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._loaded_options = None
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H%r#\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\030r\026\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\006\032\004\030d(\001'
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_PUBLICKEY'].fields_by_name['kid']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['kid']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_PUBLICKEY'].fields_by_name['alg']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['alg']._serialized_options = b'\272H\027r\025R\005ES256R\005ES384R\005ES512'
  _globals['_PUBLICKEY'].fields_by_name['use']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['use']._serialized_options = b'\272H\014r\nR\003sigR\003enc'
  _globals['_PUBLICKEY'].fields_by_name['key_pem']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['key_pem']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['description']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H%r#\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\030r\026\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\006\032\004\030d(\001'
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_REGISTRYSERVICE']._loaded_options = None
  _globals['_REGISTRYSERVICE']._serialized_options = b'\240\265\030\001'
  _globals['_REGISTRYSERVICE'].methods_by_name['RegisterServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['RegisterServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\"\"\035/registry/v1/service-accounts:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002.\")/registry/v1/service-accounts/{id}:revoke:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccount']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002$\022\"/registry/v1/service-accounts/{id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['LookupServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['LookupServiceAccount']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002M\022K/registry/v1/service-accounts/{customer_id}/{workspace_id}/{private_key_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListServiceAccounts']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListServiceAccounts']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\037\022\035/registry/v1/service-accounts'
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccountPublicKeys']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccountPublicKeys']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002@\022>/registry/v1/service-accounts/{service_account_id}/public-keys'
  _globals['_REGISTRYSERVICE'].methods_by_name['CreateRegistryCredential']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['CreateRegistryCredential']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\035\"\030/registry/v1/credentials:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListRegistryCredentials']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListRegistryCredentials']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\032\022\030/registry/v1/credentials'
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeRegistryCredential']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeRegistryCredential']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002)\"$/registry/v1/credentials/{id}:revoke:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Ping']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Ping']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\023\022\021/registry/v1/ping'
  _globals['_REGISTERSERVICEACCOUNTREQUEST']._serialized_start=204
  _globals['_REGISTERSERVICEACCOUNTREQUEST']._serialized_end=914
  _globals['_REGISTERSERVICEACCOUNTRESPONSE']._serialized_start=917
  _globals['_REGISTERSERVICEACCOUNTRESPONSE']._serialized_end=1050
  _globals['_REVOKESERVICEACCOUNTREQUEST']._serialized_start=1052
  _globals['_REVOKESERVICEACCOUNTREQUEST']._serialized_end=1157
  _globals['_REVOKESERVICEACCOUNTRESPONSE']._serialized_start=1160
  _globals['_REVOKESERVICEACCOUNTRESPONSE']._serialized_end=1291
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_start=1293
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_end=1345
  _globals['_GETSERVICEACCOUNTRESPONSE']._serialized_start=1347
  _globals['_GETSERVICEACCOUNTRESPONSE']._serialized_end=1453
  _globals['_LOOKUPSERVICEACCOUNTREQUEST']._serialized_start=1456
  _globals['_LOOKUPSERVICEACCOUNTREQUEST']._serialized_end=1678
  _globals['_LOOKUPSERVICEACCOUNTRESPONSE']._serialized_start=1680
  _globals['_LOOKUPSERVICEACCOUNTRESPONSE']._serialized_end=1789
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_start=1792
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_end=2159
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_start=2162
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_end=2370
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST']._serialized_start=2372
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST']._serialized_end=2464
  _globals['_GETSERVICEACCOUNTPUBLICKEYSRESPONSE']._serialized_start=2466
  _globals['_GETSERVICEACCOUNTPUBLICKEYSRESPONSE']._serialized_end=2565
  _globals['_SERVICEACCOUNTINFO']._serialized_start=2568
  _globals['_SERVICEACCOUNTINFO']._serialized_end=3247
  _globals['_PUBLICKEY']._serialized_start=3250
  _globals['_PUBLICKEY']._serialized_end=3465
  _globals['_CREATEREGISTRYCREDENTIALREQUEST']._serialized_start=3468
  _globals['_CREATEREGISTRYCREDENTIALREQUEST']._serialized_end=3793
  _globals['_CREATEREGISTRYCREDENTIALRESPONSE']._serialized_start=3796
  _globals['_CREATEREGISTRYCREDENTIALRESPONSE']._serialized_end=3987
  _globals['_LISTREGISTRYCREDENTIALSREQUEST']._serialized_start=3990
  _globals['_LISTREGISTRYCREDENTIALSREQUEST']._serialized_end=4361
  _globals['_LISTREGISTRYCREDENTIALSRESPONSE']._serialized_start=4364
  _globals['_LISTREGISTRYCREDENTIALSRESPONSE']._serialized_end=4571
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST']._serialized_start=4573
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST']._serialized_end=4682
  _globals['_REVOKEREGISTRYCREDENTIALRESPONSE']._serialized_start=4685
  _globals['_REVOKEREGISTRYCREDENTIALRESPONSE']._serialized_end=4820
  _globals['_REGISTRYCREDENTIALINFO']._serialized_start=4823
  _globals['_REGISTRYCREDENTIALINFO']._serialized_end=5463
  _globals['_PINGREQUEST']._serialized_start=5465
  _globals['_PINGREQUEST']._serialized_end=5478
  _globals['_PINGRESPONSE']._serialized_start=5480
  _globals['_PINGRESPONSE']._serialized_end=5578
  _globals['_REGISTRYSERVICE']._serialized_start=5581
  _globals['_REGISTRYSERVICE']._serialized_end=7444
# @@protoc_insertion_point(module_scope)
