# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/errors/v1/reasons.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/errors/v1/reasons.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctars/errors/v1/reasons.proto\x12\x0etars.errors.v1*\xec\x03\n\x0b\x45rrorReason\x12\x1c\n\x18\x45RROR_REASON_UNSPECIFIED\x10\x00\x12!\n\x1d\x45RROR_REASON_INVALID_ARGUMENT\x10\x01\x12 \n\x1c\x45RROR_REASON_UNAUTHENTICATED\x10\x02\x12\"\n\x1e\x45RROR_REASON_PERMISSION_DENIED\x10\x03\x12\x1a\n\x16\x45RROR_REASON_NOT_FOUND\x10\x04\x12\x1f\n\x1b\x45RROR_REASON_ALREADY_EXISTS\x10\x05\x12$\n ERROR_REASON_FAILED_PRECONDITION\x10\x06\x12\x19\n\x15\x45RROR_REASON_INTERNAL\x10\x07\x12\x1c\n\x18\x45RROR_REASON_UNAVAILABLE\x10\x08\x12 \n\x1c\x45RROR_REASON_MODEL_NOT_FOUND\x10\x64\x12 \n\x1c\x45RROR_REASON_MODEL_AMBIGUOUS\x10\x65\x12#\n\x1f\x45RROR_REASON_PROVIDER_NOT_FOUND\x10\x66\x12$\n ERROR_REASON_CROSS_TENANT_DENIED\x10g\x12+\n\'ERROR_REASON_SESSION_DEFAULT_UNRESOLVED\x10hB\xb5\x01\n\x12\x63om.tars.errors.v1B\x0cReasonsProtoP\x01Z7github.com/tetrateio/fraser/api/tars/errors/v1;errorsv1\xa2\x02\x03TEX\xaa\x02\x0eTars.Errors.V1\xca\x02\x0eTars\\Errors\\V1\xe2\x02\x1aTars\\Errors\\V1\\GPBMetadata\xea\x02\x10Tars::Errors::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.errors.v1.reasons_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.errors.v1B\014ReasonsProtoP\001Z7github.com/tetrateio/fraser/api/tars/errors/v1;errorsv1\242\002\003TEX\252\002\016Tars.Errors.V1\312\002\016Tars\\Errors\\V1\342\002\032Tars\\Errors\\V1\\GPBMetadata\352\002\020Tars::Errors::V1'
  _globals['_ERRORREASON']._serialized_start=49
  _globals['_ERRORREASON']._serialized_end=541
# @@protoc_insertion_point(module_scope)
