# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/configurator/v1/configurator.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/configurator/v1/configurator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'tars/configurator/v1/configurator.proto\x12\x14tars.configurator.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"Z\n\x17GetConfigurationRequest\x12?\n\x07queries\x18\x01 \x03(\x0b\x32%.tars.configurator.v1.UserConfigQueryR\x07queries\"\xad\x01\n\x0fUserConfigQuery\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x02 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\'\n\x0f\x63urrent_version\x18\x03 \x01(\x03R\x0e\x63urrentVersion\x12\x15\n\x06key_id\x18\x04 \x01(\tR\x05keyId\"g\n\x18GetConfigurationResponse\x12K\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32#.tars.configurator.v1.ConfigurationR\x0e\x63onfigurations\"\xaf\x02\n\x14TriggerUpdateRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x02 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12>\n\nevent_type\x18\x03 \x01(\x0e\x32\x1f.tars.configurator.v1.EventTypeR\teventType\x12\x15\n\x06key_id\x18\x04 \x01(\tR\x05keyId\x12!\n\x0cworkspace_id\x18\x05 \x01(\tR\x0bworkspaceId\x12\x41\n\x08metadata\x18\x06 \x01(\x0b\x32%.tars.configurator.v1.TriggerMetadataR\x08metadata\"m\n\x0fTriggerMetadata\x12Z\n\x11\x64\x61taplane_upgrade\x18\x01 \x01(\x0b\x32-.tars.configurator.v1.DataplaneUpgradeTriggerR\x10\x64\x61taplaneUpgrade\"\x82\x02\n\x17\x44\x61taplaneUpgradeTrigger\x12%\n\x0etarget_version\x18\x01 \x01(\tR\rtargetVersion\x12%\n\x0e\x61llow_downtime\x18\x02 \x01(\x08R\rallowDowntime\x12\'\n\x0f\x63redentials_ref\x18\x03 \x01(\tR\x0e\x63redentialsRef\x12,\n\x12persist_in_cluster\x18\x04 \x01(\x08R\x10persistInCluster\x12\x42\n\x1d\x61\x63knowledged_preflight_checks\x18\x05 \x03(\tR\x1b\x61\x63knowledgedPreflightChecks\"\x97\x01\n\x15TriggerUpdateResponse\x12I\n\rconfiguration\x18\x01 \x01(\x0b\x32#.tars.configurator.v1.ConfigurationR\rconfiguration\x12\x33\n\x15\x63onfiguration_updated\x18\x02 \x01(\x08R\x14\x63onfigurationUpdated\"\xb3\x01\n\x19ListConfigurationsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x02 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\"\x91\x01\n\x1aListConfigurationsResponse\x12K\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32#.tars.configurator.v1.ConfigurationR\x0e\x63onfigurations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x82\x01\n\x18ListPendingEventsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12P\n\x0e\x64octor_runtime\x18\x02 \x01(\x0b\x32).tars.configurator.v1.DoctorRuntimeStatusR\rdoctorRuntime\"\x90\x02\n\x13\x44octorRuntimeStatus\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12!\n\x0ctare_version\x18\x02 \x01(\tR\x0btareVersion\x12\x14\n\x05state\x18\x03 \x01(\tR\x05state\x12\x16\n\x06reason\x18\x04 \x01(\tR\x06reason\x12J\n\x13last_successful_run\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11lastSuccessfulRun\x12;\n\x0bobserved_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nobservedAt\"]\n\x19ListPendingEventsResponse\x12@\n\x06\x65vents\x18\x01 \x03(\x0b\x32(.tars.configurator.v1.ConfigurationEventR\x06\x65vents\"\x1b\n\x19ReconcileWorkspaceRequest\"\xd2\x01\n\x1aReconcileWorkspaceResponse\x12%\n\x0ereplayed_total\x18\x01 \x01(\x05R\rreplayedTotal\x12\'\n\x0freplayed_global\x18\x02 \x01(\x05R\x0ereplayedGlobal\x12*\n\x11replayed_per_user\x18\x03 \x01(\x05R\x0freplayedPerUser\x12\x38\n\x19replayed_per_user_per_key\x18\x04 \x01(\x05R\x15replayedPerUserPerKey\"\x1a\n\x18\x46ullSyncWorkspaceRequest\"\xa8\x01\n\x19\x46ullSyncWorkspaceResponse\x12%\n\x0ereplayed_total\x18\x01 \x01(\x05R\rreplayedTotal\x12*\n\x11replayed_per_user\x18\x02 \x01(\x05R\x0freplayedPerUser\x12\x38\n\x19replayed_per_user_per_key\x18\x03 \x01(\x05R\x15replayedPerUserPerKey\"\xb1\x03\n\x12\x43onfigurationEvent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x03 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\x1d\n\nevent_type\x18\x04 \x01(\tR\teventType\x12\x15\n\x06key_id\x18\x05 \x01(\tR\x05keyId\x12\x1b\n\tconfig_id\x18\x06 \x01(\tR\x08\x63onfigId\x12%\n\x0e\x63onfig_version\x18\x07 \x01(\x03R\rconfigVersion\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12=\n\x0ctriggered_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btriggeredAt\x12\x1f\n\x0bretry_count\x18\n \x01(\x05R\nretryCount\x12!\n\x0cworkspace_id\x18\x0b \x01(\tR\x0bworkspaceId\x12\x1a\n\x08metadata\x18\x0c \x01(\tR\x08metadata\"Q\n\x17\x41\x63knowledgeEventRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1b\n\tworker_id\x18\x02 \x01(\tR\x08workerId\"4\n\x18\x41\x63knowledgeEventResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"p\n\x14\x43ompleteEventRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"1\n\x15\x43ompleteEventResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\".\n\x16ListActiveUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\"4\n\x17ListActiveUsersResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\"\xc3\x02\n\rConfiguration\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x03 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\x1f\n\x0b\x63onfig_data\x18\x04 \x01(\tR\nconfigData\x12\x18\n\x07version\x18\x05 \x01(\x03R\x07version\x12\x15\n\x06key_id\x18\x06 \x01(\tR\x05keyId\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\xec\x01\n\x0fProviderBackend\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12\x16\n\x06weight\x18\x04 \x01(\x05R\x06weight\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12\x1f\n\x0b\x62yok_policy\x18\x06 \x01(\tR\nbyokPolicy\x12\x1f\n\x0bis_external\x18\x07 \x01(\x08R\nisExternal\x12\x1d\n\nmodel_name\x18\x08 \x01(\tR\tmodelName\"\x96\x01\n\x17SaveBYOKBackendsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0bkey_address\x18\x02 \x01(\tR\nkeyAddress\x12\x41\n\x08\x62\x61\x63kends\x18\x03 \x03(\x0b\x32%.tars.configurator.v1.ProviderBackendR\x08\x62\x61\x63kends\"\x7f\n\x18SaveBYOKBackendsResponse\x12I\n\rconfiguration\x18\x01 \x01(\x0b\x32#.tars.configurator.v1.ConfigurationR\rconfiguration\x12\x18\n\x07updated\x18\x02 \x01(\x08R\x07updated\"4\n\x19\x44\x65leteBYOKBackendsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"6\n\x1a\x44\x65leteBYOKBackendsResponse\x12\x18\n\x07\x64\x65leted\x18\x01 \x01(\x08R\x07\x64\x65leted\"k\n\x16RevokeUserTokenRequest\x12\x10\n\x03jti\x18\x01 \x01(\tR\x03jti\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1b\n\x06reason\x18\x03 \x01(\tH\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"n\n\x17RevokeUserTokenResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\"\xb1\x02\n\x08Provider\x12\x12\n\x04slug\x18\x01 \x01(\tR\x04slug\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12 \n\x0c\x61pi_base_url\x18\x03 \x01(\tR\napiBaseUrl\x12\x1b\n\tauth_type\x18\x04 \x01(\tR\x08\x61uthType\x12\x1d\n\nis_enabled\x18\x05 \x01(\x08R\tisEnabled\x12\x1a\n\x08metadata\x18\x06 \x01(\tR\x08metadata\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\x1c\n\x1aListActiveProvidersRequest\"[\n\x1bListActiveProvidersResponse\x12<\n\tproviders\x18\x01 \x03(\x0b\x32\x1e.tars.configurator.v1.ProviderR\tproviders\"t\n\x16SetDataplaneURLRequest\x12!\n\x0cworkspace_id\x18\x01 \x01(\tR\x0bworkspaceId\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12%\n\x0etrigger_update\x18\x03 \x01(\x08R\rtriggerUpdate\"\x19\n\x17SetDataplaneURLResponse\"\xcb\x02\n\x1dUpsertMCPCatalogServerRequest\x12!\n\x0cworkspace_id\x18\x01 \x01(\tR\x0bworkspaceId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x10\n\x03url\x18\x03 \x01(\tR\x03url\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x19\n\x08icon_url\x18\x06 \x01(\tR\x07iconUrl\x12\x1e\n\ncategories\x18\x07 \x03(\tR\ncategories\x12&\n\x0e\x61uthentication\x18\x08 \x01(\tR\x0e\x61uthentication\x12#\n\rrequires_auth\x18\t \x01(\x08R\x0crequiresAuth\x12\'\n\x0f\x66orce_overwrite\x18\n \x01(\x08R\x0e\x66orceOverwrite\":\n\x1eUpsertMCPCatalogServerResponse\x12\x18\n\x07\x63reated\x18\x01 \x01(\x08R\x07\x63reated\"\x1a\n\x18ValidateDataplaneRequest\"|\n\x19ValidateDataplaneResponse\x12_\n\x16gatekeeper_public_keys\x18\x01 \x03(\x0b\x32).tars.configurator.v1.GatekeeperPublicKeyR\x14gatekeeperPublicKeys\"q\n\x13GatekeeperPublicKey\x12\x10\n\x03kid\x18\x01 \x01(\tR\x03kid\x12\x10\n\x03\x61lg\x18\x02 \x01(\tR\x03\x61lg\x12\x10\n\x03use\x18\x03 \x01(\tR\x03use\x12$\n\x0epublic_key_pem\x18\x04 \x01(\tR\x0cpublicKeyPem\"S\n\x1aUpdateEventMetadataRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1a\n\x08metadata\x18\x02 \x01(\tR\x08metadata\"7\n\x1bUpdateEventMetadataResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"I\n\x1d\x43\x61ncelDataplaneUpgradeRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\":\n\x1e\x43\x61ncelDataplaneUpgradeResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"K\n\x1fRollbackDataplaneUpgradeRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\"h\n RollbackDataplaneUpgradeResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12*\n\x11rollback_event_id\x18\x02 \x01(\tR\x0frollbackEventId\"\x84\x01\n\x1a\x44\x61taplaneUpgradeCredential\x12\x12\n\x04slot\x18\x01 \x01(\tR\x04slot\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x1a\n\x08registry\x18\x04 \x01(\tR\x08registry\"\xd6\x01\n(SubmitDataplaneUpgradeCredentialsRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\x12R\n\x0b\x63redentials\x18\x02 \x03(\x0b\x32\x30.tars.configurator.v1.DataplaneUpgradeCredentialR\x0b\x63redentials\x12,\n\x12persist_in_cluster\x18\x03 \x01(\x08R\x10persistInCluster\"l\n)SubmitDataplaneUpgradeCredentialsResponse\x12%\n\x0e\x63redentials_id\x18\x01 \x01(\tR\rcredentialsId\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\"Q\n%GetDataplaneUpgradeCredentialsRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\"\xc4\x01\n&GetDataplaneUpgradeCredentialsResponse\x12R\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32\x30.tars.configurator.v1.DataplaneUpgradeCredentialR\x0b\x63redentials\x12\x18\n\x07present\x18\x02 \x01(\x08R\x07present\x12,\n\x12persist_in_cluster\x18\x03 \x01(\x08R\x10persistInCluster\"o\n%AckDataplaneUpgradeCredentialsRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\x12\x1c\n\tdelivered\x18\x02 \x01(\x08R\tdelivered\"B\n&AckDataplaneUpgradeCredentialsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success*\xa2\x03\n\nConfigType\x12\x1b\n\x17\x43ONFIG_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x43ONFIG_TYPE_GLOBAL_ROUTES\x10\x01\x12\x1b\n\x17\x43ONFIG_TYPE_USER_ROUTES\x10\x02\x12\x14\n\x10\x43ONFIG_TYPE_BYOK\x10\x03\x12\x1b\n\x17\x43ONFIG_TYPE_MCP_PROFILE\x10\x04\x12\x1c\n\x18\x43ONFIG_TYPE_MCP_BACKENDS\x10\x05\x12\x1b\n\x17\x43ONFIG_TYPE_OAUTH_TOKEN\x10\x06\x12\x1d\n\x19\x43ONFIG_TYPE_BYOK_BACKENDS\x10\x07\x12\x1a\n\x16\x43ONFIG_TYPE_GUARDRAILS\x10\x08\x12\x19\n\x15\x43ONFIG_TYPE_PROXY_URL\x10\t\x12\x15\n\x11\x43ONFIG_TYPE_PROXY\x10\n\x12 \n\x1c\x43ONFIG_TYPE_PROVIDER_SECRETS\x10\x0b\x12!\n\x1d\x43ONFIG_TYPE_DATAPLANE_UPGRADE\x10\x0c\x12\x1b\n\x17\x43ONFIG_TYPE_BYOK_SCOPED\x10\r*\x95\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x45VENT_TYPE_NEW\x10\x01\x12\x15\n\x11\x45VENT_TYPE_UPDATE\x10\x02\x12\x16\n\x12\x45VENT_TYPE_UPGRADE\x10\x08\x12\x1d\n\x19\x45VENT_TYPE_UPGRADE_CANCEL\x10\t\x12\x1f\n\x1b\x45VENT_TYPE_UPGRADE_ROLLBACK\x10\n\x12\x15\n\x11\x45VENT_TYPE_DELETE\x10\x03\x12\x1a\n\x16\x45VENT_TYPE_UPDATE_BYOK\x10\x04\x12\x19\n\x15\x45VENT_TYPE_UPDATE_MCP\x10\x05\x12\x1b\n\x17\x45VENT_TYPE_UPDATE_OAUTH\x10\x06\x32\xa9#\n\x13\x43onfiguratorService\x12\xb8\x01\n\x10GetConfiguration\x12-.tars.configurator.v1.GetConfigurationRequest\x1a..tars.configurator.v1.GetConfigurationResponse\"E\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rConfiguration\x82\xd3\xe4\x93\x02\x1c\"\x17/configurator/v1/config:\x01*\x12\xad\x01\n\rTriggerUpdate\x12*.tars.configurator.v1.TriggerUpdateRequest\x1a+.tars.configurator.v1.TriggerUpdateResponse\"C\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rConfiguration\x82\xd3\xe4\x93\x02\x1d\"\x18/configurator/v1/trigger:\x01*\x12\xbc\x01\n\x12ListConfigurations\x12/.tars.configurator.v1.ListConfigurationsRequest\x1a\x30.tars.configurator.v1.ListConfigurationsResponse\"C\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rConfiguration\x82\xd3\xe4\x93\x02\x1a\x12\x18/configurator/v1/configs\x12\xb6\x01\n\x11ListPendingEvents\x12..tars.configurator.v1.ListPendingEventsRequest\x1a/.tars.configurator.v1.ListPendingEventsResponse\"@\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02!\x12\x1f/configurator/v1/pending-events\x12\xc9\x01\n\x12ReconcileWorkspace\x12/.tars.configurator.v1.ReconcileWorkspaceRequest\x1a\x30.tars.configurator.v1.ReconcileWorkspaceResponse\"P\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0eWorkspace Sync\x82\xd3\xe4\x93\x02)\"$/configurator/v1/reconcile-workspace:\x01*\x12\xc6\x01\n\x11\x46ullSyncWorkspace\x12..tars.configurator.v1.FullSyncWorkspaceRequest\x1a/.tars.configurator.v1.FullSyncWorkspaceResponse\"P\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0eWorkspace Sync\x82\xd3\xe4\x93\x02)\"$/configurator/v1/full-sync-workspace:\x01*\x12\xb9\x01\n\x10\x41\x63knowledgeEvent\x12-.tars.configurator.v1.AcknowledgeEventRequest\x1a..tars.configurator.v1.AcknowledgeEventResponse\"F\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02\'\"\"/configurator/v1/acknowledge-event:\x01*\x12\xb5\x01\n\x0fSetDataplaneURL\x12,.tars.configurator.v1.SetDataplaneURLRequest\x1a-.tars.configurator.v1.SetDataplaneURLResponse\"E\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\tDataplane\x82\xd3\xe4\x93\x02#\"\x1e/configurator/v1/dataplane-url:\x01*\x12\xd1\x01\n\x16UpsertMCPCatalogServer\x12\x33.tars.configurator.v1.UpsertMCPCatalogServerRequest\x1a\x34.tars.configurator.v1.UpsertMCPCatalogServerResponse\"L\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02(\"#/configurator/v1/mcp-catalog/upsert:\x01*\x12\xc2\x01\n\x11ValidateDataplane\x12..tars.configurator.v1.ValidateDataplaneRequest\x1a/.tars.configurator.v1.ValidateDataplaneResponse\"L\x90\x02\x01\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\tDataplane\x82\xd3\xe4\x93\x02(\"#/configurator/v1/validate-dataplane:\x01*\x12\xad\x01\n\rCompleteEvent\x12*.tars.configurator.v1.CompleteEventRequest\x1a+.tars.configurator.v1.CompleteEventResponse\"C\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02$\"\x1f/configurator/v1/complete-event:\x01*\x12\xb5\x01\n\x0fListActiveUsers\x12,.tars.configurator.v1.ListActiveUsersRequest\x1a-.tars.configurator.v1.ListActiveUsersResponse\"E\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\nMonitoring\x82\xd3\xe4\x93\x02\x1f\x12\x1d/configurator/v1/active-users\x12\xc5\x01\n\x13ListActiveProviders\x12\x30.tars.configurator.v1.ListActiveProvidersRequest\x1a\x31.tars.configurator.v1.ListActiveProvidersResponse\"I\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\nMonitoring\x82\xd3\xe4\x93\x02#\x12!/configurator/v1/active-providers\x12\xbc\x01\n\x10SaveBYOKBackends\x12-.tars.configurator.v1.SaveBYOKBackendsRequest\x1a..tars.configurator.v1.SaveBYOKBackendsResponse\"I\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rBYOK Backends\x82\xd3\xe4\x93\x02#\"\x1e/configurator/v1/byok-backends:\x01*\x12\xc9\x01\n\x12\x44\x65leteBYOKBackends\x12/.tars.configurator.v1.DeleteBYOKBackendsRequest\x1a\x30.tars.configurator.v1.DeleteBYOKBackendsResponse\"P\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rBYOK Backends\x82\xd3\xe4\x93\x02**(/configurator/v1/byok-backends/{user_id}\x12\xc2\x01\n\x0fRevokeUserToken\x12,.tars.configurator.v1.RevokeUserTokenRequest\x1a-.tars.configurator.v1.RevokeUserTokenResponse\"R\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0bUser Tokens\x82\xd3\xe4\x93\x02.\")/configurator/v1/user-tokens/{jti}:revoke:\x01*\x12\xbe\x01\n\x13UpdateEventMetadata\x12\x30.tars.configurator.v1.UpdateEventMetadataRequest\x1a\x31.tars.configurator.v1.UpdateEventMetadataResponse\"B\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02$\"\x1f/configurator/v1/event-metadata:\x01*\x12\x82\x02\n!SubmitDataplaneUpgradeCredentials\x12>.tars.configurator.v1.SubmitDataplaneUpgradeCredentialsRequest\x1a?.tars.configurator.v1.SubmitDataplaneUpgradeCredentialsResponse\"\\\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x33\"./configurator/v1/dataplane-upgrade-credentials:\x01*\x12\x80\x02\n\x1eGetDataplaneUpgradeCredentials\x12;.tars.configurator.v1.GetDataplaneUpgradeCredentialsRequest\x1a<.tars.configurator.v1.GetDataplaneUpgradeCredentialsResponse\"c\x90\x02\x01\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x37\"2/configurator/v1/dataplane-upgrade-credentials/get:\x01*\x12\xfd\x01\n\x1e\x41\x63kDataplaneUpgradeCredentials\x12;.tars.configurator.v1.AckDataplaneUpgradeCredentialsRequest\x1a<.tars.configurator.v1.AckDataplaneUpgradeCredentialsResponse\"`\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x37\"2/configurator/v1/dataplane-upgrade-credentials/ack:\x01*\x12\xdc\x01\n\x16\x43\x61ncelDataplaneUpgrade\x12\x33.tars.configurator.v1.CancelDataplaneUpgradeRequest\x1a\x34.tars.configurator.v1.CancelDataplaneUpgradeResponse\"W\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02.\")/configurator/v1/dataplane-upgrade/cancel:\x01*\x12\xe4\x01\n\x18RollbackDataplaneUpgrade\x12\x35.tars.configurator.v1.RollbackDataplaneUpgradeRequest\x1a\x36.tars.configurator.v1.RollbackDataplaneUpgradeResponse\"Y\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x30\"+/configurator/v1/dataplane-upgrade/rollback:\x01*B\xe4\x01\n\x18\x63om.tars.configurator.v1B\x11\x43onfiguratorProtoP\x01ZCgithub.com/tetrateio/fraser/api/tars/configurator/v1;configuratorv1\xa2\x02\x03TCX\xaa\x02\x14Tars.Configurator.V1\xca\x02\x14Tars\\Configurator\\V1\xe2\x02 Tars\\Configurator\\V1\\GPBMetadata\xea\x02\x16Tars::Configurator::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.configurator.v1.configurator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.tars.configurator.v1B\021ConfiguratorProtoP\001ZCgithub.com/tetrateio/fraser/api/tars/configurator/v1;configuratorv1\242\002\003TCX\252\002\024Tars.Configurator.V1\312\002\024Tars\\Configurator\\V1\342\002 Tars\\Configurator\\V1\\GPBMetadata\352\002\026Tars::Configurator::V1'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetConfiguration']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetConfiguration']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rConfiguration\202\323\344\223\002\034\"\027/configurator/v1/config:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['TriggerUpdate']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['TriggerUpdate']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rConfiguration\202\323\344\223\002\035\"\030/configurator/v1/trigger:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListConfigurations']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListConfigurations']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rConfiguration\202\323\344\223\002\032\022\030/configurator/v1/configs'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListPendingEvents']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListPendingEvents']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002!\022\037/configurator/v1/pending-events'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ReconcileWorkspace']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ReconcileWorkspace']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\016Workspace Sync\202\323\344\223\002)\"$/configurator/v1/reconcile-workspace:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['FullSyncWorkspace']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['FullSyncWorkspace']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\016Workspace Sync\202\323\344\223\002)\"$/configurator/v1/full-sync-workspace:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AcknowledgeEvent']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AcknowledgeEvent']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002\'\"\"/configurator/v1/acknowledge-event:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SetDataplaneURL']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SetDataplaneURL']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\tDataplane\202\323\344\223\002#\"\036/configurator/v1/dataplane-url:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpsertMCPCatalogServer']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpsertMCPCatalogServer']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\013MCP Catalog\202\323\344\223\002(\"#/configurator/v1/mcp-catalog/upsert:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ValidateDataplane']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ValidateDataplane']._serialized_options = b'\220\002\001\212\265\030\n\n\001\002\022\005admin\252\265\030\tDataplane\202\323\344\223\002(\"#/configurator/v1/validate-dataplane:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CompleteEvent']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CompleteEvent']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002$\"\037/configurator/v1/complete-event:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveUsers']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveUsers']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\nMonitoring\202\323\344\223\002\037\022\035/configurator/v1/active-users'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveProviders']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveProviders']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\nMonitoring\202\323\344\223\002#\022!/configurator/v1/active-providers'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SaveBYOKBackends']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SaveBYOKBackends']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rBYOK Backends\202\323\344\223\002#\"\036/configurator/v1/byok-backends:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['DeleteBYOKBackends']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['DeleteBYOKBackends']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rBYOK Backends\202\323\344\223\002**(/configurator/v1/byok-backends/{user_id}'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RevokeUserToken']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RevokeUserToken']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\013User Tokens\202\323\344\223\002.\")/configurator/v1/user-tokens/{jti}:revoke:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpdateEventMetadata']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpdateEventMetadata']._serialized_options = b'\212\265\030\n\n\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002$\"\037/configurator/v1/event-metadata:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SubmitDataplaneUpgradeCredentials']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SubmitDataplaneUpgradeCredentials']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0023\"./configurator/v1/dataplane-upgrade-credentials:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetDataplaneUpgradeCredentials']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetDataplaneUpgradeCredentials']._serialized_options = b'\220\002\001\212\265\030\n\n\001\002\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0027\"2/configurator/v1/dataplane-upgrade-credentials/get:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AckDataplaneUpgradeCredentials']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AckDataplaneUpgradeCredentials']._serialized_options = b'\212\265\030\n\n\001\002\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0027\"2/configurator/v1/dataplane-upgrade-credentials/ack:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CancelDataplaneUpgrade']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CancelDataplaneUpgrade']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\002.\")/configurator/v1/dataplane-upgrade/cancel:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RollbackDataplaneUpgrade']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RollbackDataplaneUpgrade']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0020\"+/configurator/v1/dataplane-upgrade/rollback:\001*'
  _globals['_CONFIGTYPE']._serialized_start=7308
  _globals['_CONFIGTYPE']._serialized_end=7726
  _globals['_EVENTTYPE']._serialized_start=7729
  _globals['_EVENTTYPE']._serialized_end=8006
  _globals['_GETCONFIGURATIONREQUEST']._serialized_start=186
  _globals['_GETCONFIGURATIONREQUEST']._serialized_end=276
  _globals['_USERCONFIGQUERY']._serialized_start=279
  _globals['_USERCONFIGQUERY']._serialized_end=452
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_start=454
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_end=557
  _globals['_TRIGGERUPDATEREQUEST']._serialized_start=560
  _globals['_TRIGGERUPDATEREQUEST']._serialized_end=863
  _globals['_TRIGGERMETADATA']._serialized_start=865
  _globals['_TRIGGERMETADATA']._serialized_end=974
  _globals['_DATAPLANEUPGRADETRIGGER']._serialized_start=977
  _globals['_DATAPLANEUPGRADETRIGGER']._serialized_end=1235
  _globals['_TRIGGERUPDATERESPONSE']._serialized_start=1238
  _globals['_TRIGGERUPDATERESPONSE']._serialized_end=1389
  _globals['_LISTCONFIGURATIONSREQUEST']._serialized_start=1392
  _globals['_LISTCONFIGURATIONSREQUEST']._serialized_end=1571
  _globals['_LISTCONFIGURATIONSRESPONSE']._serialized_start=1574
  _globals['_LISTCONFIGURATIONSRESPONSE']._serialized_end=1719
  _globals['_LISTPENDINGEVENTSREQUEST']._serialized_start=1722
  _globals['_LISTPENDINGEVENTSREQUEST']._serialized_end=1852
  _globals['_DOCTORRUNTIMESTATUS']._serialized_start=1855
  _globals['_DOCTORRUNTIMESTATUS']._serialized_end=2127
  _globals['_LISTPENDINGEVENTSRESPONSE']._serialized_start=2129
  _globals['_LISTPENDINGEVENTSRESPONSE']._serialized_end=2222
  _globals['_RECONCILEWORKSPACEREQUEST']._serialized_start=2224
  _globals['_RECONCILEWORKSPACEREQUEST']._serialized_end=2251
  _globals['_RECONCILEWORKSPACERESPONSE']._serialized_start=2254
  _globals['_RECONCILEWORKSPACERESPONSE']._serialized_end=2464
  _globals['_FULLSYNCWORKSPACEREQUEST']._serialized_start=2466
  _globals['_FULLSYNCWORKSPACEREQUEST']._serialized_end=2492
  _globals['_FULLSYNCWORKSPACERESPONSE']._serialized_start=2495
  _globals['_FULLSYNCWORKSPACERESPONSE']._serialized_end=2663
  _globals['_CONFIGURATIONEVENT']._serialized_start=2666
  _globals['_CONFIGURATIONEVENT']._serialized_end=3099
  _globals['_ACKNOWLEDGEEVENTREQUEST']._serialized_start=3101
  _globals['_ACKNOWLEDGEEVENTREQUEST']._serialized_end=3182
  _globals['_ACKNOWLEDGEEVENTRESPONSE']._serialized_start=3184
  _globals['_ACKNOWLEDGEEVENTRESPONSE']._serialized_end=3236
  _globals['_COMPLETEEVENTREQUEST']._serialized_start=3238
  _globals['_COMPLETEEVENTREQUEST']._serialized_end=3350
  _globals['_COMPLETEEVENTRESPONSE']._serialized_start=3352
  _globals['_COMPLETEEVENTRESPONSE']._serialized_end=3401
  _globals['_LISTACTIVEUSERSREQUEST']._serialized_start=3403
  _globals['_LISTACTIVEUSERSREQUEST']._serialized_end=3449
  _globals['_LISTACTIVEUSERSRESPONSE']._serialized_start=3451
  _globals['_LISTACTIVEUSERSRESPONSE']._serialized_end=3503
  _globals['_CONFIGURATION']._serialized_start=3506
  _globals['_CONFIGURATION']._serialized_end=3829
  _globals['_PROVIDERBACKEND']._serialized_start=3832
  _globals['_PROVIDERBACKEND']._serialized_end=4068
  _globals['_SAVEBYOKBACKENDSREQUEST']._serialized_start=4071
  _globals['_SAVEBYOKBACKENDSREQUEST']._serialized_end=4221
  _globals['_SAVEBYOKBACKENDSRESPONSE']._serialized_start=4223
  _globals['_SAVEBYOKBACKENDSRESPONSE']._serialized_end=4350
  _globals['_DELETEBYOKBACKENDSREQUEST']._serialized_start=4352
  _globals['_DELETEBYOKBACKENDSREQUEST']._serialized_end=4404
  _globals['_DELETEBYOKBACKENDSRESPONSE']._serialized_start=4406
  _globals['_DELETEBYOKBACKENDSRESPONSE']._serialized_end=4460
  _globals['_REVOKEUSERTOKENREQUEST']._serialized_start=4462
  _globals['_REVOKEUSERTOKENREQUEST']._serialized_end=4569
  _globals['_REVOKEUSERTOKENRESPONSE']._serialized_start=4571
  _globals['_REVOKEUSERTOKENRESPONSE']._serialized_end=4681
  _globals['_PROVIDER']._serialized_start=4684
  _globals['_PROVIDER']._serialized_end=4989
  _globals['_LISTACTIVEPROVIDERSREQUEST']._serialized_start=4991
  _globals['_LISTACTIVEPROVIDERSREQUEST']._serialized_end=5019
  _globals['_LISTACTIVEPROVIDERSRESPONSE']._serialized_start=5021
  _globals['_LISTACTIVEPROVIDERSRESPONSE']._serialized_end=5112
  _globals['_SETDATAPLANEURLREQUEST']._serialized_start=5114
  _globals['_SETDATAPLANEURLREQUEST']._serialized_end=5230
  _globals['_SETDATAPLANEURLRESPONSE']._serialized_start=5232
  _globals['_SETDATAPLANEURLRESPONSE']._serialized_end=5257
  _globals['_UPSERTMCPCATALOGSERVERREQUEST']._serialized_start=5260
  _globals['_UPSERTMCPCATALOGSERVERREQUEST']._serialized_end=5591
  _globals['_UPSERTMCPCATALOGSERVERRESPONSE']._serialized_start=5593
  _globals['_UPSERTMCPCATALOGSERVERRESPONSE']._serialized_end=5651
  _globals['_VALIDATEDATAPLANEREQUEST']._serialized_start=5653
  _globals['_VALIDATEDATAPLANEREQUEST']._serialized_end=5679
  _globals['_VALIDATEDATAPLANERESPONSE']._serialized_start=5681
  _globals['_VALIDATEDATAPLANERESPONSE']._serialized_end=5805
  _globals['_GATEKEEPERPUBLICKEY']._serialized_start=5807
  _globals['_GATEKEEPERPUBLICKEY']._serialized_end=5920
  _globals['_UPDATEEVENTMETADATAREQUEST']._serialized_start=5922
  _globals['_UPDATEEVENTMETADATAREQUEST']._serialized_end=6005
  _globals['_UPDATEEVENTMETADATARESPONSE']._serialized_start=6007
  _globals['_UPDATEEVENTMETADATARESPONSE']._serialized_end=6062
  _globals['_CANCELDATAPLANEUPGRADEREQUEST']._serialized_start=6064
  _globals['_CANCELDATAPLANEUPGRADEREQUEST']._serialized_end=6137
  _globals['_CANCELDATAPLANEUPGRADERESPONSE']._serialized_start=6139
  _globals['_CANCELDATAPLANEUPGRADERESPONSE']._serialized_end=6197
  _globals['_ROLLBACKDATAPLANEUPGRADEREQUEST']._serialized_start=6199
  _globals['_ROLLBACKDATAPLANEUPGRADEREQUEST']._serialized_end=6274
  _globals['_ROLLBACKDATAPLANEUPGRADERESPONSE']._serialized_start=6276
  _globals['_ROLLBACKDATAPLANEUPGRADERESPONSE']._serialized_end=6380
  _globals['_DATAPLANEUPGRADECREDENTIAL']._serialized_start=6383
  _globals['_DATAPLANEUPGRADECREDENTIAL']._serialized_end=6515
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_start=6518
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_end=6732
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_start=6734
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_end=6842
  _globals['_GETDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_start=6844
  _globals['_GETDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_end=6925
  _globals['_GETDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_start=6928
  _globals['_GETDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_end=7124
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_start=7126
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_end=7237
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_start=7239
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_end=7305
  _globals['_CONFIGURATORSERVICE']._serialized_start=8009
  _globals['_CONFIGURATORSERVICE']._serialized_end=12530
# @@protoc_insertion_point(module_scope)
