# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/identity/v1/api_key.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/identity/v1/api_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etars/identity/v1/api_key.proto\x12\x10tars.identity.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x04\n\x06\x41piKey\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0bidentity_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nidentityId\x12$\n\x0b\x63ustomer_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12\x1b\n\x06prefix\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x06prefix\x12\x38\n\x05state\x18\x06 \x01(\x0e\x32\x1d.tars.identity.v1.ApiKeyStateB\x03\xe0\x41\x03R\x05state\x12\x35\n\x04type\x18\t \x01(\x0e\x32\x1c.tars.identity.v1.ApiKeyTypeB\x03\xe0\x41\x03R\x04type\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x41\n\x0clast_used_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nlastUsedAt\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nrevoked_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\trevokedAt\"\xa6\x02\n\x07Session\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0bidentity_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nidentityId\x12<\n\tissued_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x08issuedAt\x12>\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\texpiresAt\x12)\n\x0estep_up_active\x18\x05 \x01(\x08\x42\x03\xe0\x41\x03R\x0cstepUpActive\x12\"\n\nuser_agent\x18\x06 \x01(\tB\x03\xe0\x41\x03R\tuserAgent\x12\x13\n\x02ip\x18\x07 \x01(\tB\x03\xe0\x41\x03R\x02ip\"\xed\x01\n\x03Jwk\x12\x15\n\x03kid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03kid\x12$\n\x0bidentity_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nidentityId\x12)\n\x0epublic_key_pem\x18\x03 \x01(\x0c\x42\x03\xe0\x41\x02R\x0cpublicKeyPem\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\ndeleted_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tdeletedAt*a\n\x0b\x41piKeyState\x12\x1d\n\x19\x41PI_KEY_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41PI_KEY_STATE_ACTIVE\x10\x01\x12\x19\n\x15\x41PI_KEY_STATE_REVOKED\x10\x02*`\n\nApiKeyType\x12\x1c\n\x18\x41PI_KEY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41PI_KEY_TYPE_PROMPT\x10\x01\x12\x1b\n\x17\x41PI_KEY_TYPE_MANAGEMENT\x10\x02\x42\xc2\x01\n\x14\x63om.tars.identity.v1B\x0b\x41piKeyProtoP\x01Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Identity.V1\xca\x02\x10Tars\\Identity\\V1\xe2\x02\x1cTars\\Identity\\V1\\GPBMetadata\xea\x02\x12Tars::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.identity.v1.api_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.identity.v1B\013ApiKeyProtoP\001Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\242\002\003TIX\252\002\020Tars.Identity.V1\312\002\020Tars\\Identity\\V1\342\002\034Tars\\Identity\\V1\\GPBMetadata\352\002\022Tars::Identity::V1'
  _globals['_APIKEY'].fields_by_name['id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['identity_id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['identity_id']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['customer_id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['prefix']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['prefix']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['state']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['type']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['type']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['last_used_at']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['last_used_at']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['created_at']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['revoked_at']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['revoked_at']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['id']._loaded_options = None
  _globals['_SESSION'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['identity_id']._loaded_options = None
  _globals['_SESSION'].fields_by_name['identity_id']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['issued_at']._loaded_options = None
  _globals['_SESSION'].fields_by_name['issued_at']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['expires_at']._loaded_options = None
  _globals['_SESSION'].fields_by_name['expires_at']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['step_up_active']._loaded_options = None
  _globals['_SESSION'].fields_by_name['step_up_active']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['user_agent']._loaded_options = None
  _globals['_SESSION'].fields_by_name['user_agent']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['ip']._loaded_options = None
  _globals['_SESSION'].fields_by_name['ip']._serialized_options = b'\340A\003'
  _globals['_JWK'].fields_by_name['kid']._loaded_options = None
  _globals['_JWK'].fields_by_name['kid']._serialized_options = b'\340A\002'
  _globals['_JWK'].fields_by_name['identity_id']._loaded_options = None
  _globals['_JWK'].fields_by_name['identity_id']._serialized_options = b'\340A\003'
  _globals['_JWK'].fields_by_name['public_key_pem']._loaded_options = None
  _globals['_JWK'].fields_by_name['public_key_pem']._serialized_options = b'\340A\002'
  _globals['_JWK'].fields_by_name['created_at']._loaded_options = None
  _globals['_JWK'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_JWK'].fields_by_name['deleted_at']._loaded_options = None
  _globals['_JWK'].fields_by_name['deleted_at']._serialized_options = b'\340A\003'
  _globals['_APIKEYSTATE']._serialized_start=1179
  _globals['_APIKEYSTATE']._serialized_end=1276
  _globals['_APIKEYTYPE']._serialized_start=1278
  _globals['_APIKEYTYPE']._serialized_end=1374
  _globals['_APIKEY']._serialized_start=119
  _globals['_APIKEY']._serialized_end=640
  _globals['_SESSION']._serialized_start=643
  _globals['_SESSION']._serialized_end=937
  _globals['_JWK']._serialized_start=940
  _globals['_JWK']._serialized_end=1177
# @@protoc_insertion_point(module_scope)
