# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/sdk/v1/sdk.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/sdk/v1/sdk.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15tars/sdk/v1/sdk.proto\x12\x0btars.sdk.v1\x1a google/protobuf/descriptor.proto:9\n\x06handle\x12\x1f.google.protobuf.ServiceOptions\x18\xd6\x86\x03 \x01(\tR\x06handle:8\n\x06method\x12\x1e.google.protobuf.MethodOptions\x18\xd6\x86\x03 \x01(\tR\x06methodB\x9c\x01\n\x0f\x63om.tars.sdk.v1B\x08SdkProtoP\x01Z1github.com/tetrateio/fraser/api/tars/sdk/v1;sdkv1\xa2\x02\x03TSX\xaa\x02\x0bTars.Sdk.V1\xca\x02\x0bTars\\Sdk\\V1\xe2\x02\x17Tars\\Sdk\\V1\\GPBMetadata\xea\x02\rTars::Sdk::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.sdk.v1.sdk_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.sdk.v1B\010SdkProtoP\001Z1github.com/tetrateio/fraser/api/tars/sdk/v1;sdkv1\242\002\003TSX\252\002\013Tars.Sdk.V1\312\002\013Tars\\Sdk\\V1\342\002\027Tars\\Sdk\\V1\\GPBMetadata\352\002\rTars::Sdk::V1'
# @@protoc_insertion_point(module_scope)
