from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
COMMAND_FIELD_NUMBER: _ClassVar[int]
command: _descriptor.FieldDescriptor
FIELD_FIELD_NUMBER: _ClassVar[int]
field: _descriptor.FieldDescriptor

class Command(_message.Message):
    __slots__ = ("name", "aliases", "primary_flag", "hidden", "path")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALIASES_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_FLAG_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    name: str
    aliases: _containers.RepeatedScalarFieldContainer[str]
    primary_flag: str
    hidden: bool
    path: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., aliases: _Optional[_Iterable[str]] = ..., primary_flag: _Optional[str] = ..., hidden: _Optional[bool] = ..., path: _Optional[_Iterable[str]] = ...) -> None: ...

class Field(_message.Message):
    __slots__ = ("flag", "hidden")
    FLAG_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    flag: str
    hidden: bool
    def __init__(self, flag: _Optional[str] = ..., hidden: _Optional[bool] = ...) -> None: ...
