# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/identity/v1/identity_service.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/identity/v1/identity_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2
from tars.identity.v1 import api_key_pb2 as tars_dot_identity_dot_v1_dot_api__key__pb2
from tars.identity.v1 import identity_pb2 as tars_dot_identity_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'tars/identity/v1/identity_service.proto\x12\x10tars.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\x1a\x1etars/identity/v1/api_key.proto\x1a\x1ftars/identity/v1/identity.proto\"\xb3\x01\n\x0cLoginRequest\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12&\n\x0credirect_uri\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bredirectUri\x12*\n\x0e\x63ode_challenge\x18\x03 \x01(\tB\x03\xe0\x41\x02R\rcodeChallenge\x12\x37\n\x15\x63ode_challenge_method\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x13\x63odeChallengeMethod\"\\\n\rLoginResponse\x12\x30\n\x11\x61uthorization_url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x10\x61uthorizationUrl\x12\x19\n\x05state\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05state\"\x0f\n\rLogoutRequest\"\x10\n\x0eLogoutResponse\"\x0e\n\x0cGetMeRequest\"G\n\rGetMeResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32\x1a.tars.identity.v1.IdentityR\x08identity\"\x87\x01\n\x11IssueMyKeyRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\x1c.tars.identity.v1.ApiKeyTypeR\x04type\x12\'\n\x0fidempotency_key\x18\x63 \x01(\tR\x0eidempotencyKey\"]\n\x12IssueMyKeyResponse\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x18.tars.identity.v1.ApiKeyR\x03key\x12\x1b\n\x06secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x06secret\"D\n\x11ListMyKeysRequest\x12/\n\x04page\x18\x01 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"t\n\x12ListMyKeysResponse\x12,\n\x04keys\x18\x01 \x03(\x0b\x32\x18.tars.identity.v1.ApiKeyR\x04keys\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"0\n\x12RevokeMyKeyRequest\x12\x1a\n\x06key_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05keyId\"\x15\n\x13RevokeMyKeyResponse\"-\n\x14ResolveApiKeyRequest\x12\x15\n\x03key\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03key\"{\n\x15ResolveApiKeyResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32\x1a.tars.identity.v1.IdentityR\x08identity\x12*\n\x03key\x18\x02 \x01(\x0b\x32\x18.tars.identity.v1.ApiKeyR\x03key2\xd0\x07\n\tMeService\x12\x8b\x01\n\x05Login\x12\x1e.tars.identity.v1.LoginRequest\x1a\x1f.tars.identity.v1.LoginResponse\"A\x92\xb5\x18\x02(\x01\xa2\xb5\x18\x13Initiate OIDC login\xaa\xb5\x18\x07\x41\x63\x63ount\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/auth/login:\x01*\x12\x90\x01\n\x06Logout\x12\x1f.tars.identity.v1.LogoutRequest\x1a .tars.identity.v1.LogoutResponse\"C\x8a\xb5\x18\x03\n\x01\x03\x92\xb5\x18\x08:\x06logout\xa2\xb5\x18\x07Log out\xaa\xb5\x18\x07\x41\x63\x63ount\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/auth/logout:\x01*\x12\x92\x01\n\x05GetMe\x12\x1e.tars.identity.v1.GetMeRequest\x1a\x1f.tars.identity.v1.GetMeResponse\"H\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x08:\x06whoami\xa2\xb5\x18\x14Get current identity\xaa\xb5\x18\x07\x41\x63\x63ount\x82\xd3\xe4\x93\x02\x08\x12\x06/v1/me\x12\xa8\x01\n\nIssueMyKey\x12#.tars.identity.v1.IssueMyKeyRequest\x1a$.tars.identity.v1.IssueMyKeyResponse\"O\x8a\xb5\x18\x03\n\x01\x03\x92\xb5\x18\x0e:\x04keys:\x06\x63reate\xa2\xb5\x18\x10Issue an API key\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/me/keys:\x01*\x12\xa4\x01\n\nListMyKeys\x12#.tars.identity.v1.ListMyKeysRequest\x1a$.tars.identity.v1.ListMyKeysResponse\"K\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0c:\x04keys:\x04list\xa2\xb5\x18\rList API keys\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/me/keys\x12\xba\x01\n\x0bRevokeMyKey\x12$.tars.identity.v1.RevokeMyKeyRequest\x1a%.tars.identity.v1.RevokeMyKeyResponse\"^\x8a\xb5\x18\x03\n\x01\x03\x92\xb5\x18\x16\x1a\x06key_id:\x04keys:\x06revoke\xa2\xb5\x18\x11Revoke an API key\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x16*\x14/v1/me/keys/{key_id}2\x8f\x01\n\x0fIdentityService\x12|\n\rResolveApiKey\x12&.tars.identity.v1.ResolveApiKeyRequest\x1a\'.tars.identity.v1.ResolveApiKeyResponse\"\x1a\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x02(\x01\x42\xcb\x01\n\x14\x63om.tars.identity.v1B\x14IdentityServiceProtoP\x01Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Identity.V1\xca\x02\x10Tars\\Identity\\V1\xe2\x02\x1cTars\\Identity\\V1\\GPBMetadata\xea\x02\x12Tars::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.identity.v1.identity_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.identity.v1B\024IdentityServiceProtoP\001Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\242\002\003TIX\252\002\020Tars.Identity.V1\312\002\020Tars\\Identity\\V1\342\002\034Tars\\Identity\\V1\\GPBMetadata\352\002\022Tars::Identity::V1'
  _globals['_LOGINREQUEST'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_LOGINREQUEST'].fields_by_name['redirect_uri']._serialized_options = b'\340A\002'
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge']._loaded_options = None
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge']._serialized_options = b'\340A\002'
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge_method']._loaded_options = None
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge_method']._serialized_options = b'\340A\002'
  _globals['_LOGINRESPONSE'].fields_by_name['authorization_url']._loaded_options = None
  _globals['_LOGINRESPONSE'].fields_by_name['authorization_url']._serialized_options = b'\340A\003'
  _globals['_LOGINRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_LOGINRESPONSE'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_ISSUEMYKEYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ISSUEMYKEYREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_ISSUEMYKEYRESPONSE'].fields_by_name['secret']._loaded_options = None
  _globals['_ISSUEMYKEYRESPONSE'].fields_by_name['secret']._serialized_options = b'\340A\003'
  _globals['_REVOKEMYKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_REVOKEMYKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\340A\002'
  _globals['_RESOLVEAPIKEYREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_RESOLVEAPIKEYREQUEST'].fields_by_name['key']._serialized_options = b'\340A\002'
  _globals['_MESERVICE'].methods_by_name['Login']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['Login']._serialized_options = b'\222\265\030\002(\001\242\265\030\023Initiate OIDC login\252\265\030\007Account\202\323\344\223\002\023\"\016/v1/auth/login:\001*'
  _globals['_MESERVICE'].methods_by_name['Logout']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['Logout']._serialized_options = b'\212\265\030\003\n\001\003\222\265\030\010:\006logout\242\265\030\007Log out\252\265\030\007Account\202\323\344\223\002\024\"\017/v1/auth/logout:\001*'
  _globals['_MESERVICE'].methods_by_name['GetMe']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['GetMe']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\010:\006whoami\242\265\030\024Get current identity\252\265\030\007Account\202\323\344\223\002\010\022\006/v1/me'
  _globals['_MESERVICE'].methods_by_name['IssueMyKey']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['IssueMyKey']._serialized_options = b'\212\265\030\003\n\001\003\222\265\030\016:\004keys:\006create\242\265\030\020Issue an API key\252\265\030\010API Keys\202\323\344\223\002\020\"\013/v1/me/keys:\001*'
  _globals['_MESERVICE'].methods_by_name['ListMyKeys']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['ListMyKeys']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\014:\004keys:\004list\242\265\030\rList API keys\252\265\030\010API Keys\202\323\344\223\002\r\022\013/v1/me/keys'
  _globals['_MESERVICE'].methods_by_name['RevokeMyKey']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['RevokeMyKey']._serialized_options = b'\212\265\030\003\n\001\003\222\265\030\026\032\006key_id:\004keys:\006revoke\242\265\030\021Revoke an API key\252\265\030\010API Keys\202\323\344\223\002\026*\024/v1/me/keys/{key_id}'
  _globals['_IDENTITYSERVICE'].methods_by_name['ResolveApiKey']._loaded_options = None
  _globals['_IDENTITYSERVICE'].methods_by_name['ResolveApiKey']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal\222\265\030\002(\001'
  _globals['_LOGINREQUEST']._serialized_start=299
  _globals['_LOGINREQUEST']._serialized_end=478
  _globals['_LOGINRESPONSE']._serialized_start=480
  _globals['_LOGINRESPONSE']._serialized_end=572
  _globals['_LOGOUTREQUEST']._serialized_start=574
  _globals['_LOGOUTREQUEST']._serialized_end=589
  _globals['_LOGOUTRESPONSE']._serialized_start=591
  _globals['_LOGOUTRESPONSE']._serialized_end=607
  _globals['_GETMEREQUEST']._serialized_start=609
  _globals['_GETMEREQUEST']._serialized_end=623
  _globals['_GETMERESPONSE']._serialized_start=625
  _globals['_GETMERESPONSE']._serialized_end=696
  _globals['_ISSUEMYKEYREQUEST']._serialized_start=699
  _globals['_ISSUEMYKEYREQUEST']._serialized_end=834
  _globals['_ISSUEMYKEYRESPONSE']._serialized_start=836
  _globals['_ISSUEMYKEYRESPONSE']._serialized_end=929
  _globals['_LISTMYKEYSREQUEST']._serialized_start=931
  _globals['_LISTMYKEYSREQUEST']._serialized_end=999
  _globals['_LISTMYKEYSRESPONSE']._serialized_start=1001
  _globals['_LISTMYKEYSRESPONSE']._serialized_end=1117
  _globals['_REVOKEMYKEYREQUEST']._serialized_start=1119
  _globals['_REVOKEMYKEYREQUEST']._serialized_end=1167
  _globals['_REVOKEMYKEYRESPONSE']._serialized_start=1169
  _globals['_REVOKEMYKEYRESPONSE']._serialized_end=1190
  _globals['_RESOLVEAPIKEYREQUEST']._serialized_start=1192
  _globals['_RESOLVEAPIKEYREQUEST']._serialized_end=1237
  _globals['_RESOLVEAPIKEYRESPONSE']._serialized_start=1239
  _globals['_RESOLVEAPIKEYRESPONSE']._serialized_end=1362
  _globals['_MESERVICE']._serialized_start=1365
  _globals['_MESERVICE']._serialized_end=2341
  _globals['_IDENTITYSERVICE']._serialized_start=2344
  _globals['_IDENTITYSERVICE']._serialized_end=2487
# @@protoc_insertion_point(module_scope)
