# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/identity/v1/identity.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/identity/v1/identity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/identity/v1/identity.proto\x12\x10tars.identity.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x01\n\x0bUserDetails\x12&\n\x0coidc_subject\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0boidcSubject\x12$\n\x0boidc_issuer\x18\x02 \x01(\tB\x03\xe0\x41\x02R\noidcIssuer\x12\x14\n\x05\x65mail\x18\x03 \x01(\tR\x05\x65mail\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12%\n\x0e\x65mail_verified\x18\x05 \x01(\x08R\remailVerified\"9\n\x15ServiceAccountDetails\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\"1\n\rClientDetails\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\"\xf5\x04\n\x08Identity\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32\x1e.tars.identity.v1.IdentityTypeB\x03\xe0\x41\x02R\x04type\x12:\n\x05state\x18\x04 \x01(\x0e\x32\x1f.tars.identity.v1.IdentityStateB\x03\xe0\x41\x03R\x05state\x12\x33\n\x04user\x18\n \x01(\x0b\x32\x1d.tars.identity.v1.UserDetailsH\x00R\x04user\x12R\n\x0fservice_account\x18\x0b \x01(\x0b\x32\'.tars.identity.v1.ServiceAccountDetailsH\x00R\x0eserviceAccount\x12\x39\n\x06\x63lient\x18\x0c \x01(\x0b\x32\x1f.tars.identity.v1.ClientDetailsH\x00R\x06\x63lient\x12\x18\n\x07\x62undles\x18\x14 \x03(\tR\x07\x62undles\x12\x36\n\x14\x63ustomer_memberships\x18\x15 \x03(\tB\x03\xe0\x41\x03R\x13\x63ustomerMemberships\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\x12\x18\n\x07version\x18\x34 \x01(\x03R\x07versionB\t\n\x07\x64\x65tails*\x82\x01\n\x0cIdentityType\x12\x1d\n\x19IDENTITY_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12IDENTITY_TYPE_USER\x10\x01\x12!\n\x1dIDENTITY_TYPE_SERVICE_ACCOUNT\x10\x02\x12\x18\n\x14IDENTITY_TYPE_CLIENT\x10\x03*\x84\x01\n\rIdentityState\x12\x1e\n\x1aIDENTITY_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15IDENTITY_STATE_ACTIVE\x10\x01\x12\x1c\n\x18IDENTITY_STATE_SUSPENDED\x10\x02\x12\x1a\n\x16IDENTITY_STATE_DELETED\x10\x03\x42\xc4\x01\n\x14\x63om.tars.identity.v1B\rIdentityProtoP\x01Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Identity.V1\xca\x02\x10Tars\\Identity\\V1\xe2\x02\x1cTars\\Identity\\V1\\GPBMetadata\xea\x02\x12Tars::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.identity.v1.identity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.identity.v1B\rIdentityProtoP\001Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\242\002\003TIX\252\002\020Tars.Identity.V1\312\002\020Tars\\Identity\\V1\342\002\034Tars\\Identity\\V1\\GPBMetadata\352\002\022Tars::Identity::V1'
  _globals['_USERDETAILS'].fields_by_name['oidc_subject']._loaded_options = None
  _globals['_USERDETAILS'].fields_by_name['oidc_subject']._serialized_options = b'\340A\002'
  _globals['_USERDETAILS'].fields_by_name['oidc_issuer']._loaded_options = None
  _globals['_USERDETAILS'].fields_by_name['oidc_issuer']._serialized_options = b'\340A\002'
  _globals['_IDENTITY'].fields_by_name['id']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['customer_id']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['type']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['type']._serialized_options = b'\340A\002'
  _globals['_IDENTITY'].fields_by_name['state']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['customer_memberships']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['customer_memberships']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['created_at']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['updated_at']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_IDENTITYTYPE']._serialized_start=1037
  _globals['_IDENTITYTYPE']._serialized_end=1167
  _globals['_IDENTITYSTATE']._serialized_start=1170
  _globals['_IDENTITYSTATE']._serialized_end=1302
  _globals['_USERDETAILS']._serialized_start=120
  _globals['_USERDETAILS']._serialized_end=292
  _globals['_SERVICEACCOUNTDETAILS']._serialized_start=294
  _globals['_SERVICEACCOUNTDETAILS']._serialized_end=351
  _globals['_CLIENTDETAILS']._serialized_start=353
  _globals['_CLIENTDETAILS']._serialized_end=402
  _globals['_IDENTITY']._serialized_start=405
  _globals['_IDENTITY']._serialized_end=1034
# @@protoc_insertion_point(module_scope)
