# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/tenancy/v1/customer.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/tenancy/v1/customer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etars/tenancy/v1/customer.proto\x12\x0ftars.tenancy.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x81\x04\n\x08\x43ustomer\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x39\n\x05state\x18\x05 \x01(\x0e\x32\x1e.tars.tenancy.v1.CustomerStateB\x03\xe0\x41\x03R\x05state\x12=\n\x06labels\x18\x06 \x03(\x0b\x32%.tars.tenancy.v1.Customer.LabelsEntryR\x06labels\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\x12@\n\x0b\x61rchived_at\x18\x34 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\narchivedAt\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*g\n\rCustomerState\x12\x1e\n\x1a\x43USTOMER_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43USTOMER_STATE_ACTIVE\x10\x01\x12\x1b\n\x17\x43USTOMER_STATE_ARCHIVED\x10\x02\x42\xbd\x01\n\x13\x63om.tars.tenancy.v1B\rCustomerProtoP\x01Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\xa2\x02\x03TTX\xaa\x02\x0fTars.Tenancy.V1\xca\x02\x0fTars\\Tenancy\\V1\xe2\x02\x1bTars\\Tenancy\\V1\\GPBMetadata\xea\x02\x11Tars::Tenancy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.tenancy.v1.customer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.tenancy.v1B\rCustomerProtoP\001Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\242\002\003TTX\252\002\017Tars.Tenancy.V1\312\002\017Tars\\Tenancy\\V1\342\002\033Tars\\Tenancy\\V1\\GPBMetadata\352\002\021Tars::Tenancy::V1'
  _globals['_CUSTOMER_LABELSENTRY']._loaded_options = None
  _globals['_CUSTOMER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CUSTOMER'].fields_by_name['id']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CUSTOMER'].fields_by_name['state']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['created_at']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['updated_at']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['archived_at']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['archived_at']._serialized_options = b'\340A\003'
  _globals['_CUSTOMERSTATE']._serialized_start=633
  _globals['_CUSTOMERSTATE']._serialized_end=736
  _globals['_CUSTOMER']._serialized_start=118
  _globals['_CUSTOMER']._serialized_end=631
  _globals['_CUSTOMER_LABELSENTRY']._serialized_start=574
  _globals['_CUSTOMER_LABELSENTRY']._serialized_end=631
# @@protoc_insertion_point(module_scope)
