# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/inference/v1/inference.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/inference/v1/inference.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tars/inference/v1/inference.proto\x12\x11tars.inference.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\xe9\x01\n\rPromptRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x14\n\x05model\x18\x03 \x01(\tR\x05model\x12\x1b\n\x06prompt\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x06prompt\x12\x15\n\x06key_id\x18\x05 \x01(\tR\x05keyId\x12/\n\x0fidempotency_key\x18\x63 \x01(\tB\x06\x9a\xb5\x18\x02\x10\x01R\x0eidempotencyKey\"\xd4\x01\n\x0ePromptResponse\x12#\n\ncompletion\x18\x01 \x01(\tB\x03\xe0\x41\x03R\ncompletion\x12\x19\n\x05model\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05model\x12&\n\x0c\x64\x61taplane_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x61taplaneId\x12(\n\rprompt_tokens\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\x0cpromptTokens\x12\x30\n\x11\x63ompletion_tokens\x18\x05 \x01(\x05\x42\x03\xe0\x41\x03R\x10\x63ompletionTokens\"w\n\x16GetDataplaneURLRequest\x12,\n\nproject_id\x18\x01 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12/\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\"\xb0\x01\n\x0c\x44\x61taplaneURL\x12\x15\n\x03url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03url\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\x12&\n\x0cworkspace_id\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0bworkspaceId\x12\x17\n\x04name\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x04name\"]\n\x17GetDataplaneURLResponse\x12\x42\n\tdataplane\x18\x01 \x01(\x0b\x32\x1f.tars.inference.v1.DataplaneURLB\x03\xe0\x41\x03R\tdataplane\"\x1a\n\x18ListDataplaneURLsRequest\"a\n\x19ListDataplaneURLsResponse\x12\x44\n\ndataplanes\x18\x01 \x03(\x0b\x32\x1f.tars.inference.v1.DataplaneURLB\x03\xe0\x41\x03R\ndataplanes2\xd2\x04\n\x17InferenceIngressService\x12\xc0\x01\n\x06Prompt\x12 .tars.inference.v1.PromptRequest\x1a!.tars.inference.v1.PromptResponse\"q\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x10\x1a\x06prompt:\x06prompt\xa2\xb5\x18\rSend a prompt\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id}/projects/{project_id}/prompts:\x01*\x12\xb3\x01\n\x0fGetDataplaneURL\x12).tars.inference.v1.GetDataplaneURLRequest\x1a*.tars.inference.v1.GetDataplaneURLResponse\"I\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0f:\rdataplane-url\xa2\xb5\x18\x11Get dataplane URL\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/dataplane-url\x12\xbd\x01\n\x11ListDataplaneURLs\x12+.tars.inference.v1.ListDataplaneURLsRequest\x1a,.tars.inference.v1.ListDataplaneURLsResponse\"M\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x10:\x0e\x64\x61taplane-urls\xa2\xb5\x18\x13List dataplane URLs\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/dataplane-urlsB\xcc\x01\n\x15\x63om.tars.inference.v1B\x0eInferenceProtoP\x01Z=github.com/tetrateio/fraser/api/tars/inference/v1;inferencev1\xa2\x02\x03TIX\xaa\x02\x11Tars.Inference.V1\xca\x02\x11Tars\\Inference\\V1\xe2\x02\x1dTars\\Inference\\V1\\GPBMetadata\xea\x02\x13Tars::Inference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.inference.v1.inference_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.tars.inference.v1B\016InferenceProtoP\001Z=github.com/tetrateio/fraser/api/tars/inference/v1;inferencev1\242\002\003TIX\252\002\021Tars.Inference.V1\312\002\021Tars\\Inference\\V1\342\002\035Tars\\Inference\\V1\\GPBMetadata\352\002\023Tars::Inference::V1'
  _globals['_PROMPTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_PROMPTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_PROMPTREQUEST'].fields_by_name['prompt']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['prompt']._serialized_options = b'\340A\002'
  _globals['_PROMPTREQUEST'].fields_by_name['idempotency_key']._loaded_options = None
  _globals['_PROMPTREQUEST'].fields_by_name['idempotency_key']._serialized_options = b'\232\265\030\002\020\001'
  _globals['_PROMPTRESPONSE'].fields_by_name['completion']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['completion']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['model']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['model']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['dataplane_id']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['dataplane_id']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['prompt_tokens']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['prompt_tokens']._serialized_options = b'\340A\003'
  _globals['_PROMPTRESPONSE'].fields_by_name['completion_tokens']._loaded_options = None
  _globals['_PROMPTRESPONSE'].fields_by_name['completion_tokens']._serialized_options = b'\340A\003'
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETDATAPLANEURLREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_DATAPLANEURL'].fields_by_name['url']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['url']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['project_id']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['project_id']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['workspace_id']._serialized_options = b'\340A\003'
  _globals['_DATAPLANEURL'].fields_by_name['name']._loaded_options = None
  _globals['_DATAPLANEURL'].fields_by_name['name']._serialized_options = b'\340A\003'
  _globals['_GETDATAPLANEURLRESPONSE'].fields_by_name['dataplane']._loaded_options = None
  _globals['_GETDATAPLANEURLRESPONSE'].fields_by_name['dataplane']._serialized_options = b'\340A\003'
  _globals['_LISTDATAPLANEURLSRESPONSE'].fields_by_name['dataplanes']._loaded_options = None
  _globals['_LISTDATAPLANEURLSRESPONSE'].fields_by_name['dataplanes']._serialized_options = b'\340A\003'
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['Prompt']._loaded_options = None
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['Prompt']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\020\032\006prompt:\006prompt\242\265\030\rSend a prompt\202\323\344\223\002>\"9/v1/customers/{customer_id}/projects/{project_id}/prompts:\001*'
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['GetDataplaneURL']._loaded_options = None
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['GetDataplaneURL']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\017:\rdataplane-url\242\265\030\021Get dataplane URL\202\323\344\223\002\023\022\021/v1/dataplane-url'
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['ListDataplaneURLs']._loaded_options = None
  _globals['_INFERENCEINGRESSSERVICE'].methods_by_name['ListDataplaneURLs']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\020:\016dataplane-urls\242\265\030\023List dataplane URLs\202\323\344\223\002\024\022\022/v1/dataplane-urls'
  _globals['_PROMPTREQUEST']._serialized_start=201
  _globals['_PROMPTREQUEST']._serialized_end=434
  _globals['_PROMPTRESPONSE']._serialized_start=437
  _globals['_PROMPTRESPONSE']._serialized_end=649
  _globals['_GETDATAPLANEURLREQUEST']._serialized_start=651
  _globals['_GETDATAPLANEURLREQUEST']._serialized_end=770
  _globals['_DATAPLANEURL']._serialized_start=773
  _globals['_DATAPLANEURL']._serialized_end=949
  _globals['_GETDATAPLANEURLRESPONSE']._serialized_start=951
  _globals['_GETDATAPLANEURLRESPONSE']._serialized_end=1044
  _globals['_LISTDATAPLANEURLSREQUEST']._serialized_start=1046
  _globals['_LISTDATAPLANEURLSREQUEST']._serialized_end=1072
  _globals['_LISTDATAPLANEURLSRESPONSE']._serialized_start=1074
  _globals['_LISTDATAPLANEURLSRESPONSE']._serialized_end=1171
  _globals['_INFERENCEINGRESSSERVICE']._serialized_start=1174
  _globals['_INFERENCEINGRESSSERVICE']._serialized_end=1768
# @@protoc_insertion_point(module_scope)
