# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/docs/v1/docs.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/docs/v1/docs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tars/docs/v1/docs.proto\x12\x0ctars.docs.v1\x1a google/protobuf/descriptor.proto:6\n\x05title\x12\x1e.google.protobuf.MethodOptions\x18\xd4\x86\x03 \x01(\tR\x05title:6\n\x05group\x12\x1e.google.protobuf.MethodOptions\x18\xd5\x86\x03 \x01(\tR\x05group:=\n\x08internal\x12\x1f.google.protobuf.ServiceOptions\x18\xd4\x86\x03 \x01(\x08R\x08internalB\xa4\x01\n\x10\x63om.tars.docs.v1B\tDocsProtoP\x01Z3github.com/tetrateio/fraser/api/tars/docs/v1;docsv1\xa2\x02\x03TDX\xaa\x02\x0cTars.Docs.V1\xca\x02\x0cTars\\Docs\\V1\xe2\x02\x18Tars\\Docs\\V1\\GPBMetadata\xea\x02\x0eTars::Docs::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.docs.v1.docs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.tars.docs.v1B\tDocsProtoP\001Z3github.com/tetrateio/fraser/api/tars/docs/v1;docsv1\242\002\003TDX\252\002\014Tars.Docs.V1\312\002\014Tars\\Docs\\V1\342\002\030Tars\\Docs\\V1\\GPBMetadata\352\002\016Tars::Docs::V1'
# @@protoc_insertion_point(module_scope)
