from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
TITLE_FIELD_NUMBER: _ClassVar[int]
title: _descriptor.FieldDescriptor
GROUP_FIELD_NUMBER: _ClassVar[int]
group: _descriptor.FieldDescriptor
INTERNAL_FIELD_NUMBER: _ClassVar[int]
internal: _descriptor.FieldDescriptor
