# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/cli/v1/cli.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/cli/v1/cli.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15tars/cli/v1/cli.proto\x12\x0btars.cli.v1\x1a google/protobuf/descriptor.proto\"\xac\x01\n\x07\x43ommand\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07\x61liases\x18\x02 \x03(\tR\x07\x61liases\x12!\n\x0cprimary_flag\x18\x03 \x01(\tR\x0bprimaryFlag\x12\x16\n\x06hidden\x18\x05 \x01(\x08R\x06hidden\x12\x12\n\x04path\x18\x07 \x03(\tR\x04pathJ\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07R\x07\x63onfirmR\x0foutput_template\"3\n\x05\x46ield\x12\x12\n\x04\x66lag\x18\x01 \x01(\tR\x04\x66lag\x12\x16\n\x06hidden\x18\x02 \x01(\x08R\x06hidden:P\n\x07\x63ommand\x12\x1e.google.protobuf.MethodOptions\x18\xd2\x86\x03 \x01(\x0b\x32\x14.tars.cli.v1.CommandR\x07\x63ommand:I\n\x05\x66ield\x12\x1d.google.protobuf.FieldOptions\x18\xd3\x86\x03 \x01(\x0b\x32\x12.tars.cli.v1.FieldR\x05\x66ieldB\x9c\x01\n\x0f\x63om.tars.cli.v1B\x08\x43liProtoP\x01Z1github.com/tetrateio/fraser/api/tars/cli/v1;cliv1\xa2\x02\x03TCX\xaa\x02\x0bTars.Cli.V1\xca\x02\x0bTars\\Cli\\V1\xe2\x02\x17Tars\\Cli\\V1\\GPBMetadata\xea\x02\rTars::Cli::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.cli.v1.cli_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.cli.v1B\010CliProtoP\001Z1github.com/tetrateio/fraser/api/tars/cli/v1;cliv1\242\002\003TCX\252\002\013Tars.Cli.V1\312\002\013Tars\\Cli\\V1\342\002\027Tars\\Cli\\V1\\GPBMetadata\352\002\rTars::Cli::V1'
  _globals['_COMMAND']._serialized_start=73
  _globals['_COMMAND']._serialized_end=245
  _globals['_FIELD']._serialized_start=247
  _globals['_FIELD']._serialized_end=298
# @@protoc_insertion_point(module_scope)
