import datetime

from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    IDENTITY_TYPE_UNSPECIFIED: _ClassVar[IdentityType]
    IDENTITY_TYPE_USER: _ClassVar[IdentityType]
    IDENTITY_TYPE_SERVICE_ACCOUNT: _ClassVar[IdentityType]
    IDENTITY_TYPE_CLIENT: _ClassVar[IdentityType]

class IdentityState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    IDENTITY_STATE_UNSPECIFIED: _ClassVar[IdentityState]
    IDENTITY_STATE_ACTIVE: _ClassVar[IdentityState]
    IDENTITY_STATE_SUSPENDED: _ClassVar[IdentityState]
    IDENTITY_STATE_DELETED: _ClassVar[IdentityState]
IDENTITY_TYPE_UNSPECIFIED: IdentityType
IDENTITY_TYPE_USER: IdentityType
IDENTITY_TYPE_SERVICE_ACCOUNT: IdentityType
IDENTITY_TYPE_CLIENT: IdentityType
IDENTITY_STATE_UNSPECIFIED: IdentityState
IDENTITY_STATE_ACTIVE: IdentityState
IDENTITY_STATE_SUSPENDED: IdentityState
IDENTITY_STATE_DELETED: IdentityState

class UserDetails(_message.Message):
    __slots__ = ("oidc_subject", "oidc_issuer", "email", "name", "email_verified")
    OIDC_SUBJECT_FIELD_NUMBER: _ClassVar[int]
    OIDC_ISSUER_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    oidc_subject: str
    oidc_issuer: str
    email: str
    name: str
    email_verified: bool
    def __init__(self, oidc_subject: _Optional[str] = ..., oidc_issuer: _Optional[str] = ..., email: _Optional[str] = ..., name: _Optional[str] = ..., email_verified: _Optional[bool] = ...) -> None: ...

class ServiceAccountDetails(_message.Message):
    __slots__ = ("description",)
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    description: str
    def __init__(self, description: _Optional[str] = ...) -> None: ...

class ClientDetails(_message.Message):
    __slots__ = ("description",)
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    description: str
    def __init__(self, description: _Optional[str] = ...) -> None: ...

class Identity(_message.Message):
    __slots__ = ("id", "customer_id", "type", "state", "user", "service_account", "client", "bundles", "customer_memberships", "created_at", "updated_at", "version")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    BUNDLES_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_MEMBERSHIPS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    type: IdentityType
    state: IdentityState
    user: UserDetails
    service_account: ServiceAccountDetails
    client: ClientDetails
    bundles: _containers.RepeatedScalarFieldContainer[str]
    customer_memberships: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    version: int
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., type: _Optional[_Union[IdentityType, str]] = ..., state: _Optional[_Union[IdentityState, str]] = ..., user: _Optional[_Union[UserDetails, _Mapping]] = ..., service_account: _Optional[_Union[ServiceAccountDetails, _Mapping]] = ..., client: _Optional[_Union[ClientDetails, _Mapping]] = ..., bundles: _Optional[_Iterable[str]] = ..., customer_memberships: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., version: _Optional[int] = ...) -> None: ...
