# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/api_keys/v1/api_keys.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/api_keys/v1/api_keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/api_keys/v1/api_keys.proto\x12\x10tars.api_keys.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"\x84\x01\n\x11\x45nterpriseContext\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x02 \x01(\tR\x0bworkspaceId\x12+\n\x11organization_unit\x18\x03 \x01(\tR\x10organizationUnit\"\xdc\x01\n\x13\x43reateApiKeyRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12(\n\x10user_key_address\x18\x02 \x01(\tR\x0euserKeyAddress\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12W\n\x12\x65nterprise_context\x18\x04 \x01(\x0b\x32#.tars.api_keys.v1.EnterpriseContextH\x00R\x11\x65nterpriseContext\x88\x01\x01\x42\x15\n\x13_enterprise_context\"\xcb\x01\n\x14\x43reateApiKeyResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x17\n\x07\x61pi_key\x18\x03 \x01(\tR\x06\x61piKey\x12\x16\n\x06prefix\x18\x04 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x05 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x06 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x07 \x01(\tR\tkeySuffix\"\x97\x01\n\x13UpdateApiKeyRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x17\n\x04name\x18\x03 \x01(\tH\x00R\x04name\x88\x01\x01\x12 \n\tis_active\x18\x04 \x01(\x08H\x01R\x08isActive\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_is_active\"0\n\x14UpdateApiKeyResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"E\n\x13\x44\x65leteApiKeyRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\"0\n\x14\x44\x65leteApiKeyResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success2\xd8\x03\n\x0e\x41piKeysService\x12\x90\x01\n\x0c\x43reateApiKey\x12%.tars.api_keys.v1.CreateApiKeyRequest\x1a&.tars.api_keys.v1.CreateApiKeyResponse\"1\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/api-keys:\x01*\x12\x99\x01\n\x0cUpdateApiKey\x12%.tars.api_keys.v1.UpdateApiKeyRequest\x1a&.tars.api_keys.v1.UpdateApiKeyResponse\":\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x1a\x32\x15/v1/api-keys/{key_id}:\x01*\x12\x96\x01\n\x0c\x44\x65leteApiKey\x12%.tars.api_keys.v1.DeleteApiKeyRequest\x1a&.tars.api_keys.v1.DeleteApiKeyResponse\"7\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x17*\x15/v1/api-keys/{key_id}B\xbe\x01\n\x14\x63om.tars.api_keys.v1B\x0c\x41piKeysProtoP\x01Z:github.com/tetrateio/fraser/api/tars/api_keys/v1;apikeysv1\xa2\x02\x03TAX\xaa\x02\x0fTars.ApiKeys.V1\xca\x02\x0fTars\\ApiKeys\\V1\xe2\x02\x1bTars\\ApiKeys\\V1\\GPBMetadata\xea\x02\x11Tars::ApiKeys::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.api_keys.v1.api_keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.api_keys.v1B\014ApiKeysProtoP\001Z:github.com/tetrateio/fraser/api/tars/api_keys/v1;apikeysv1\242\002\003TAX\252\002\017Tars.ApiKeys.V1\312\002\017Tars\\ApiKeys\\V1\342\002\033Tars\\ApiKeys\\V1\\GPBMetadata\352\002\021Tars::ApiKeys::V1'
  _globals['_APIKEYSSERVICE'].methods_by_name['CreateApiKey']._loaded_options = None
  _globals['_APIKEYSSERVICE'].methods_by_name['CreateApiKey']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\010API Keys\202\323\344\223\002\021\"\014/v1/api-keys:\001*'
  _globals['_APIKEYSSERVICE'].methods_by_name['UpdateApiKey']._loaded_options = None
  _globals['_APIKEYSSERVICE'].methods_by_name['UpdateApiKey']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\010API Keys\202\323\344\223\002\0322\025/v1/api-keys/{key_id}:\001*'
  _globals['_APIKEYSSERVICE'].methods_by_name['DeleteApiKey']._loaded_options = None
  _globals['_APIKEYSSERVICE'].methods_by_name['DeleteApiKey']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\010API Keys\202\323\344\223\002\027*\025/v1/api-keys/{key_id}'
  _globals['_ENTERPRISECONTEXT']._serialized_start=142
  _globals['_ENTERPRISECONTEXT']._serialized_end=274
  _globals['_CREATEAPIKEYREQUEST']._serialized_start=277
  _globals['_CREATEAPIKEYREQUEST']._serialized_end=497
  _globals['_CREATEAPIKEYRESPONSE']._serialized_start=500
  _globals['_CREATEAPIKEYRESPONSE']._serialized_end=703
  _globals['_UPDATEAPIKEYREQUEST']._serialized_start=706
  _globals['_UPDATEAPIKEYREQUEST']._serialized_end=857
  _globals['_UPDATEAPIKEYRESPONSE']._serialized_start=859
  _globals['_UPDATEAPIKEYRESPONSE']._serialized_end=907
  _globals['_DELETEAPIKEYREQUEST']._serialized_start=909
  _globals['_DELETEAPIKEYREQUEST']._serialized_end=978
  _globals['_DELETEAPIKEYRESPONSE']._serialized_start=980
  _globals['_DELETEAPIKEYRESPONSE']._serialized_end=1028
  _globals['_APIKEYSSERVICE']._serialized_start=1031
  _globals['_APIKEYSSERVICE']._serialized_end=1503
# @@protoc_insertion_point(module_scope)
