# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/mcp/v1/mcp.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/mcp/v1/mcp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15tars/mcp/v1/mcp.proto\x12\x0btars.mcp.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\"\xfe\x03\n\nMCPProfile\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1f\n\x0b\x63ustomer_id\x18\n \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x0b \x01(\tR\tprojectId\x12\x17\n\x04name\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x03url\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x03url\x12\x1b\n\x06status\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x06status\x12(\n\rerror_message\x18\x07 \x01(\tB\x03\xe0\x41\x03R\x0c\x65rrorMessage\x12\x35\n\x14security_policy_type\x18\x08 \x01(\tB\x03\xe0\x41\x02R\x12securityPolicyType\x12\x32\n\x15security_policy_value\x18\t \x01(\tR\x13securityPolicyValue\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\"\xef\x03\n\x10MCPCatalogServer\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x03url\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x03url\x12\x19\n\x08icon_url\x18\x06 \x01(\tR\x07iconUrl\x12\x1e\n\ncategories\x18\x07 \x03(\tR\ncategories\x12\x12\n\x04note\x18\x08 \x01(\tR\x04note\x12&\n\x0e\x61uthentication\x18\t \x01(\tR\x0e\x61uthentication\x12#\n\rrequires_auth\x18\n \x01(\x08R\x0crequiresAuth\x12)\n\x10requires_profile\x18\x0b \x01(\x08R\x0frequiresProfile\x12\x1d\n\nis_enabled\x18\x0c \x01(\x08R\tisEnabled\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAtJ\x04\x08\x05\x10\x06R\x08tars_url\"\x98\x02\n\x17\x43reateMCPProfileRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x35\n\x14security_policy_type\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x12securityPolicyType\x12\x32\n\x15security_policy_value\x18\x05 \x01(\tR\x13securityPolicyValue\x12\x1f\n\x0b\x63ustomer_id\x18\x06 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x07 \x01(\tR\tprojectId\"\x93\x01\n\x14GetMCPProfileRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\"\n\nprofile_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprofileId\x12\x1f\n\x0b\x63ustomer_id\x18\x03 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x04 \x01(\tR\tprojectId\"\xa2\x01\n\x16ListMCPProfilesRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12/\n\x04page\x18\x02 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\x12\x1f\n\x0b\x63ustomer_id\x18\x03 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x04 \x01(\tR\tprojectId\"\x80\x01\n\x17ListMCPProfilesResponse\x12\x33\n\x08profiles\x18\x01 \x03(\x0b\x32\x17.tars.mcp.v1.MCPProfileR\x08profiles\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\xb2\x02\n\x17UpdateMCPProfileRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\"\n\nprofile_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprofileId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x30\n\x14security_policy_type\x18\x05 \x01(\tR\x12securityPolicyType\x12\x32\n\x15security_policy_value\x18\x06 \x01(\tR\x13securityPolicyValue\x12\x1f\n\x0b\x63ustomer_id\x18\x07 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x08 \x01(\tR\tprojectId\"\x96\x01\n\x17\x44\x65leteMCPProfileRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\"\n\nprofile_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprofileId\x12\x1f\n\x0b\x63ustomer_id\x18\x03 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x04 \x01(\tR\tprojectId\"\xfb\x02\n\x1aUpsertCatalogServerRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12&\n\x03url\x18\x04 \x01(\tB\x14\xe0\x41\x02\x9a\xb5\x18\r\n\x0b\x63\x61talog-urlR\x03url\x12\x19\n\x08icon_url\x18\x06 \x01(\tR\x07iconUrl\x12\x1e\n\ncategories\x18\x07 \x03(\tR\ncategories\x12\x12\n\x04note\x18\x08 \x01(\tR\x04note\x12&\n\x0e\x61uthentication\x18\t \x01(\tR\x0e\x61uthentication\x12#\n\rrequires_auth\x18\n \x01(\x08R\x0crequiresAuth\x12)\n\x10requires_profile\x18\x0b \x01(\x08R\x0frequiresProfileJ\x04\x08\x05\x10\x06J\x04\x08\x0c\x10\rR\x08tars_urlR\x08\x64isabled\".\n\x17GetCatalogServerRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"w\n\x19ListCatalogServersRequest\x12)\n\x10include_disabled\x18\x01 \x01(\x08R\x0fincludeDisabled\x12/\n\x04page\x18\x02 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x87\x01\n\x1aListCatalogServersResponse\x12\x37\n\x07servers\x18\x01 \x03(\x0b\x32\x1d.tars.mcp.v1.MCPCatalogServerR\x07servers\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"1\n\x1a\x44\x65leteCatalogServerRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"T\n\x1eSetCatalogServerEnabledRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x1d\n\x07\x65nabled\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02R\x07\x65nabled2\x9c\n\n\x12MCPProfilesService\x12\xf9\x01\n\x10\x43reateMCPProfile\x12$.tars.mcp.v1.CreateMCPProfileRequest\x1a\x17.tars.mcp.v1.MCPProfile\"\xa5\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x03mcp:\x08profiles:\x06\x63reate\xa2\xb5\x18\x15\x43reate an MCP profile\xaa\xb5\x18\x0cMCP Profiles\x82\xd3\xe4\x93\x02S\"N/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles:\x01*\x12\xfa\x01\n\rGetMCPProfile\x12!.tars.mcp.v1.GetMCPProfileRequest\x1a\x17.tars.mcp.v1.MCPProfile\"\xac\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x14:\x03mcp:\x08profiles:\x03get\xa2\xb5\x18\x12Get an MCP profile\xaa\xb5\x18\x0cMCP Profiles\x82\xd3\xe4\x93\x02]\x12[/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles/{profile_id}\x12\xfe\x01\n\x0fListMCPProfiles\x12#.tars.mcp.v1.ListMCPProfilesRequest\x1a$.tars.mcp.v1.ListMCPProfilesResponse\"\x9f\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x15:\x03mcp:\x08profiles:\x04list\xa2\xb5\x18\x11List MCP profiles\xaa\xb5\x18\x0cMCP Profiles\x82\xd3\xe4\x93\x02P\x12N/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles\x12\x86\x02\n\x10UpdateMCPProfile\x12$.tars.mcp.v1.UpdateMCPProfileRequest\x1a\x17.tars.mcp.v1.MCPProfile\"\xb2\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x03mcp:\x08profiles:\x06update\xa2\xb5\x18\x15Update an MCP profile\xaa\xb5\x18\x0cMCP Profiles\x82\xd3\xe4\x93\x02`2[/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles/{profile_id}:\x01*\x12\x82\x02\n\x10\x44\x65leteMCPProfile\x12$.tars.mcp.v1.DeleteMCPProfileRequest\x1a\x16.google.protobuf.Empty\"\xaf\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x03mcp:\x08profiles:\x06\x64\x65lete\xa2\xb5\x18\x15\x44\x65lete an MCP profile\xaa\xb5\x18\x0cMCP Profiles\x82\xd3\xe4\x93\x02]*[/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles/{profile_id}2\x8c\t\n\x11MCPCatalogService\x12\xe4\x01\n\x13UpsertCatalogServer\x12\'.tars.mcp.v1.UpsertCatalogServerRequest\x1a\x1d.tars.mcp.v1.MCPCatalogServer\"\x84\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x16:\x03mcp:\x07\x63\x61talog:\x06upsert\xa2\xb5\x18&Create or update an MCP catalog server\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/mcp/catalog/servers:\x01*\x12\xd6\x01\n\x10GetCatalogServer\x12$.tars.mcp.v1.GetCatalogServerRequest\x1a\x1d.tars.mcp.v1.MCPCatalogServer\"}\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x17\x1a\x02id:\x03mcp:\x07\x63\x61talog:\x03get\xa2\xb5\x18\x19Get an MCP catalog server\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/mcp/catalog/servers/{id}\x12\xdb\x01\n\x12ListCatalogServers\x12&.tars.mcp.v1.ListCatalogServersRequest\x1a\'.tars.mcp.v1.ListCatalogServersResponse\"t\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x14:\x03mcp:\x07\x63\x61talog:\x04list\xa2\xb5\x18\x18List MCP catalog servers\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/mcp/catalog/servers\x12\xfc\x01\n\x17SetCatalogServerEnabled\x12+.tars.mcp.v1.SetCatalogServerEnabledRequest\x1a\x1d.tars.mcp.v1.MCPCatalogServer\"\x94\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x1b:\x03mcp:\x07\x63\x61talog:\x0bset-enabled\xa2\xb5\x18$Toggle MCP catalog server visibility\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02)\"$/v1/mcp/catalog/servers/{id}/enabled:\x01*\x12\xd9\x01\n\x13\x44\x65leteCatalogServer\x12\'.tars.mcp.v1.DeleteCatalogServerRequest\x1a\x16.google.protobuf.Empty\"\x80\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x1a\x1a\x02id:\x03mcp:\x07\x63\x61talog:\x06\x64\x65lete\xa2\xb5\x18\x1c\x44\x65lete an MCP catalog server\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02\x1e*\x1c/v1/mcp/catalog/servers/{id}B\x9c\x01\n\x0f\x63om.tars.mcp.v1B\x08McpProtoP\x01Z1github.com/tetrateio/fraser/api/tars/mcp/v1;mcpv1\xa2\x02\x03TMX\xaa\x02\x0bTars.Mcp.V1\xca\x02\x0bTars\\Mcp\\V1\xe2\x02\x17Tars\\Mcp\\V1\\GPBMetadata\xea\x02\rTars::Mcp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.mcp.v1.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.mcp.v1B\010McpProtoP\001Z1github.com/tetrateio/fraser/api/tars/mcp/v1;mcpv1\242\002\003TMX\252\002\013Tars.Mcp.V1\312\002\013Tars\\Mcp\\V1\342\002\027Tars\\Mcp\\V1\\GPBMetadata\352\002\rTars::Mcp::V1'
  _globals['_MCPPROFILE'].fields_by_name['id']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_MCPPROFILE'].fields_by_name['name']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_MCPPROFILE'].fields_by_name['url']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['url']._serialized_options = b'\340A\003'
  _globals['_MCPPROFILE'].fields_by_name['status']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['status']._serialized_options = b'\340A\003'
  _globals['_MCPPROFILE'].fields_by_name['error_message']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['error_message']._serialized_options = b'\340A\003'
  _globals['_MCPPROFILE'].fields_by_name['security_policy_type']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['security_policy_type']._serialized_options = b'\340A\002'
  _globals['_MCPPROFILE'].fields_by_name['created_at']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_MCPPROFILE'].fields_by_name['updated_at']._loaded_options = None
  _globals['_MCPPROFILE'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_MCPCATALOGSERVER'].fields_by_name['id']._loaded_options = None
  _globals['_MCPCATALOGSERVER'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_MCPCATALOGSERVER'].fields_by_name['name']._loaded_options = None
  _globals['_MCPCATALOGSERVER'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_MCPCATALOGSERVER'].fields_by_name['url']._loaded_options = None
  _globals['_MCPCATALOGSERVER'].fields_by_name['url']._serialized_options = b'\340A\002'
  _globals['_MCPCATALOGSERVER'].fields_by_name['created_at']._loaded_options = None
  _globals['_MCPCATALOGSERVER'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_MCPCATALOGSERVER'].fields_by_name['updated_at']._loaded_options = None
  _globals['_MCPCATALOGSERVER'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_CREATEMCPPROFILEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEMCPPROFILEREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_CREATEMCPPROFILEREQUEST'].fields_by_name['security_policy_type']._loaded_options = None
  _globals['_CREATEMCPPROFILEREQUEST'].fields_by_name['security_policy_type']._serialized_options = b'\340A\002'
  _globals['_GETMCPPROFILEREQUEST'].fields_by_name['profile_id']._loaded_options = None
  _globals['_GETMCPPROFILEREQUEST'].fields_by_name['profile_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEMCPPROFILEREQUEST'].fields_by_name['profile_id']._loaded_options = None
  _globals['_UPDATEMCPPROFILEREQUEST'].fields_by_name['profile_id']._serialized_options = b'\340A\002'
  _globals['_DELETEMCPPROFILEREQUEST'].fields_by_name['profile_id']._loaded_options = None
  _globals['_DELETEMCPPROFILEREQUEST'].fields_by_name['profile_id']._serialized_options = b'\340A\002'
  _globals['_UPSERTCATALOGSERVERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPSERTCATALOGSERVERREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_UPSERTCATALOGSERVERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPSERTCATALOGSERVERREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_UPSERTCATALOGSERVERREQUEST'].fields_by_name['url']._loaded_options = None
  _globals['_UPSERTCATALOGSERVERREQUEST'].fields_by_name['url']._serialized_options = b'\340A\002\232\265\030\r\n\013catalog-url'
  _globals['_GETCATALOGSERVERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETCATALOGSERVERREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_DELETECATALOGSERVERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETECATALOGSERVERREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_SETCATALOGSERVERENABLEDREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_SETCATALOGSERVERENABLEDREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_SETCATALOGSERVERENABLEDREQUEST'].fields_by_name['enabled']._loaded_options = None
  _globals['_SETCATALOGSERVERENABLEDREQUEST'].fields_by_name['enabled']._serialized_options = b'\340A\002'
  _globals['_MCPPROFILESSERVICE'].methods_by_name['CreateMCPProfile']._loaded_options = None
  _globals['_MCPPROFILESSERVICE'].methods_by_name['CreateMCPProfile']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\003mcp:\010profiles:\006create\242\265\030\025Create an MCP profile\252\265\030\014MCP Profiles\202\323\344\223\002S\"N/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles:\001*'
  _globals['_MCPPROFILESSERVICE'].methods_by_name['GetMCPProfile']._loaded_options = None
  _globals['_MCPPROFILESSERVICE'].methods_by_name['GetMCPProfile']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\024:\003mcp:\010profiles:\003get\242\265\030\022Get an MCP profile\252\265\030\014MCP Profiles\202\323\344\223\002]\022[/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles/{profile_id}'
  _globals['_MCPPROFILESSERVICE'].methods_by_name['ListMCPProfiles']._loaded_options = None
  _globals['_MCPPROFILESSERVICE'].methods_by_name['ListMCPProfiles']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\025:\003mcp:\010profiles:\004list\242\265\030\021List MCP profiles\252\265\030\014MCP Profiles\202\323\344\223\002P\022N/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles'
  _globals['_MCPPROFILESSERVICE'].methods_by_name['UpdateMCPProfile']._loaded_options = None
  _globals['_MCPPROFILESSERVICE'].methods_by_name['UpdateMCPProfile']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\003mcp:\010profiles:\006update\242\265\030\025Update an MCP profile\252\265\030\014MCP Profiles\202\323\344\223\002`2[/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles/{profile_id}:\001*'
  _globals['_MCPPROFILESSERVICE'].methods_by_name['DeleteMCPProfile']._loaded_options = None
  _globals['_MCPPROFILESSERVICE'].methods_by_name['DeleteMCPProfile']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\003mcp:\010profiles:\006delete\242\265\030\025Delete an MCP profile\252\265\030\014MCP Profiles\202\323\344\223\002]*[/v1/customers/{customer_id}/projects/{project_id}/users/{user_id}/mcp-profiles/{profile_id}'
  _globals['_MCPCATALOGSERVICE'].methods_by_name['UpsertCatalogServer']._loaded_options = None
  _globals['_MCPCATALOGSERVICE'].methods_by_name['UpsertCatalogServer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\026:\003mcp:\007catalog:\006upsert\242\265\030&Create or update an MCP catalog server\252\265\030\013MCP Catalog\202\323\344\223\002\034\"\027/v1/mcp/catalog/servers:\001*'
  _globals['_MCPCATALOGSERVICE'].methods_by_name['GetCatalogServer']._loaded_options = None
  _globals['_MCPCATALOGSERVICE'].methods_by_name['GetCatalogServer']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\027\032\002id:\003mcp:\007catalog:\003get\242\265\030\031Get an MCP catalog server\252\265\030\013MCP Catalog\202\323\344\223\002\036\022\034/v1/mcp/catalog/servers/{id}'
  _globals['_MCPCATALOGSERVICE'].methods_by_name['ListCatalogServers']._loaded_options = None
  _globals['_MCPCATALOGSERVICE'].methods_by_name['ListCatalogServers']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\024:\003mcp:\007catalog:\004list\242\265\030\030List MCP catalog servers\252\265\030\013MCP Catalog\202\323\344\223\002\031\022\027/v1/mcp/catalog/servers'
  _globals['_MCPCATALOGSERVICE'].methods_by_name['SetCatalogServerEnabled']._loaded_options = None
  _globals['_MCPCATALOGSERVICE'].methods_by_name['SetCatalogServerEnabled']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\033:\003mcp:\007catalog:\013set-enabled\242\265\030$Toggle MCP catalog server visibility\252\265\030\013MCP Catalog\202\323\344\223\002)\"$/v1/mcp/catalog/servers/{id}/enabled:\001*'
  _globals['_MCPCATALOGSERVICE'].methods_by_name['DeleteCatalogServer']._loaded_options = None
  _globals['_MCPCATALOGSERVICE'].methods_by_name['DeleteCatalogServer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\032\032\002id:\003mcp:\007catalog:\006delete\242\265\030\034Delete an MCP catalog server\252\265\030\013MCP Catalog\202\323\344\223\002\036*\034/v1/mcp/catalog/servers/{id}'
  _globals['_MCPPROFILE']._serialized_start=273
  _globals['_MCPPROFILE']._serialized_end=783
  _globals['_MCPCATALOGSERVER']._serialized_start=786
  _globals['_MCPCATALOGSERVER']._serialized_end=1281
  _globals['_CREATEMCPPROFILEREQUEST']._serialized_start=1284
  _globals['_CREATEMCPPROFILEREQUEST']._serialized_end=1564
  _globals['_GETMCPPROFILEREQUEST']._serialized_start=1567
  _globals['_GETMCPPROFILEREQUEST']._serialized_end=1714
  _globals['_LISTMCPPROFILESREQUEST']._serialized_start=1717
  _globals['_LISTMCPPROFILESREQUEST']._serialized_end=1879
  _globals['_LISTMCPPROFILESRESPONSE']._serialized_start=1882
  _globals['_LISTMCPPROFILESRESPONSE']._serialized_end=2010
  _globals['_UPDATEMCPPROFILEREQUEST']._serialized_start=2013
  _globals['_UPDATEMCPPROFILEREQUEST']._serialized_end=2319
  _globals['_DELETEMCPPROFILEREQUEST']._serialized_start=2322
  _globals['_DELETEMCPPROFILEREQUEST']._serialized_end=2472
  _globals['_UPSERTCATALOGSERVERREQUEST']._serialized_start=2475
  _globals['_UPSERTCATALOGSERVERREQUEST']._serialized_end=2854
  _globals['_GETCATALOGSERVERREQUEST']._serialized_start=2856
  _globals['_GETCATALOGSERVERREQUEST']._serialized_end=2902
  _globals['_LISTCATALOGSERVERSREQUEST']._serialized_start=2904
  _globals['_LISTCATALOGSERVERSREQUEST']._serialized_end=3023
  _globals['_LISTCATALOGSERVERSRESPONSE']._serialized_start=3026
  _globals['_LISTCATALOGSERVERSRESPONSE']._serialized_end=3161
  _globals['_DELETECATALOGSERVERREQUEST']._serialized_start=3163
  _globals['_DELETECATALOGSERVERREQUEST']._serialized_end=3212
  _globals['_SETCATALOGSERVERENABLEDREQUEST']._serialized_start=3214
  _globals['_SETCATALOGSERVERENABLEDREQUEST']._serialized_end=3298
  _globals['_MCPPROFILESSERVICE']._serialized_start=3301
  _globals['_MCPPROFILESSERVICE']._serialized_end=4609
  _globals['_MCPCATALOGSERVICE']._serialized_start=4612
  _globals['_MCPCATALOGSERVICE']._serialized_end=5776
# @@protoc_insertion_point(module_scope)
