# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/auth/v1/auth.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/auth/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tars/auth/v1/auth.proto\x12\x0ctars.auth.v1\x1a\x1cgoogle/api/annotations.proto\"\x10\n\x0eGetJWKSRequest\"8\n\x0fGetJWKSResponse\x12%\n\x04keys\x18\x01 \x03(\x0b\x32\x11.tars.auth.v1.JWKR\x04keys\"{\n\x03JWK\x12\x10\n\x03kid\x18\x01 \x01(\tR\x03kid\x12\x10\n\x03kty\x18\x02 \x01(\tR\x03kty\x12\x10\n\x03\x61lg\x18\x03 \x01(\tR\x03\x61lg\x12\x10\n\x03use\x18\x04 \x01(\tR\x03use\x12\x10\n\x03\x63rv\x18\x05 \x01(\tR\x03\x63rv\x12\x0c\n\x01x\x18\x06 \x01(\tR\x01x\x12\x0c\n\x01y\x18\x07 \x01(\tR\x01y2x\n\x0b\x41uthService\x12i\n\x07GetJWKS\x12\x1c.tars.auth.v1.GetJWKSRequest\x1a\x1d.tars.auth.v1.GetJWKSResponse\"!\x90\x02\x01\x82\xd3\xe4\x93\x02\x18\x12\x16/.well-known/jwks.jsonBo\n\x10\x63om.tars.auth.v1B\tAuthProtoP\x01\xa2\x02\x03TAX\xaa\x02\x0cTars.Auth.V1\xca\x02\x0cTars\\Auth\\V1\xe2\x02\x18Tars\\Auth\\V1\\GPBMetadata\xea\x02\x0eTars::Auth::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.auth.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.tars.auth.v1B\tAuthProtoP\001\242\002\003TAX\252\002\014Tars.Auth.V1\312\002\014Tars\\Auth\\V1\342\002\030Tars\\Auth\\V1\\GPBMetadata\352\002\016Tars::Auth::V1'
  _globals['_AUTHSERVICE'].methods_by_name['GetJWKS']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['GetJWKS']._serialized_options = b'\220\002\001\202\323\344\223\002\030\022\026/.well-known/jwks.json'
  _globals['_GETJWKSREQUEST']._serialized_start=71
  _globals['_GETJWKSREQUEST']._serialized_end=87
  _globals['_GETJWKSRESPONSE']._serialized_start=89
  _globals['_GETJWKSRESPONSE']._serialized_end=145
  _globals['_JWK']._serialized_start=147
  _globals['_JWK']._serialized_end=270
  _globals['_AUTHSERVICE']._serialized_start=272
  _globals['_AUTHSERVICE']._serialized_end=392
# @@protoc_insertion_point(module_scope)
