# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/aikeys/v1/aikeys.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/aikeys/v1/aikeys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btars/aikeys/v1/aikeys.proto\x12\x0etars.aikeys.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\x97\x04\n\x05\x41iKey\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\x12\x39\n\x08provider\x18\x04 \x01(\x0e\x32\x18.tars.aikeys.v1.ProviderB\x03\xe0\x41\x02R\x08provider\x12\x17\n\x04name\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x04name\x12*\n\x0e\x64isplay_suffix\x18\x06 \x01(\tB\x03\xe0\x41\x03R\rdisplaySuffix\x12\"\n\nuser_scope\x18\x07 \x01(\x08\x42\x03\xe0\x41\x03R\tuserScope\x12\'\n\rscope_user_id\x18\x08 \x01(\tB\x03\xe0\x41\x03R\x0bscopeUserId\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\x12>\n\nrevoked_at\x18\x34 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\trevokedAt\x12\"\n\nsecret_ref\x18< \x01(\tB\x03\xe0\x41\x03R\tsecretRef\"\x9b\x02\n\x0fRegisterRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x39\n\x08provider\x18\x03 \x01(\x0e\x32\x18.tars.aikeys.v1.ProviderB\x03\xe0\x41\x02R\x08provider\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04name\x12$\n\x06secret\x18\x05 \x01(\tB\x0c\xe0\x41\x02\x9a\xb5\x18\x05\n\x03keyR\x06secret\x12/\n\nuser_scope\x18\x06 \x01(\x08\x42\x10\x9a\xb5\x18\x0c\n\nuser-scopeR\tuserScope\";\n\x10RegisterResponse\x12\'\n\x03key\x18\x01 \x01(\x0b\x32\x15.tars.aikeys.v1.AiKeyR\x03key\"\x80\x01\n\nGetRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x02id\"6\n\x0bGetResponse\x12\'\n\x03key\x18\x01 \x01(\x0b\x32\x15.tars.aikeys.v1.AiKeyR\x03key\"l\n\x0bListRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\"9\n\x0cListResponse\x12)\n\x04keys\x18\x01 \x03(\x0b\x32\x15.tars.aikeys.v1.AiKeyR\x04keys\"\x83\x01\n\rRevokeRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x10\n\x0eRevokeResponse\"#\n\x0c\x46\x65tchRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x93\x01\n\rFetchResponse\x12\x39\n\x08provider\x18\x01 \x01(\x0e\x32\x18.tars.aikeys.v1.ProviderB\x03\xe0\x41\x03R\x08provider\x12\x1b\n\x06secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x06secret\x12*\n\x0e\x64isplay_suffix\x18\x03 \x01(\tB\x03\xe0\x41\x03R\rdisplaySuffix*\xa2\x01\n\x08Provider\x12\x18\n\x14PROVIDER_UNSPECIFIED\x10\x00\x12\x13\n\x0fPROVIDER_OPENAI\x10\x01\x12\x16\n\x12PROVIDER_ANTHROPIC\x10\x02\x12\x19\n\x15PROVIDER_AZURE_OPENAI\x10\x03\x12\x1a\n\x16PROVIDER_GOOGLE_VERTEX\x10\x04\x12\x18\n\x14PROVIDER_AWS_BEDROCK\x10\x05\x32\x8b\x07\n\rAiKeysService\x12\xca\x01\n\x08Register\x12\x1f.tars.aikeys.v1.RegisterRequest\x1a .tars.aikeys.v1.RegisterResponse\"{\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0b:\x04\x62yok:\x03\x61\x64\x64\xa2\xb5\x18\x12Register an AI key\xaa\xb5\x18\x07\x41I Keys\x82\xd3\xe4\x93\x02=\"8/v1/customers/{customer_id}/projects/{project_id}/aikeys:\x01*\x12\xbf\x01\n\x03Get\x12\x1a.tars.aikeys.v1.GetRequest\x1a\x1b.tars.aikeys.v1.GetResponse\"\x7f\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0f\x1a\x02id:\x04\x62yok:\x03get\xa2\xb5\x18\rGet an AI key\xaa\xb5\x18\x07\x41I Keys\x82\xd3\xe4\x93\x02?\x12=/v1/customers/{customer_id}/projects/{project_id}/aikeys/{id}\x12\xb9\x01\n\x04List\x12\x1b.tars.aikeys.v1.ListRequest\x1a\x1c.tars.aikeys.v1.ListResponse\"v\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0c:\x04\x62yok:\x04list\xa2\xb5\x18\x0cList AI keys\xaa\xb5\x18\x07\x41I Keys\x82\xd3\xe4\x93\x02:\x12\x38/v1/customers/{customer_id}/projects/{project_id}/aikeys\x12\xcc\x01\n\x06Revoke\x12\x1d.tars.aikeys.v1.RevokeRequest\x1a\x1e.tars.aikeys.v1.RevokeResponse\"\x82\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x12\x1a\x02id:\x04\x62yok:\x06remove\xa2\xb5\x18\x10Revoke an AI key\xaa\xb5\x18\x07\x41I Keys\x82\xd3\xe4\x93\x02?*=/v1/customers/{customer_id}/projects/{project_id}/aikeys/{id}\x12`\n\x05\x46\x65tch\x12\x1c.tars.aikeys.v1.FetchRequest\x1a\x1d.tars.aikeys.v1.FetchResponse\"\x1a\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x02(\x01\x42\xb4\x01\n\x12\x63om.tars.aikeys.v1B\x0b\x41ikeysProtoP\x01Z7github.com/tetrateio/fraser/api/tars/aikeys/v1;aikeysv1\xa2\x02\x03TAX\xaa\x02\x0eTars.Aikeys.V1\xca\x02\x0eTars\\Aikeys\\V1\xe2\x02\x1aTars\\Aikeys\\V1\\GPBMetadata\xea\x02\x10Tars::Aikeys::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.aikeys.v1.aikeys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.aikeys.v1B\013AikeysProtoP\001Z7github.com/tetrateio/fraser/api/tars/aikeys/v1;aikeysv1\242\002\003TAX\252\002\016Tars.Aikeys.V1\312\002\016Tars\\Aikeys\\V1\342\002\032Tars\\Aikeys\\V1\\GPBMetadata\352\002\020Tars::Aikeys::V1'
  _globals['_AIKEY'].fields_by_name['id']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['customer_id']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['project_id']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['project_id']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['provider']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['provider']._serialized_options = b'\340A\002'
  _globals['_AIKEY'].fields_by_name['name']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_AIKEY'].fields_by_name['display_suffix']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['display_suffix']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['user_scope']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['user_scope']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['scope_user_id']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['scope_user_id']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['created_at']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['updated_at']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['revoked_at']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['revoked_at']._serialized_options = b'\340A\003'
  _globals['_AIKEY'].fields_by_name['secret_ref']._loaded_options = None
  _globals['_AIKEY'].fields_by_name['secret_ref']._serialized_options = b'\340A\003'
  _globals['_REGISTERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_REGISTERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_REGISTERREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['provider']._serialized_options = b'\340A\002'
  _globals['_REGISTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_REGISTERREQUEST'].fields_by_name['secret']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['secret']._serialized_options = b'\340A\002\232\265\030\005\n\003key'
  _globals['_REGISTERREQUEST'].fields_by_name['user_scope']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['user_scope']._serialized_options = b'\232\265\030\014\n\nuser-scope'
  _globals['_GETREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_GETREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_GETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_LISTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_LISTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_REVOKEREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REVOKEREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_REVOKEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REVOKEREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_REVOKEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_REVOKEREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_FETCHREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_FETCHREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_FETCHRESPONSE'].fields_by_name['provider']._loaded_options = None
  _globals['_FETCHRESPONSE'].fields_by_name['provider']._serialized_options = b'\340A\003'
  _globals['_FETCHRESPONSE'].fields_by_name['secret']._loaded_options = None
  _globals['_FETCHRESPONSE'].fields_by_name['secret']._serialized_options = b'\340A\003'
  _globals['_FETCHRESPONSE'].fields_by_name['display_suffix']._loaded_options = None
  _globals['_FETCHRESPONSE'].fields_by_name['display_suffix']._serialized_options = b'\340A\003'
  _globals['_AIKEYSSERVICE'].methods_by_name['Register']._loaded_options = None
  _globals['_AIKEYSSERVICE'].methods_by_name['Register']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\013:\004byok:\003add\242\265\030\022Register an AI key\252\265\030\007AI Keys\202\323\344\223\002=\"8/v1/customers/{customer_id}/projects/{project_id}/aikeys:\001*'
  _globals['_AIKEYSSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_AIKEYSSERVICE'].methods_by_name['Get']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\017\032\002id:\004byok:\003get\242\265\030\rGet an AI key\252\265\030\007AI Keys\202\323\344\223\002?\022=/v1/customers/{customer_id}/projects/{project_id}/aikeys/{id}'
  _globals['_AIKEYSSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_AIKEYSSERVICE'].methods_by_name['List']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\014:\004byok:\004list\242\265\030\014List AI keys\252\265\030\007AI Keys\202\323\344\223\002:\0228/v1/customers/{customer_id}/projects/{project_id}/aikeys'
  _globals['_AIKEYSSERVICE'].methods_by_name['Revoke']._loaded_options = None
  _globals['_AIKEYSSERVICE'].methods_by_name['Revoke']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\022\032\002id:\004byok:\006remove\242\265\030\020Revoke an AI key\252\265\030\007AI Keys\202\323\344\223\002?*=/v1/customers/{customer_id}/projects/{project_id}/aikeys/{id}'
  _globals['_AIKEYSSERVICE'].methods_by_name['Fetch']._loaded_options = None
  _globals['_AIKEYSSERVICE'].methods_by_name['Fetch']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal\222\265\030\002(\001'
  _globals['_PROVIDER']._serialized_start=1805
  _globals['_PROVIDER']._serialized_end=1967
  _globals['_AIKEY']._serialized_start=225
  _globals['_AIKEY']._serialized_end=760
  _globals['_REGISTERREQUEST']._serialized_start=763
  _globals['_REGISTERREQUEST']._serialized_end=1046
  _globals['_REGISTERRESPONSE']._serialized_start=1048
  _globals['_REGISTERRESPONSE']._serialized_end=1107
  _globals['_GETREQUEST']._serialized_start=1110
  _globals['_GETREQUEST']._serialized_end=1238
  _globals['_GETRESPONSE']._serialized_start=1240
  _globals['_GETRESPONSE']._serialized_end=1294
  _globals['_LISTREQUEST']._serialized_start=1296
  _globals['_LISTREQUEST']._serialized_end=1404
  _globals['_LISTRESPONSE']._serialized_start=1406
  _globals['_LISTRESPONSE']._serialized_end=1463
  _globals['_REVOKEREQUEST']._serialized_start=1466
  _globals['_REVOKEREQUEST']._serialized_end=1597
  _globals['_REVOKERESPONSE']._serialized_start=1599
  _globals['_REVOKERESPONSE']._serialized_end=1615
  _globals['_FETCHREQUEST']._serialized_start=1617
  _globals['_FETCHREQUEST']._serialized_end=1652
  _globals['_FETCHRESPONSE']._serialized_start=1655
  _globals['_FETCHRESPONSE']._serialized_end=1802
  _globals['_AIKEYSSERVICE']._serialized_start=1970
  _globals['_AIKEYSSERVICE']._serialized_end=2877
# @@protoc_insertion_point(module_scope)
