# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/test/v1/test.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/test/v1/test.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tars/test/v1/test.proto\x12\x0ctars.test.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\"\r\n\x0bPingRequest\"\x82\x04\n\x0cPingResponse\x12$\n\rauthenticated\x18\x01 \x01(\x08R\rauthenticated\x12!\n\x0c\x63lient_email\x18\x02 \x01(\tR\x0b\x63lientEmail\x12\x16\n\x06issuer\x18\x03 \x01(\tR\x06issuer\x12\x1a\n\x08\x61udience\x18\x04 \x01(\tR\x08\x61udience\x12\x18\n\x07subject\x18\x05 \x01(\tR\x07subject\x12\x16\n\x06scopes\x18\x06 \x03(\tR\x06scopes\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x37\n\tissued_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08issuedAt\x12;\n\x0bserver_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nserverTime\x12Q\n\rcustom_claims\x18\n \x03(\x0b\x32,.tars.test.v1.PingResponse.CustomClaimsEntryR\x0c\x63ustomClaims\x1a?\n\x11\x43ustomClaimsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x32s\n\x0bTestService\x12\x64\n\x04Ping\x12\x19.tars.test.v1.PingRequest\x1a\x1a.tars.test.v1.PingResponse\"%\x90\x02\x01\x8a\xb5\x18\t\n\x01\x02\x12\x04read\x82\xd3\xe4\x93\x02\x0f\x12\r/test/v1/pingBo\n\x10\x63om.tars.test.v1B\tTestProtoP\x01\xa2\x02\x03TTX\xaa\x02\x0cTars.Test.V1\xca\x02\x0cTars\\Test\\V1\xe2\x02\x18Tars\\Test\\V1\\GPBMetadata\xea\x02\x0eTars::Test::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.test.v1.test_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.tars.test.v1B\tTestProtoP\001\242\002\003TTX\252\002\014Tars.Test.V1\312\002\014Tars\\Test\\V1\342\002\030Tars\\Test\\V1\\GPBMetadata\352\002\016Tars::Test::V1'
  _globals['_PINGRESPONSE_CUSTOMCLAIMSENTRY']._loaded_options = None
  _globals['_PINGRESPONSE_CUSTOMCLAIMSENTRY']._serialized_options = b'8\001'
  _globals['_TESTSERVICE'].methods_by_name['Ping']._loaded_options = None
  _globals['_TESTSERVICE'].methods_by_name['Ping']._serialized_options = b'\220\002\001\212\265\030\t\n\001\002\022\004read\202\323\344\223\002\017\022\r/test/v1/ping'
  _globals['_PINGREQUEST']._serialized_start=137
  _globals['_PINGREQUEST']._serialized_end=150
  _globals['_PINGRESPONSE']._serialized_start=153
  _globals['_PINGRESPONSE']._serialized_end=667
  _globals['_PINGRESPONSE_CUSTOMCLAIMSENTRY']._serialized_start=604
  _globals['_PINGRESPONSE_CUSTOMCLAIMSENTRY']._serialized_end=667
  _globals['_TESTSERVICE']._serialized_start=669
  _globals['_TESTSERVICE']._serialized_end=784
# @@protoc_insertion_point(module_scope)
