# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/tokens/v1/tokens.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/tokens/v1/tokens.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btars/tokens/v1/tokens.proto\x12\x0etars.tokens.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\"\x80\x01\n\x18GetRevocationListRequest\x12\x35\n\x05since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x05since\x88\x01\x01\x12\x19\n\x05limit\x18\x02 \x01(\x05H\x01R\x05limit\x88\x01\x01\x42\x08\n\x06_sinceB\x08\n\x06_limit\"\xbd\x01\n\x19GetRevocationListResponse\x12\x42\n\x0brevocations\x18\x01 \x03(\x0b\x32 .tars.tokens.v1.RevokedTokenInfoR\x0brevocations\x12;\n\x0bsnapshot_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nsnapshotAt\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x03R\ntotalCount\"\x87\x01\n\x10RevokedTokenInfo\x12\x10\n\x03jti\x18\x01 \x01(\tR\x03jti\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\x12\x1b\n\x06reason\x18\x03 \x01(\tH\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"o\n\x15UpdateLastUsedRequest\x12\x10\n\x03jti\x18\x01 \x01(\tR\x03jti\x12\x38\n\x07used_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x06usedAt\x88\x01\x01\x42\n\n\x08_used_at\"o\n\x16UpdateLastUsedResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12;\n\x0brecorded_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordedAt2\xbc\x02\n\rTokensService\x12\x9d\x01\n\x11GetRevocationList\x12(.tars.tokens.v1.GetRevocationListRequest\x1a).tars.tokens.v1.GetRevocationListResponse\"3\x8a\xb5\x18\x11\n\x02\x02\x01\x12\x04read\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/tokens/revocations\x12\x8a\x01\n\x0eUpdateLastUsed\x12%.tars.tokens.v1.UpdateLastUsedRequest\x1a&.tars.tokens.v1.UpdateLastUsedResponse\")\x8a\xb5\x18\n\n\x01\x02\x12\x05write\x82\xd3\xe4\x93\x02\x15\"\x10/v1/tokens/usage:\x01*B\xb4\x01\n\x12\x63om.tars.tokens.v1B\x0bTokensProtoP\x01Z7github.com/tetrateio/fraser/api/tars/tokens/v1;tokensv1\xa2\x02\x03TTX\xaa\x02\x0eTars.Tokens.V1\xca\x02\x0eTars\\Tokens\\V1\xe2\x02\x1aTars\\Tokens\\V1\\GPBMetadata\xea\x02\x10Tars::Tokens::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.tokens.v1.tokens_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.tokens.v1B\013TokensProtoP\001Z7github.com/tetrateio/fraser/api/tars/tokens/v1;tokensv1\242\002\003TTX\252\002\016Tars.Tokens.V1\312\002\016Tars\\Tokens\\V1\342\002\032Tars\\Tokens\\V1\\GPBMetadata\352\002\020Tars::Tokens::V1'
  _globals['_TOKENSSERVICE'].methods_by_name['GetRevocationList']._loaded_options = None
  _globals['_TOKENSSERVICE'].methods_by_name['GetRevocationList']._serialized_options = b'\212\265\030\021\n\002\002\001\022\004read\022\005admin\202\323\344\223\002\030\022\026/v1/tokens/revocations'
  _globals['_TOKENSSERVICE'].methods_by_name['UpdateLastUsed']._loaded_options = None
  _globals['_TOKENSSERVICE'].methods_by_name['UpdateLastUsed']._serialized_options = b'\212\265\030\n\n\001\002\022\005write\202\323\344\223\002\025\"\020/v1/tokens/usage:\001*'
  _globals['_GETREVOCATIONLISTREQUEST']._serialized_start=144
  _globals['_GETREVOCATIONLISTREQUEST']._serialized_end=272
  _globals['_GETREVOCATIONLISTRESPONSE']._serialized_start=275
  _globals['_GETREVOCATIONLISTRESPONSE']._serialized_end=464
  _globals['_REVOKEDTOKENINFO']._serialized_start=467
  _globals['_REVOKEDTOKENINFO']._serialized_end=602
  _globals['_UPDATELASTUSEDREQUEST']._serialized_start=604
  _globals['_UPDATELASTUSEDREQUEST']._serialized_end=715
  _globals['_UPDATELASTUSEDRESPONSE']._serialized_start=717
  _globals['_UPDATELASTUSEDRESPONSE']._serialized_end=828
  _globals['_TOKENSSERVICE']._serialized_start=831
  _globals['_TOKENSSERVICE']._serialized_end=1147
# @@protoc_insertion_point(module_scope)
