# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/mcp/v1/mcp_oauth_clients.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/mcp/v1/mcp_oauth_clients.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#tars/mcp/v1/mcp_oauth_clients.proto\x12\x0btars.mcp.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\"\xa8\x05\n\x0eMcpOAuthClient\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\x12\x1f\n\x08provider\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x08provider\x12(\n\rprovider_name\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0cproviderName\x12 \n\tclient_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12\x30\n\x11\x61uthorization_url\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x10\x61uthorizationUrl\x12 \n\ttoken_url\x18\x08 \x01(\tB\x03\xe0\x41\x02R\x08tokenUrl\x12\x16\n\x06scopes\x18\t \x03(\tR\x06scopes\x12#\n\rredirect_uris\x18\n \x03(\tR\x0credirectUris\x12\x45\n\x08metadata\x18\x0b \x03(\x0b\x32).tars.mcp.v1.McpOAuthClient.MetadataEntryR\x08metadata\x12\x1d\n\nserver_ids\x18\x0c \x03(\tR\tserverIds\x12\x16\n\x06status\x18\r \x01(\tR\x06status\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe0\x04\n\x1b\x43reateMcpOAuthClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1f\n\x08provider\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08provider\x12(\n\rprovider_name\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0cproviderName\x12 \n\tclient_id\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12;\n\rclient_secret\x18\x06 \x01(\tB\x16\xe0\x41\x02\x9a\xb5\x18\x0f\n\rclient-secretR\x0c\x63lientSecret\x12\x30\n\x11\x61uthorization_url\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x10\x61uthorizationUrl\x12 \n\ttoken_url\x18\x08 \x01(\tB\x03\xe0\x41\x02R\x08tokenUrl\x12\x16\n\x06scopes\x18\t \x03(\tR\x06scopes\x12#\n\rredirect_uris\x18\n \x03(\tR\x0credirectUris\x12R\n\x08metadata\x18\x0b \x03(\x0b\x32\x36.tars.mcp.v1.CreateMcpOAuthClientRequest.MetadataEntryR\x08metadata\x12\x1d\n\nserver_ids\x18\x0c \x03(\tR\tserverIds\x12\x16\n\x06status\x18\r \x01(\tR\x06status\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"o\n\x18GetMcpOAuthClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x8d\x01\n\x1aListMcpOAuthClientsRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12/\n\x04page\x18\x03 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x86\x01\n\x1bListMcpOAuthClientsResponse\x12\x35\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x1b.tars.mcp.v1.McpOAuthClientR\x07\x63lients\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\xf1\x05\n\x1bUpdateMcpOAuthClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x02id\x12#\n\rprovider_name\x18\x04 \x01(\tR\x0cproviderName\x12\x1b\n\tclient_id\x18\x05 \x01(\tR\x08\x63lientId\x12\x38\n\rclient_secret\x18\x06 \x01(\tB\x13\x9a\xb5\x18\x0f\n\rclient-secretR\x0c\x63lientSecret\x12+\n\x11\x61uthorization_url\x18\x07 \x01(\tR\x10\x61uthorizationUrl\x12\x1b\n\ttoken_url\x18\x08 \x01(\tR\x08tokenUrl\x12\x16\n\x06status\x18\t \x01(\tR\x06status\x12\x16\n\x06scopes\x18\n \x03(\tR\x06scopes\x12#\n\rredirect_uris\x18\x0b \x03(\tR\x0credirectUris\x12R\n\x08metadata\x18\x0c \x03(\x0b\x32\x36.tars.mcp.v1.UpdateMcpOAuthClientRequest.MetadataEntryR\x08metadata\x12\x1d\n\nserver_ids\x18\r \x03(\tR\tserverIds\x12%\n\x0ereplace_scopes\x18\x14 \x01(\x08R\rreplaceScopes\x12\x32\n\x15replace_redirect_uris\x18\x15 \x01(\x08R\x13replaceRedirectUris\x12)\n\x10replace_metadata\x18\x16 \x01(\x08R\x0freplaceMetadata\x12,\n\x12replace_server_ids\x18\x17 \x01(\x08R\x10replaceServerIds\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"r\n\x1b\x44\x65leteMcpOAuthClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x02id2\xf5\n\n\x16McpOAuthClientsService\x12\x94\x02\n\x14\x43reateMcpOAuthClient\x12(.tars.mcp.v1.CreateMcpOAuthClientRequest\x1a\x1b.tars.mcp.v1.McpOAuthClient\"\xb4\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x1c:\x03mcp:\roauth-clients:\x06\x63reate\xa2\xb5\x18\x1a\x43reate an MCP OAuth client\xaa\xb5\x18\rOAuth Clients\x82\xd3\xe4\x93\x02H\"C/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients:\x01*\x12\x82\x02\n\x11GetMcpOAuthClient\x12%.tars.mcp.v1.GetMcpOAuthClientRequest\x1a\x1b.tars.mcp.v1.McpOAuthClient\"\xa8\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x1d\x1a\x02id:\x03mcp:\roauth-clients:\x03get\xa2\xb5\x18\x17Get an MCP OAuth client\xaa\xb5\x18\rOAuth Clients\x82\xd3\xe4\x93\x02J\x12H/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients/{id}\x12\x8a\x02\n\x13ListMcpOAuthClients\x12\'.tars.mcp.v1.ListMcpOAuthClientsRequest\x1a(.tars.mcp.v1.ListMcpOAuthClientsResponse\"\x9f\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x1a:\x03mcp:\roauth-clients:\x04list\xa2\xb5\x18\x16List MCP OAuth clients\xaa\xb5\x18\rOAuth Clients\x82\xd3\xe4\x93\x02\x45\x12\x43/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients\x12\x99\x02\n\x14UpdateMcpOAuthClient\x12(.tars.mcp.v1.UpdateMcpOAuthClientRequest\x1a\x1b.tars.mcp.v1.McpOAuthClient\"\xb9\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x1c:\x03mcp:\roauth-clients:\x06update\xa2\xb5\x18\x1aUpdate an MCP OAuth client\xaa\xb5\x18\rOAuth Clients\x82\xd3\xe4\x93\x02M2H/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients/{id}:\x01*\x12\x95\x02\n\x14\x44\x65leteMcpOAuthClient\x12(.tars.mcp.v1.DeleteMcpOAuthClientRequest\x1a\x16.google.protobuf.Empty\"\xba\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18 \x1a\x02id:\x03mcp:\roauth-clients:\x06\x64\x65lete\xa2\xb5\x18\x1a\x44\x65lete an MCP OAuth client\xaa\xb5\x18\rOAuth Clients\x82\xd3\xe4\x93\x02J*H/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients/{id}B\xa8\x01\n\x0f\x63om.tars.mcp.v1B\x14McpOauthClientsProtoP\x01Z1github.com/tetrateio/fraser/api/tars/mcp/v1;mcpv1\xa2\x02\x03TMX\xaa\x02\x0bTars.Mcp.V1\xca\x02\x0bTars\\Mcp\\V1\xe2\x02\x17Tars\\Mcp\\V1\\GPBMetadata\xea\x02\rTars::Mcp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.mcp.v1.mcp_oauth_clients_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.mcp.v1B\024McpOauthClientsProtoP\001Z1github.com/tetrateio/fraser/api/tars/mcp/v1;mcpv1\242\002\003TMX\252\002\013Tars.Mcp.V1\312\002\013Tars\\Mcp\\V1\342\002\027Tars\\Mcp\\V1\\GPBMetadata\352\002\rTars::Mcp::V1'
  _globals['_MCPOAUTHCLIENT_METADATAENTRY']._loaded_options = None
  _globals['_MCPOAUTHCLIENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['id']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['customer_id']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['project_id']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['project_id']._serialized_options = b'\340A\003'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['provider']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['provider']._serialized_options = b'\340A\002'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['provider_name']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['provider_name']._serialized_options = b'\340A\002'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['client_id']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['authorization_url']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['authorization_url']._serialized_options = b'\340A\002'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['token_url']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['token_url']._serialized_options = b'\340A\002'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['created_at']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_MCPOAUTHCLIENT'].fields_by_name['updated_at']._loaded_options = None
  _globals['_MCPOAUTHCLIENT'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['provider']._serialized_options = b'\340A\002'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['provider_name']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['provider_name']._serialized_options = b'\340A\002'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['client_secret']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['client_secret']._serialized_options = b'\340A\002\232\265\030\017\n\rclient-secret'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['authorization_url']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['authorization_url']._serialized_options = b'\340A\002'
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['token_url']._loaded_options = None
  _globals['_CREATEMCPOAUTHCLIENTREQUEST'].fields_by_name['token_url']._serialized_options = b'\340A\002'
  _globals['_GETMCPOAUTHCLIENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETMCPOAUTHCLIENTREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST'].fields_by_name['client_secret']._loaded_options = None
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST'].fields_by_name['client_secret']._serialized_options = b'\232\265\030\017\n\rclient-secret'
  _globals['_DELETEMCPOAUTHCLIENTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEMCPOAUTHCLIENTREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['CreateMcpOAuthClient']._loaded_options = None
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['CreateMcpOAuthClient']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\034:\003mcp:\roauth-clients:\006create\242\265\030\032Create an MCP OAuth client\252\265\030\rOAuth Clients\202\323\344\223\002H\"C/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients:\001*'
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['GetMcpOAuthClient']._loaded_options = None
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['GetMcpOAuthClient']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\035\032\002id:\003mcp:\roauth-clients:\003get\242\265\030\027Get an MCP OAuth client\252\265\030\rOAuth Clients\202\323\344\223\002J\022H/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients/{id}'
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['ListMcpOAuthClients']._loaded_options = None
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['ListMcpOAuthClients']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\032:\003mcp:\roauth-clients:\004list\242\265\030\026List MCP OAuth clients\252\265\030\rOAuth Clients\202\323\344\223\002E\022C/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients'
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['UpdateMcpOAuthClient']._loaded_options = None
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['UpdateMcpOAuthClient']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\034:\003mcp:\roauth-clients:\006update\242\265\030\032Update an MCP OAuth client\252\265\030\rOAuth Clients\202\323\344\223\002M2H/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients/{id}:\001*'
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['DeleteMcpOAuthClient']._loaded_options = None
  _globals['_MCPOAUTHCLIENTSSERVICE'].methods_by_name['DeleteMcpOAuthClient']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030 \032\002id:\003mcp:\roauth-clients:\006delete\242\265\030\032Delete an MCP OAuth client\252\265\030\rOAuth Clients\202\323\344\223\002J*H/v1/customers/{customer_id}/projects/{project_id}/mcp-oauth-clients/{id}'
  _globals['_MCPOAUTHCLIENT']._serialized_start=287
  _globals['_MCPOAUTHCLIENT']._serialized_end=967
  _globals['_MCPOAUTHCLIENT_METADATAENTRY']._serialized_start=908
  _globals['_MCPOAUTHCLIENT_METADATAENTRY']._serialized_end=967
  _globals['_CREATEMCPOAUTHCLIENTREQUEST']._serialized_start=970
  _globals['_CREATEMCPOAUTHCLIENTREQUEST']._serialized_end=1578
  _globals['_CREATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._serialized_start=908
  _globals['_CREATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._serialized_end=967
  _globals['_GETMCPOAUTHCLIENTREQUEST']._serialized_start=1580
  _globals['_GETMCPOAUTHCLIENTREQUEST']._serialized_end=1691
  _globals['_LISTMCPOAUTHCLIENTSREQUEST']._serialized_start=1694
  _globals['_LISTMCPOAUTHCLIENTSREQUEST']._serialized_end=1835
  _globals['_LISTMCPOAUTHCLIENTSRESPONSE']._serialized_start=1838
  _globals['_LISTMCPOAUTHCLIENTSRESPONSE']._serialized_end=1972
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST']._serialized_start=1975
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST']._serialized_end=2728
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._serialized_start=908
  _globals['_UPDATEMCPOAUTHCLIENTREQUEST_METADATAENTRY']._serialized_end=967
  _globals['_DELETEMCPOAUTHCLIENTREQUEST']._serialized_start=2730
  _globals['_DELETEMCPOAUTHCLIENTREQUEST']._serialized_end=2844
  _globals['_MCPOAUTHCLIENTSSERVICE']._serialized_start=2847
  _globals['_MCPOAUTHCLIENTSSERVICE']._serialized_end=4244
# @@protoc_insertion_point(module_scope)
