# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/catalog/v1/catalog.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/catalog/v1/catalog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtars/catalog/v1/catalog.proto\x12\x0ftars.catalog.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\"\xe8\x02\n\x08Provider\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12&\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0b\x64isplayName\x12\x1e\n\x08\x62\x61se_url\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x62\x61seUrl\x12\x34\n\x16supported_auth_schemes\x18\x05 \x03(\tR\x14supportedAuthSchemes\x12\x30\n\x11\x63redential_suffix\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x10\x63redentialSuffix\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\"\xc9\x01\n\x07Pricing\x12*\n\x11input_per_million\x18\x01 \x01(\tR\x0finputPerMillion\x12,\n\x12output_per_million\x18\x02 \x01(\tR\x10outputPerMillion\x12\x33\n\x16\x63\x61\x63he_read_per_million\x18\x03 \x01(\tR\x13\x63\x61\x63heReadPerMillion\x12/\n\x14max_cost_per_request\x18\x04 \x01(\tR\x11maxCostPerRequest\"\x8d\x03\n\x05Model\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0bprovider_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\nproviderId\x12\x17\n\x04name\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x04name\x12*\n\x0eupstream_model\x18\x04 \x01(\tB\x03\xe0\x41\x02R\rupstreamModel\x12\x32\n\x07pricing\x18\x05 \x01(\x0b\x32\x18.tars.catalog.v1.PricingR\x07pricing\x12,\n\x12max_context_tokens\x18\x06 \x01(\rR\x10maxContextTokens\x12\"\n\x0c\x63\x61pabilities\x18\x07 \x03(\tR\x0c\x63\x61pabilities\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\"G\n\x14ListProvidersRequest\x12/\n\x04page\x18\x01 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x82\x01\n\x15ListProvidersResponse\x12\x37\n\tproviders\x18\x01 \x03(\x0b\x32\x19.tars.catalog.v1.ProviderR\tproviders\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\")\n\x12GetProviderRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"L\n\x13GetProviderResponse\x12\x35\n\x08provider\x18\x01 \x01(\x0b\x32\x19.tars.catalog.v1.ProviderR\x08provider\"e\n\x11ListModelsRequest\x12\x1f\n\x0bprovider_id\x18\x01 \x01(\tR\nproviderId\x12/\n\x04page\x18\x02 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"v\n\x12ListModelsResponse\x12.\n\x06models\x18\x01 \x03(\x0b\x32\x16.tars.catalog.v1.ModelR\x06models\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"&\n\x0fGetModelRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"@\n\x10GetModelResponse\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x16.tars.catalog.v1.ModelR\x05model\"\xf1\x01\n\x11ProjectModelEntry\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x19\n\x08model_id\x18\x04 \x01(\tR\x07modelId\x12,\n\x05model\x18\x05 \x01(\x0b\x32\x16.tars.catalog.v1.ModelR\x05model\x12>\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\"\xc1\x01\n\x15UpsertProviderRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12&\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0b\x64isplayName\x12\x35\n\x08\x62\x61se_url\x18\x03 \x01(\tB\x1a\xe0\x41\x02\x9a\xb5\x18\x13\n\x11provider-base-urlR\x07\x62\x61seUrl\x12\x34\n\x16supported_auth_schemes\x18\x04 \x03(\tR\x14supportedAuthSchemes\"\x8c\x03\n\x12UpsertModelRequest\x12$\n\x0bprovider_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\nproviderId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12%\n\x0eupstream_model\x18\x03 \x01(\tR\rupstreamModel\x12*\n\x11input_per_million\x18\x04 \x01(\tR\x0finputPerMillion\x12,\n\x12output_per_million\x18\x05 \x01(\tR\x10outputPerMillion\x12\x33\n\x16\x63\x61\x63he_read_per_million\x18\x06 \x01(\tR\x13\x63\x61\x63heReadPerMillion\x12/\n\x14max_cost_per_request\x18\x07 \x01(\tR\x11maxCostPerRequest\x12,\n\x12max_context_tokens\x18\x08 \x01(\rR\x10maxContextTokens\x12\"\n\x0c\x63\x61pabilities\x18\t \x03(\tR\x0c\x63\x61pabilities\"X\n\x1cSetProviderCredentialRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12#\n\ncredential\x18\x02 \x01(\tB\x03\xe0\x41\x02R\ncredential\",\n\x15\x44\x65leteProviderRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\")\n\x12\x44\x65leteModelRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x9c\x01\n\x1b\x41ssignModelToProjectRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x1e\n\x08model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07modelId\"X\n\x1c\x41ssignModelToProjectResponse\x12\x38\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\".tars.catalog.v1.ProjectModelEntryR\x05\x65ntry\"y\n\x18ListProjectModelsRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\"Y\n\x19ListProjectModelsResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\".tars.catalog.v1.ProjectModelEntryR\x07\x65ntries\"\xa0\x01\n\x1fUnassignModelFromProjectRequest\x12/\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x0e\x9a\xb5\x18\n\n\x08\x63ustomerR\ncustomerId\x12,\n\nproject_id\x18\x02 \x01(\tB\r\x9a\xb5\x18\t\n\x07projectR\tprojectId\x12\x1e\n\x08model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07modelId\"<\n UnassignModelFromProjectResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success2\xf7\x14\n\x0e\x43\x61talogService\x12\xc6\x01\n\rListProviders\x12%.tars.catalog.v1.ListProvidersRequest\x1a&.tars.catalog.v1.ListProvidersResponse\"f\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x14:\x07\x63\x61talog:\tproviders\xa2\xb5\x18\x0eList providers\xaa\xb5\x18\tProviders\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/catalog/providers\x12\xc8\x01\n\x0bGetProvider\x12#.tars.catalog.v1.GetProviderRequest\x1a$.tars.catalog.v1.GetProviderResponse\"n\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x17\x1a\x02id:\x07\x63\x61talog:\x08provider\xa2\xb5\x18\x0eGet a provider\xaa\xb5\x18\tProviders\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/catalog/providers/{id}\x12\xb1\x01\n\nListModels\x12\".tars.catalog.v1.ListModelsRequest\x1a#.tars.catalog.v1.ListModelsResponse\"Z\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x11:\x07\x63\x61talog:\x06models\xa2\xb5\x18\x0bList models\xaa\xb5\x18\x06Models\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/catalog/models\x12\xb3\x01\n\x08GetModel\x12 .tars.catalog.v1.GetModelRequest\x1a!.tars.catalog.v1.GetModelResponse\"b\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x14\x1a\x02id:\x07\x63\x61talog:\x05model\xa2\xb5\x18\x0bGet a model\xaa\xb5\x18\x06Models\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/catalog/models/{id}\x12\xd0\x01\n\x0eUpsertProvider\x12&.tars.catalog.v1.UpsertProviderRequest\x1a\x19.tars.catalog.v1.Provider\"{\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x1c:\x07\x63\x61talog:\tproviders:\x06upsert\xa2\xb5\x18\x1b\x43reate or update a provider\xaa\xb5\x18\tProviders\x82\xd3\xe4\x93\x02\x1a\"\x15/v1/catalog/providers:\x01*\x12\xbb\x01\n\x0bUpsertModel\x12#.tars.catalog.v1.UpsertModelRequest\x1a\x16.tars.catalog.v1.Model\"o\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x19:\x07\x63\x61talog:\x06models:\x06upsert\xa2\xb5\x18\x18\x43reate or update a model\xaa\xb5\x18\x06Models\x82\xd3\xe4\x93\x02\x17\"\x12/v1/catalog/models:\x01*\x12\xf9\x01\n\x15SetProviderCredential\x12-.tars.catalog.v1.SetProviderCredentialRequest\x1a\x19.tars.catalog.v1.Provider\"\x95\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18(\x1a\x02id:\x07\x63\x61talog:\tproviders:\x0eset-credential\xa2\xb5\x18\x19Set a provider credential\xaa\xb5\x18\tProviders\x82\xd3\xe4\x93\x02*\"%/v1/catalog/providers/{id}/credential:\x01*\x12\xc9\x01\n\x0e\x44\x65leteProvider\x12&.tars.catalog.v1.DeleteProviderRequest\x1a\x16.google.protobuf.Empty\"w\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18 \x1a\x02id:\x07\x63\x61talog:\tproviders:\x06\x64\x65lete\xa2\xb5\x18\x11\x44\x65lete a provider\xaa\xb5\x18\tProviders\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/catalog/providers/{id}\x12\xb7\x01\n\x0b\x44\x65leteModel\x12#.tars.catalog.v1.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"k\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x1d\x1a\x02id:\x07\x63\x61talog:\x06models:\x06\x64\x65lete\xa2\xb5\x18\x0e\x44\x65lete a model\xaa\xb5\x18\x06Models\x82\xd3\xe4\x93\x02\x19*\x17/v1/catalog/models/{id}\x12\x9b\x02\n\x14\x41ssignModelToProject\x12,.tars.catalog.v1.AssignModelToProjectRequest\x1a-.tars.catalog.v1.AssignModelToProjectResponse\"\xa5\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x16:\x07project:\x06models:\x03\x61\x64\x64\xa2\xb5\x18\x1b\x41ssign a model to a project\xaa\xb5\x18\x0eProject Models\x82\xd3\xe4\x93\x02=\"8/v1/customers/{customer_id}/projects/{project_id}/models:\x01*\x12\xfc\x01\n\x11ListProjectModels\x12).tars.catalog.v1.ListProjectModelsRequest\x1a*.tars.catalog.v1.ListProjectModelsResponse\"\x8f\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x07project:\x06models:\x04list\xa2\xb5\x18\x13List project models\xaa\xb5\x18\x0eProject Models\x82\xd3\xe4\x93\x02:\x12\x38/v1/customers/{customer_id}/projects/{project_id}/models\x12\xb6\x02\n\x18UnassignModelFromProject\x12\x30.tars.catalog.v1.UnassignModelFromProjectRequest\x1a\x31.tars.catalog.v1.UnassignModelFromProjectResponse\"\xb4\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x19:\x07project:\x06models:\x06remove\xa2\xb5\x18\x1fUnassign a model from a project\xaa\xb5\x18\x0eProject Models\x82\xd3\xe4\x93\x02\x45*C/v1/customers/{customer_id}/projects/{project_id}/models/{model_id}B\xbc\x01\n\x13\x63om.tars.catalog.v1B\x0c\x43\x61talogProtoP\x01Z9github.com/tetrateio/fraser/api/tars/catalog/v1;catalogv1\xa2\x02\x03TCX\xaa\x02\x0fTars.Catalog.V1\xca\x02\x0fTars\\Catalog\\V1\xe2\x02\x1bTars\\Catalog\\V1\\GPBMetadata\xea\x02\x11Tars::Catalog::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.catalog.v1.catalog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.catalog.v1B\014CatalogProtoP\001Z9github.com/tetrateio/fraser/api/tars/catalog/v1;catalogv1\242\002\003TCX\252\002\017Tars.Catalog.V1\312\002\017Tars\\Catalog\\V1\342\002\033Tars\\Catalog\\V1\\GPBMetadata\352\002\021Tars::Catalog::V1'
  _globals['_PROVIDER'].fields_by_name['id']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_PROVIDER'].fields_by_name['name']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_PROVIDER'].fields_by_name['display_name']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['display_name']._serialized_options = b'\340A\002'
  _globals['_PROVIDER'].fields_by_name['base_url']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['base_url']._serialized_options = b'\340A\002'
  _globals['_PROVIDER'].fields_by_name['credential_suffix']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['credential_suffix']._serialized_options = b'\340A\003'
  _globals['_PROVIDER'].fields_by_name['created_at']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_PROVIDER'].fields_by_name['updated_at']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_MODEL'].fields_by_name['id']._loaded_options = None
  _globals['_MODEL'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_MODEL'].fields_by_name['provider_id']._loaded_options = None
  _globals['_MODEL'].fields_by_name['provider_id']._serialized_options = b'\340A\002'
  _globals['_MODEL'].fields_by_name['name']._loaded_options = None
  _globals['_MODEL'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_MODEL'].fields_by_name['upstream_model']._loaded_options = None
  _globals['_MODEL'].fields_by_name['upstream_model']._serialized_options = b'\340A\002'
  _globals['_MODEL'].fields_by_name['created_at']._loaded_options = None
  _globals['_MODEL'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_MODEL'].fields_by_name['updated_at']._loaded_options = None
  _globals['_MODEL'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_GETPROVIDERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETPROVIDERREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_GETMODELREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETMODELREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_PROJECTMODELENTRY'].fields_by_name['id']._loaded_options = None
  _globals['_PROJECTMODELENTRY'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_PROJECTMODELENTRY'].fields_by_name['created_at']._loaded_options = None
  _globals['_PROJECTMODELENTRY'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_UPSERTPROVIDERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPSERTPROVIDERREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_UPSERTPROVIDERREQUEST'].fields_by_name['display_name']._loaded_options = None
  _globals['_UPSERTPROVIDERREQUEST'].fields_by_name['display_name']._serialized_options = b'\340A\002'
  _globals['_UPSERTPROVIDERREQUEST'].fields_by_name['base_url']._loaded_options = None
  _globals['_UPSERTPROVIDERREQUEST'].fields_by_name['base_url']._serialized_options = b'\340A\002\232\265\030\023\n\021provider-base-url'
  _globals['_UPSERTMODELREQUEST'].fields_by_name['provider_id']._loaded_options = None
  _globals['_UPSERTMODELREQUEST'].fields_by_name['provider_id']._serialized_options = b'\340A\002'
  _globals['_UPSERTMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPSERTMODELREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_SETPROVIDERCREDENTIALREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_SETPROVIDERCREDENTIALREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_SETPROVIDERCREDENTIALREQUEST'].fields_by_name['credential']._loaded_options = None
  _globals['_SETPROVIDERCREDENTIALREQUEST'].fields_by_name['credential']._serialized_options = b'\340A\002'
  _globals['_DELETEPROVIDERREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEPROVIDERREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_DELETEMODELREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEMODELREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_ASSIGNMODELTOPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ASSIGNMODELTOPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_ASSIGNMODELTOPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ASSIGNMODELTOPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_ASSIGNMODELTOPROJECTREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_ASSIGNMODELTOPROJECTREQUEST'].fields_by_name['model_id']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTMODELSREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\232\265\030\n\n\010customer'
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\232\265\030\t\n\007project'
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST'].fields_by_name['model_id']._loaded_options = None
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST'].fields_by_name['model_id']._serialized_options = b'\340A\002'
  _globals['_CATALOGSERVICE'].methods_by_name['ListProviders']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['ListProviders']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\024:\007catalog:\tproviders\242\265\030\016List providers\252\265\030\tProviders\202\323\344\223\002\027\022\025/v1/catalog/providers'
  _globals['_CATALOGSERVICE'].methods_by_name['GetProvider']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['GetProvider']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\027\032\002id:\007catalog:\010provider\242\265\030\016Get a provider\252\265\030\tProviders\202\323\344\223\002\034\022\032/v1/catalog/providers/{id}'
  _globals['_CATALOGSERVICE'].methods_by_name['ListModels']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['ListModels']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\021:\007catalog:\006models\242\265\030\013List models\252\265\030\006Models\202\323\344\223\002\024\022\022/v1/catalog/models'
  _globals['_CATALOGSERVICE'].methods_by_name['GetModel']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['GetModel']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\024\032\002id:\007catalog:\005model\242\265\030\013Get a model\252\265\030\006Models\202\323\344\223\002\031\022\027/v1/catalog/models/{id}'
  _globals['_CATALOGSERVICE'].methods_by_name['UpsertProvider']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['UpsertProvider']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\034:\007catalog:\tproviders:\006upsert\242\265\030\033Create or update a provider\252\265\030\tProviders\202\323\344\223\002\032\"\025/v1/catalog/providers:\001*'
  _globals['_CATALOGSERVICE'].methods_by_name['UpsertModel']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['UpsertModel']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\031:\007catalog:\006models:\006upsert\242\265\030\030Create or update a model\252\265\030\006Models\202\323\344\223\002\027\"\022/v1/catalog/models:\001*'
  _globals['_CATALOGSERVICE'].methods_by_name['SetProviderCredential']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['SetProviderCredential']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030(\032\002id:\007catalog:\tproviders:\016set-credential\242\265\030\031Set a provider credential\252\265\030\tProviders\202\323\344\223\002*\"%/v1/catalog/providers/{id}/credential:\001*'
  _globals['_CATALOGSERVICE'].methods_by_name['DeleteProvider']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['DeleteProvider']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030 \032\002id:\007catalog:\tproviders:\006delete\242\265\030\021Delete a provider\252\265\030\tProviders\202\323\344\223\002\034*\032/v1/catalog/providers/{id}'
  _globals['_CATALOGSERVICE'].methods_by_name['DeleteModel']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['DeleteModel']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\035\032\002id:\007catalog:\006models:\006delete\242\265\030\016Delete a model\252\265\030\006Models\202\323\344\223\002\031*\027/v1/catalog/models/{id}'
  _globals['_CATALOGSERVICE'].methods_by_name['AssignModelToProject']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['AssignModelToProject']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\026:\007project:\006models:\003add\242\265\030\033Assign a model to a project\252\265\030\016Project Models\202\323\344\223\002=\"8/v1/customers/{customer_id}/projects/{project_id}/models:\001*'
  _globals['_CATALOGSERVICE'].methods_by_name['ListProjectModels']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['ListProjectModels']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\027:\007project:\006models:\004list\242\265\030\023List project models\252\265\030\016Project Models\202\323\344\223\002:\0228/v1/customers/{customer_id}/projects/{project_id}/models'
  _globals['_CATALOGSERVICE'].methods_by_name['UnassignModelFromProject']._loaded_options = None
  _globals['_CATALOGSERVICE'].methods_by_name['UnassignModelFromProject']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\031:\007project:\006models:\006remove\242\265\030\037Unassign a model from a project\252\265\030\016Project Models\202\323\344\223\002E*C/v1/customers/{customer_id}/projects/{project_id}/models/{model_id}'
  _globals['_PROVIDER']._serialized_start=285
  _globals['_PROVIDER']._serialized_end=645
  _globals['_PRICING']._serialized_start=648
  _globals['_PRICING']._serialized_end=849
  _globals['_MODEL']._serialized_start=852
  _globals['_MODEL']._serialized_end=1249
  _globals['_LISTPROVIDERSREQUEST']._serialized_start=1251
  _globals['_LISTPROVIDERSREQUEST']._serialized_end=1322
  _globals['_LISTPROVIDERSRESPONSE']._serialized_start=1325
  _globals['_LISTPROVIDERSRESPONSE']._serialized_end=1455
  _globals['_GETPROVIDERREQUEST']._serialized_start=1457
  _globals['_GETPROVIDERREQUEST']._serialized_end=1498
  _globals['_GETPROVIDERRESPONSE']._serialized_start=1500
  _globals['_GETPROVIDERRESPONSE']._serialized_end=1576
  _globals['_LISTMODELSREQUEST']._serialized_start=1578
  _globals['_LISTMODELSREQUEST']._serialized_end=1679
  _globals['_LISTMODELSRESPONSE']._serialized_start=1681
  _globals['_LISTMODELSRESPONSE']._serialized_end=1799
  _globals['_GETMODELREQUEST']._serialized_start=1801
  _globals['_GETMODELREQUEST']._serialized_end=1839
  _globals['_GETMODELRESPONSE']._serialized_start=1841
  _globals['_GETMODELRESPONSE']._serialized_end=1905
  _globals['_PROJECTMODELENTRY']._serialized_start=1908
  _globals['_PROJECTMODELENTRY']._serialized_end=2149
  _globals['_UPSERTPROVIDERREQUEST']._serialized_start=2152
  _globals['_UPSERTPROVIDERREQUEST']._serialized_end=2345
  _globals['_UPSERTMODELREQUEST']._serialized_start=2348
  _globals['_UPSERTMODELREQUEST']._serialized_end=2744
  _globals['_SETPROVIDERCREDENTIALREQUEST']._serialized_start=2746
  _globals['_SETPROVIDERCREDENTIALREQUEST']._serialized_end=2834
  _globals['_DELETEPROVIDERREQUEST']._serialized_start=2836
  _globals['_DELETEPROVIDERREQUEST']._serialized_end=2880
  _globals['_DELETEMODELREQUEST']._serialized_start=2882
  _globals['_DELETEMODELREQUEST']._serialized_end=2923
  _globals['_ASSIGNMODELTOPROJECTREQUEST']._serialized_start=2926
  _globals['_ASSIGNMODELTOPROJECTREQUEST']._serialized_end=3082
  _globals['_ASSIGNMODELTOPROJECTRESPONSE']._serialized_start=3084
  _globals['_ASSIGNMODELTOPROJECTRESPONSE']._serialized_end=3172
  _globals['_LISTPROJECTMODELSREQUEST']._serialized_start=3174
  _globals['_LISTPROJECTMODELSREQUEST']._serialized_end=3295
  _globals['_LISTPROJECTMODELSRESPONSE']._serialized_start=3297
  _globals['_LISTPROJECTMODELSRESPONSE']._serialized_end=3386
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST']._serialized_start=3389
  _globals['_UNASSIGNMODELFROMPROJECTREQUEST']._serialized_end=3549
  _globals['_UNASSIGNMODELFROMPROJECTRESPONSE']._serialized_start=3551
  _globals['_UNASSIGNMODELFROMPROJECTRESPONSE']._serialized_end=3611
  _globals['_CATALOGSERVICE']._serialized_start=3614
  _globals['_CATALOGSERVICE']._serialized_end=6293
# @@protoc_insertion_point(module_scope)
