# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/tenancy/v1/tenancy_service.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/tenancy/v1/tenancy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2
from tars.tenancy.v1 import customer_pb2 as tars_dot_tenancy_dot_v1_dot_customer__pb2
from tars.tenancy.v1 import project_pb2 as tars_dot_tenancy_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%tars/tenancy/v1/tenancy_service.proto\x12\x0ftars.tenancy.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\x1a\x1etars/tenancy/v1/customer.proto\x1a\x1dtars/tenancy/v1/project.proto\"\x82\x01\n\x15\x43reateCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\":\n\x12GetCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\"G\n\x14ListCustomersRequest\x12/\n\x04page\x18\x01 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x82\x01\n\x15ListCustomersResponse\x12\x37\n\tcustomers\x18\x01 \x03(\x0b\x32\x19.tars.tenancy.v1.CustomerR\tcustomers\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\x82\x01\n\x15UpdateCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\">\n\x16\x41rchiveCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\"\xa5\x01\n\x14\x43reateProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"]\n\x11GetProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"l\n\x13ListProjectsRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12/\n\x04page\x18\x02 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"~\n\x14ListProjectsResponse\x12\x34\n\x08projects\x18\x01 \x03(\x0b\x32\x18.tars.tenancy.v1.ProjectR\x08projects\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\xa5\x01\n\x14UpdateProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"a\n\x15\x41rchiveProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\xa2\x01\n\x17\x41\x64\x64ProjectMemberRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12$\n\x0bidentity_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nidentityId\x12\x17\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04role\"\x96\x01\n\x19ListProjectMembersRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12/\n\x04page\x18\x03 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x88\x01\n\x1aListProjectMembersResponse\x12\x38\n\x07members\x18\x01 \x03(\x0b\x32\x1e.tars.tenancy.v1.ProjectMemberR\x07members\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\xa5\x01\n\x1aUpdateProjectMemberRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12$\n\x0bidentity_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nidentityId\x12\x17\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04role\"\x8c\x01\n\x1aRemoveProjectMemberRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12$\n\x0bidentity_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nidentityId2\xca\x07\n\x0eTenancyService\x12\xb5\x01\n\x0e\x43reateCustomer\x12&.tars.tenancy.v1.CreateCustomerRequest\x1a\x19.tars.tenancy.v1.Customer\"`\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x13:\tcustomers:\x06\x63reate\xa2\xb5\x18\x11\x43reate a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x12\"\r/v1/customers:\x01*\x12\xb7\x01\n\x0bGetCustomer\x12#.tars.tenancy.v1.GetCustomerRequest\x1a\x19.tars.tenancy.v1.Customer\"h\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x10:\tcustomers:\x03get\xa2\xb5\x18\x0eGet a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/customers/{customer_id}\x12\xbb\x01\n\rListCustomers\x12%.tars.tenancy.v1.ListCustomersRequest\x1a&.tars.tenancy.v1.ListCustomersResponse\"[\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x11:\tcustomers:\x04list\xa2\xb5\x18\x0eList customers\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/customers\x12\xc3\x01\n\x0eUpdateCustomer\x12&.tars.tenancy.v1.UpdateCustomerRequest\x1a\x19.tars.tenancy.v1.Customer\"n\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x13:\tcustomers:\x06update\xa2\xb5\x18\x11Update a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02 2\x1b/v1/customers/{customer_id}:\x01*\x12\xc1\x01\n\x0f\x41rchiveCustomer\x12\'.tars.tenancy.v1.ArchiveCustomerRequest\x1a\x16.google.protobuf.Empty\"m\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x14:\tcustomers:\x07\x61rchive\xa2\xb5\x18\x12\x41rchive a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/customers/{customer_id}2\x84\x11\n\x0fProjectsService\x12\xc6\x01\n\rCreateProject\x12%.tars.tenancy.v1.CreateProjectRequest\x1a\x18.tars.tenancy.v1.Project\"t\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x12:\x08projects:\x06\x63reate\xa2\xb5\x18\x10\x43reate a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02)\"$/v1/customers/{customer_id}/projects:\x01*\x12\xd0\x01\n\nGetProject\x12\".tars.tenancy.v1.GetProjectRequest\x1a\x18.tars.tenancy.v1.Project\"\x83\x01\x90\x02\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x0f:\x08projects:\x03get\xa2\xb5\x18\rGet a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/customers/{customer_id}/projects/{project_id}\x12\xcc\x01\n\x0cListProjects\x12$.tars.tenancy.v1.ListProjectsRequest\x1a%.tars.tenancy.v1.ListProjectsResponse\"o\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x10:\x08projects:\x04list\xa2\xb5\x18\rList projects\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02&\x12$/v1/customers/{customer_id}/projects\x12\xdc\x01\n\rUpdateProject\x12%.tars.tenancy.v1.UpdateProjectRequest\x1a\x18.tars.tenancy.v1.Project\"\x89\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x12:\x08projects:\x06update\xa2\xb5\x18\x10Update a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x36\x32\x31/v1/customers/{customer_id}/projects/{project_id}:\x01*\x12\xdb\x01\n\x0e\x41rchiveProject\x12&.tars.tenancy.v1.ArchiveProjectRequest\x1a\x16.google.protobuf.Empty\"\x88\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x13:\x08projects:\x07\x61rchive\xa2\xb5\x18\x11\x41rchive a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x33*1/v1/customers/{customer_id}/projects/{project_id}\x12\x81\x02\n\x10\x41\x64\x64ProjectMember\x12(.tars.tenancy.v1.AddProjectMemberRequest\x1a\x1e.tars.tenancy.v1.ProjectMember\"\xa2\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x18:\x08projects:\x07members:\x03\x61\x64\x64\xa2\xb5\x18\x14\x41\x64\x64 a project member\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id}/projects/{project_id}/members:\x01*\x12\x93\x02\n\x12ListProjectMembers\x12*.tars.tenancy.v1.ListProjectMembersRequest\x1a+.tars.tenancy.v1.ListProjectMembersResponse\"\xa3\x01\x90\x02\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x19:\x08projects:\x07members:\x04list\xa2\xb5\x18\x14List project members\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02;\x12\x39/v1/customers/{customer_id}/projects/{project_id}/members\x12\x9b\x02\n\x13UpdateProjectMember\x12+.tars.tenancy.v1.UpdateProjectMemberRequest\x1a\x1e.tars.tenancy.v1.ProjectMember\"\xb6\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x1b:\x08projects:\x07members:\x06update\xa2\xb5\x18\x17Update a project member\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02L2G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}:\x01*\x12\x90\x02\n\x13RemoveProjectMember\x12+.tars.tenancy.v1.RemoveProjectMemberRequest\x1a\x16.google.protobuf.Empty\"\xb3\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x1b:\x08projects:\x07members:\x06remove\xa2\xb5\x18\x17Remove a project member\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02I*G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}B\xc3\x01\n\x13\x63om.tars.tenancy.v1B\x13TenancyServiceProtoP\x01Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\xa2\x02\x03TTX\xaa\x02\x0fTars.Tenancy.V1\xca\x02\x0fTars\\Tenancy\\V1\xe2\x02\x1bTars\\Tenancy\\V1\\GPBMetadata\xea\x02\x11Tars::Tenancy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.tenancy.v1.tenancy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.tenancy.v1B\023TenancyServiceProtoP\001Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\242\002\003TTX\252\002\017Tars.Tenancy.V1\312\002\017Tars\\Tenancy\\V1\342\002\033Tars\\Tenancy\\V1\\GPBMetadata\352\002\021Tars::Tenancy::V1'
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETCUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETCUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_ARCHIVECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ARCHIVECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['role']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['role']._serialized_options = b'\340A\002'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._serialized_options = b'\340A\002'
  _globals['_TENANCYSERVICE'].methods_by_name['CreateCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['CreateCustomer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\023:\tcustomers:\006create\242\265\030\021Create a customer\252\265\030\tCustomers\202\323\344\223\002\022\"\r/v1/customers:\001*'
  _globals['_TENANCYSERVICE'].methods_by_name['GetCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['GetCustomer']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\020:\tcustomers:\003get\242\265\030\016Get a customer\252\265\030\tCustomers\202\323\344\223\002\035\022\033/v1/customers/{customer_id}'
  _globals['_TENANCYSERVICE'].methods_by_name['ListCustomers']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['ListCustomers']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\021:\tcustomers:\004list\242\265\030\016List customers\252\265\030\tCustomers\202\323\344\223\002\017\022\r/v1/customers'
  _globals['_TENANCYSERVICE'].methods_by_name['UpdateCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['UpdateCustomer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\023:\tcustomers:\006update\242\265\030\021Update a customer\252\265\030\tCustomers\202\323\344\223\002 2\033/v1/customers/{customer_id}:\001*'
  _globals['_TENANCYSERVICE'].methods_by_name['ArchiveCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['ArchiveCustomer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\024:\tcustomers:\007archive\242\265\030\022Archive a customer\252\265\030\tCustomers\202\323\344\223\002\035*\033/v1/customers/{customer_id}'
  _globals['_PROJECTSSERVICE'].methods_by_name['CreateProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['CreateProject']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\022:\010projects:\006create\242\265\030\020Create a project\252\265\030\010Projects\202\323\344\223\002)\"$/v1/customers/{customer_id}/projects:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['GetProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['GetProject']._serialized_options = b'\220\002\001\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\017:\010projects:\003get\242\265\030\rGet a project\252\265\030\010Projects\202\323\344\223\0023\0221/v1/customers/{customer_id}/projects/{project_id}'
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjects']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjects']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\020:\010projects:\004list\242\265\030\rList projects\252\265\030\010Projects\202\323\344\223\002&\022$/v1/customers/{customer_id}/projects'
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProject']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\022:\010projects:\006update\242\265\030\020Update a project\252\265\030\010Projects\202\323\344\223\002621/v1/customers/{customer_id}/projects/{project_id}:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['ArchiveProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['ArchiveProject']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\023:\010projects:\007archive\242\265\030\021Archive a project\252\265\030\010Projects\202\323\344\223\0023*1/v1/customers/{customer_id}/projects/{project_id}'
  _globals['_PROJECTSSERVICE'].methods_by_name['AddProjectMember']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['AddProjectMember']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\030:\010projects:\007members:\003add\242\265\030\024Add a project member\252\265\030\017Project Members\202\323\344\223\002>\"9/v1/customers/{customer_id}/projects/{project_id}/members:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjectMembers']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjectMembers']._serialized_options = b'\220\002\001\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\031:\010projects:\007members:\004list\242\265\030\024List project members\252\265\030\017Project Members\202\323\344\223\002;\0229/v1/customers/{customer_id}/projects/{project_id}/members'
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProjectMember']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProjectMember']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\033:\010projects:\007members:\006update\242\265\030\027Update a project member\252\265\030\017Project Members\202\323\344\223\002L2G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['RemoveProjectMember']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['RemoveProjectMember']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\033:\010projects:\007members:\006remove\242\265\030\027Remove a project member\252\265\030\017Project Members\202\323\344\223\002I*G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}'
  _globals['_CREATECUSTOMERREQUEST']._serialized_start=323
  _globals['_CREATECUSTOMERREQUEST']._serialized_end=453
  _globals['_GETCUSTOMERREQUEST']._serialized_start=455
  _globals['_GETCUSTOMERREQUEST']._serialized_end=513
  _globals['_LISTCUSTOMERSREQUEST']._serialized_start=515
  _globals['_LISTCUSTOMERSREQUEST']._serialized_end=586
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_start=589
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_end=719
  _globals['_UPDATECUSTOMERREQUEST']._serialized_start=722
  _globals['_UPDATECUSTOMERREQUEST']._serialized_end=852
  _globals['_ARCHIVECUSTOMERREQUEST']._serialized_start=854
  _globals['_ARCHIVECUSTOMERREQUEST']._serialized_end=916
  _globals['_CREATEPROJECTREQUEST']._serialized_start=919
  _globals['_CREATEPROJECTREQUEST']._serialized_end=1084
  _globals['_GETPROJECTREQUEST']._serialized_start=1086
  _globals['_GETPROJECTREQUEST']._serialized_end=1179
  _globals['_LISTPROJECTSREQUEST']._serialized_start=1181
  _globals['_LISTPROJECTSREQUEST']._serialized_end=1289
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=1291
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=1417
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=1420
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1585
  _globals['_ARCHIVEPROJECTREQUEST']._serialized_start=1587
  _globals['_ARCHIVEPROJECTREQUEST']._serialized_end=1684
  _globals['_ADDPROJECTMEMBERREQUEST']._serialized_start=1687
  _globals['_ADDPROJECTMEMBERREQUEST']._serialized_end=1849
  _globals['_LISTPROJECTMEMBERSREQUEST']._serialized_start=1852
  _globals['_LISTPROJECTMEMBERSREQUEST']._serialized_end=2002
  _globals['_LISTPROJECTMEMBERSRESPONSE']._serialized_start=2005
  _globals['_LISTPROJECTMEMBERSRESPONSE']._serialized_end=2141
  _globals['_UPDATEPROJECTMEMBERREQUEST']._serialized_start=2144
  _globals['_UPDATEPROJECTMEMBERREQUEST']._serialized_end=2309
  _globals['_REMOVEPROJECTMEMBERREQUEST']._serialized_start=2312
  _globals['_REMOVEPROJECTMEMBERREQUEST']._serialized_end=2452
  _globals['_TENANCYSERVICE']._serialized_start=2455
  _globals['_TENANCYSERVICE']._serialized_end=3425
  _globals['_PROJECTSSERVICE']._serialized_start=3428
  _globals['_PROJECTSSERVICE']._serialized_end=5608
# @@protoc_insertion_point(module_scope)
