# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/kms/v1/secrets_svc.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/kms/v1/secrets_svc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtars/kms/v1/secrets_svc.proto\x12\x0btars.kms.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\x91\x02\n\tSecretRef\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x33\n\x07purpose\x18\x02 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x03R\x07purpose\x12$\n\x0bkek_version\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\nkekVersion\x12\x14\n\x05label\x18\x04 \x01(\tR\x05label\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\"\x80\x01\n\x10PutSecretRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\x12!\n\tplaintext\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tplaintext\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\"=\n\x11PutSecretResponse\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x16.tars.kms.v1.SecretRefR\x03ref\"\'\n\x10GetSecretRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"`\n\x11GetSecretResponse\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x16.tars.kms.v1.SecretRefR\x03ref\x12!\n\tplaintext\x18\x02 \x01(\tB\x03\xe0\x41\x03R\tplaintext\"/\n\x18RotateResourceDekRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x1b\n\x19RotateResourceDekResponse\")\n\x12\x45raseSecretRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x15\n\x13\x45raseSecretResponse\"N\n\x17RotatePurposeKekRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\"B\n\x18RotatePurposeKekResponse\x12&\n\x0coperation_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0boperationId\"\x18\n\x16RotateMasterKekRequest\"A\n\x17RotateMasterKekResponse\x12&\n\x0coperation_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0boperationId\"a\n\x0bSignRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\x12\x1d\n\x07payload\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x07payload\"W\n\x0cSignResponse\x12!\n\tsignature\x18\x01 \x01(\x0c\x42\x03\xe0\x41\x03R\tsignature\x12$\n\x0bkek_version\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\nkekVersion\"\x86\x01\n\rVerifyRequest\x12\x33\n\x07purpose\x18\x01 \x01(\x0e\x32\x14.tars.kms.v1.PurposeB\x03\xe0\x41\x02R\x07purpose\x12\x1d\n\x07payload\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x07payload\x12!\n\tsignature\x18\x03 \x01(\x0c\x42\x03\xe0\x41\x02R\tsignature\"Q\n\x0eVerifyResponse\x12\x19\n\x05valid\x18\x01 \x01(\x08\x42\x03\xe0\x41\x03R\x05valid\x12$\n\x0bkek_version\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\nkekVersion*\x9f\x01\n\x07Purpose\x12\x17\n\x13PURPOSE_UNSPECIFIED\x10\x00\x12\x19\n\x15PURPOSE_AUDIT_SIGNING\x10\x01\x12\x10\n\x0cPURPOSE_BYOK\x10\x02\x12\x18\n\x14PURPOSE_JWKS_SIGNING\x10\x03\x12\x1a\n\x16PURPOSE_WEBHOOK_SECRET\x10\x04\x12\x18\n\x14PURPOSE_DATAPLANE_SA\x10\x05\x32\xce\n\n\x0eSecretsService\x12\xa2\x01\n\tPutSecret\x12\x1d.tars.kms.v1.PutSecretRequest\x1a\x1e.tars.kms.v1.PutSecretResponse\"V\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x13(\x01:\x03kms:\nput-secret\xa2\xb5\x18\x10Put a KMS secret\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/kms/secrets:\x01*\x12\xab\x01\n\tGetSecret\x12\x1d.tars.kms.v1.GetSecretRequest\x1a\x1e.tars.kms.v1.GetSecretResponse\"_\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x17\x1a\x02id(\x01:\x03kms:\nget-secret\xa2\xb5\x18\x10Get a KMS secret\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/kms/secrets/{id}\x12\xe9\x01\n\x11RotateResourceDek\x12%.tars.kms.v1.RotateResourceDekRequest\x1a&.tars.kms.v1.RotateResourceDekResponse\"\x84\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x17\x1a\x02id(\x01:\x03kms:\nrotate-dek\xa2\xb5\x18*Rotate the resource DEK on a stored secret\x82\xd3\xe4\x93\x02$\"\x1f/v1/kms/secrets/{id}/rotate-dek:\x01*\x12\xb2\x01\n\x0b\x45raseSecret\x12\x1f.tars.kms.v1.EraseSecretRequest\x1a .tars.kms.v1.EraseSecretResponse\"`\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x19\x1a\x02id(\x01:\x03kms:\x0c\x65rase-secret\xa2\xb5\x18\x12\x45rase a KMS secret\x82\xd3\xe4\x93\x02\x16*\x14/v1/kms/secrets/{id}\x12\xd1\x01\n\x10RotatePurposeKek\x12$.tars.kms.v1.RotatePurposeKekRequest\x1a%.tars.kms.v1.RotatePurposeKekResponse\"p\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x1b(\x01:\x03kms:\x12rotate-purpose-kek\xa2\xb5\x18\x16Rotate the purpose KEK\x82\xd3\xe4\x93\x02 \"\x1b/v1/kms/purpose-keks/rotate:\x01*\x12\xca\x01\n\x0fRotateMasterKek\x12#.tars.kms.v1.RotateMasterKekRequest\x1a$.tars.kms.v1.RotateMasterKekResponse\"l\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x1a(\x01:\x03kms:\x11rotate-master-kek\xa2\xb5\x18\x15Rotate the master KEK\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/kms/master-kek/rotate:\x01*\x12N\n\x04Sign\x12\x18.tars.kms.v1.SignRequest\x1a\x19.tars.kms.v1.SignResponse\"\x11\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x12W\n\x06Verify\x12\x1a.tars.kms.v1.VerifyRequest\x1a\x1b.tars.kms.v1.VerifyResponse\"\x14\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internalB\xa3\x01\n\x0f\x63om.tars.kms.v1B\x0fSecretsSvcProtoP\x01Z1github.com/tetrateio/fraser/api/tars/kms/v1;kmsv1\xa2\x02\x03TKX\xaa\x02\x0bTars.Kms.V1\xca\x02\x0bTars\\Kms\\V1\xe2\x02\x17Tars\\Kms\\V1\\GPBMetadata\xea\x02\rTars::Kms::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.kms.v1.secrets_svc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.kms.v1B\017SecretsSvcProtoP\001Z1github.com/tetrateio/fraser/api/tars/kms/v1;kmsv1\242\002\003TKX\252\002\013Tars.Kms.V1\312\002\013Tars\\Kms\\V1\342\002\027Tars\\Kms\\V1\\GPBMetadata\352\002\rTars::Kms::V1'
  _globals['_SECRETREF'].fields_by_name['id']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['purpose']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['purpose']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['kek_version']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['kek_version']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['created_at']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_SECRETREF'].fields_by_name['updated_at']._loaded_options = None
  _globals['_SECRETREF'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_PUTSECRETREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_PUTSECRETREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_PUTSECRETREQUEST'].fields_by_name['plaintext']._loaded_options = None
  _globals['_PUTSECRETREQUEST'].fields_by_name['plaintext']._serialized_options = b'\340A\002'
  _globals['_GETSECRETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSECRETREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_GETSECRETRESPONSE'].fields_by_name['plaintext']._loaded_options = None
  _globals['_GETSECRETRESPONSE'].fields_by_name['plaintext']._serialized_options = b'\340A\003'
  _globals['_ROTATERESOURCEDEKREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ROTATERESOURCEDEKREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_ERASESECRETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ERASESECRETREQUEST'].fields_by_name['id']._serialized_options = b'\340A\002'
  _globals['_ROTATEPURPOSEKEKREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_ROTATEPURPOSEKEKREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_ROTATEPURPOSEKEKRESPONSE'].fields_by_name['operation_id']._loaded_options = None
  _globals['_ROTATEPURPOSEKEKRESPONSE'].fields_by_name['operation_id']._serialized_options = b'\340A\003'
  _globals['_ROTATEMASTERKEKRESPONSE'].fields_by_name['operation_id']._loaded_options = None
  _globals['_ROTATEMASTERKEKRESPONSE'].fields_by_name['operation_id']._serialized_options = b'\340A\003'
  _globals['_SIGNREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_SIGNREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_SIGNREQUEST'].fields_by_name['payload']._loaded_options = None
  _globals['_SIGNREQUEST'].fields_by_name['payload']._serialized_options = b'\340A\002'
  _globals['_SIGNRESPONSE'].fields_by_name['signature']._loaded_options = None
  _globals['_SIGNRESPONSE'].fields_by_name['signature']._serialized_options = b'\340A\003'
  _globals['_SIGNRESPONSE'].fields_by_name['kek_version']._loaded_options = None
  _globals['_SIGNRESPONSE'].fields_by_name['kek_version']._serialized_options = b'\340A\003'
  _globals['_VERIFYREQUEST'].fields_by_name['purpose']._loaded_options = None
  _globals['_VERIFYREQUEST'].fields_by_name['purpose']._serialized_options = b'\340A\002'
  _globals['_VERIFYREQUEST'].fields_by_name['payload']._loaded_options = None
  _globals['_VERIFYREQUEST'].fields_by_name['payload']._serialized_options = b'\340A\002'
  _globals['_VERIFYREQUEST'].fields_by_name['signature']._loaded_options = None
  _globals['_VERIFYREQUEST'].fields_by_name['signature']._serialized_options = b'\340A\002'
  _globals['_VERIFYRESPONSE'].fields_by_name['valid']._loaded_options = None
  _globals['_VERIFYRESPONSE'].fields_by_name['valid']._serialized_options = b'\340A\003'
  _globals['_VERIFYRESPONSE'].fields_by_name['kek_version']._loaded_options = None
  _globals['_VERIFYRESPONSE'].fields_by_name['kek_version']._serialized_options = b'\340A\003'
  _globals['_SECRETSSERVICE'].methods_by_name['PutSecret']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['PutSecret']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\023(\001:\003kms:\nput-secret\242\265\030\020Put a KMS secret\202\323\344\223\002\024\"\017/v1/kms/secrets:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['GetSecret']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal\222\265\030\027\032\002id(\001:\003kms:\nget-secret\242\265\030\020Get a KMS secret\202\323\344\223\002\026\022\024/v1/kms/secrets/{id}'
  _globals['_SECRETSSERVICE'].methods_by_name['RotateResourceDek']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['RotateResourceDek']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\027\032\002id(\001:\003kms:\nrotate-dek\242\265\030*Rotate the resource DEK on a stored secret\202\323\344\223\002$\"\037/v1/kms/secrets/{id}/rotate-dek:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['EraseSecret']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['EraseSecret']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\031\032\002id(\001:\003kms:\014erase-secret\242\265\030\022Erase a KMS secret\202\323\344\223\002\026*\024/v1/kms/secrets/{id}'
  _globals['_SECRETSSERVICE'].methods_by_name['RotatePurposeKek']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['RotatePurposeKek']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\033(\001:\003kms:\022rotate-purpose-kek\242\265\030\026Rotate the purpose KEK\202\323\344\223\002 \"\033/v1/kms/purpose-keks/rotate:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['RotateMasterKek']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['RotateMasterKek']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal\222\265\030\032(\001:\003kms:\021rotate-master-kek\242\265\030\025Rotate the master KEK\202\323\344\223\002\036\"\031/v1/kms/master-kek/rotate:\001*'
  _globals['_SECRETSSERVICE'].methods_by_name['Sign']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['Sign']._serialized_options = b'\212\265\030\r\n\001\002\022\010internal'
  _globals['_SECRETSSERVICE'].methods_by_name['Verify']._loaded_options = None
  _globals['_SECRETSSERVICE'].methods_by_name['Verify']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal'
  _globals['_PURPOSE']._serialized_start=1626
  _globals['_PURPOSE']._serialized_end=1785
  _globals['_SECRETREF']._serialized_start=224
  _globals['_SECRETREF']._serialized_end=497
  _globals['_PUTSECRETREQUEST']._serialized_start=500
  _globals['_PUTSECRETREQUEST']._serialized_end=628
  _globals['_PUTSECRETRESPONSE']._serialized_start=630
  _globals['_PUTSECRETRESPONSE']._serialized_end=691
  _globals['_GETSECRETREQUEST']._serialized_start=693
  _globals['_GETSECRETREQUEST']._serialized_end=732
  _globals['_GETSECRETRESPONSE']._serialized_start=734
  _globals['_GETSECRETRESPONSE']._serialized_end=830
  _globals['_ROTATERESOURCEDEKREQUEST']._serialized_start=832
  _globals['_ROTATERESOURCEDEKREQUEST']._serialized_end=879
  _globals['_ROTATERESOURCEDEKRESPONSE']._serialized_start=881
  _globals['_ROTATERESOURCEDEKRESPONSE']._serialized_end=908
  _globals['_ERASESECRETREQUEST']._serialized_start=910
  _globals['_ERASESECRETREQUEST']._serialized_end=951
  _globals['_ERASESECRETRESPONSE']._serialized_start=953
  _globals['_ERASESECRETRESPONSE']._serialized_end=974
  _globals['_ROTATEPURPOSEKEKREQUEST']._serialized_start=976
  _globals['_ROTATEPURPOSEKEKREQUEST']._serialized_end=1054
  _globals['_ROTATEPURPOSEKEKRESPONSE']._serialized_start=1056
  _globals['_ROTATEPURPOSEKEKRESPONSE']._serialized_end=1122
  _globals['_ROTATEMASTERKEKREQUEST']._serialized_start=1124
  _globals['_ROTATEMASTERKEKREQUEST']._serialized_end=1148
  _globals['_ROTATEMASTERKEKRESPONSE']._serialized_start=1150
  _globals['_ROTATEMASTERKEKRESPONSE']._serialized_end=1215
  _globals['_SIGNREQUEST']._serialized_start=1217
  _globals['_SIGNREQUEST']._serialized_end=1314
  _globals['_SIGNRESPONSE']._serialized_start=1316
  _globals['_SIGNRESPONSE']._serialized_end=1403
  _globals['_VERIFYREQUEST']._serialized_start=1406
  _globals['_VERIFYREQUEST']._serialized_end=1540
  _globals['_VERIFYRESPONSE']._serialized_start=1542
  _globals['_VERIFYRESPONSE']._serialized_end=1623
  _globals['_SECRETSSERVICE']._serialized_start=1788
  _globals['_SECRETSSERVICE']._serialized_end=3146
# @@protoc_insertion_point(module_scope)
