# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/lookup/v1/lookup.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/lookup/v1/lookup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btars/lookup/v1/lookup.proto\x12\x0etars.lookup.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"U\n\x19GetMCPProfileByURLRequest\x12\x19\n\x03url\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03url\x12\x1d\n\nuser_token\x18\x02 \x01(\tR\tuserToken\"R\n\x1aGetMCPProfileByURLResponse\x12\x34\n\x07profile\x18\x01 \x01(\x0b\x32\x1a.tars.lookup.v1.MCPProfileR\x07profile\"\x93\x03\n\nMCPProfile\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x10\n\x03url\x18\x05 \x01(\tR\x03url\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12#\n\rerror_message\x18\x07 \x01(\tR\x0c\x65rrorMessage\x12\x30\n\x14security_policy_type\x18\x08 \x01(\tR\x12securityPolicyType\x12\x32\n\x15security_policy_value\x18\t \x01(\tR\x13securityPolicyValue\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"d\n ResolveRouteIdentityByKeyRequest\x12 \n\x07user_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06userId\x12\x1e\n\x06key_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05keyId\"\xe6\x01\n!ResolveRouteIdentityByKeyResponse\x12.\n\x13\x65\x66\x66\x65\x63tive_client_id\x18\x01 \x01(\tR\x11\x65\x66\x66\x65\x63tiveClientId\x12$\n\x0eroute_owner_id\x18\x02 \x01(\tR\x0crouteOwnerId\x12(\n\x10route_owner_hash\x18\x03 \x01(\tR\x0erouteOwnerHash\x12\x17\n\x07tars_id\x18\x04 \x01(\tR\x06tarsId\x12(\n\x10is_mapped_client\x18\x05 \x01(\x08R\x0eisMappedClient2\xfa\x02\n\rLookupService\x12\xa4\x01\n\x12GetMCPProfileByURL\x12).tars.lookup.v1.GetMCPProfileByURLRequest\x1a*.tars.lookup.v1.GetMCPProfileByURLResponse\"7\x90\x02\x01\x8a\xb5\x18\n\n\x02\x02\x01\x12\x04read\x82\xd3\xe4\x93\x02 \x12\x1e/lookup/v1/mcp-profiles/by-url\x12\xbb\x01\n\x19ResolveRouteIdentityByKey\x12\x30.tars.lookup.v1.ResolveRouteIdentityByKeyRequest\x1a\x31.tars.lookup.v1.ResolveRouteIdentityByKeyResponse\"9\x90\x02\x01\x8a\xb5\x18\n\n\x02\x02\x01\x12\x04read\x82\xd3\xe4\x93\x02\"\x12 /lookup/v1/route-identity/by-key\x1a\x04\xa0\xb5\x18\x01\x42{\n\x12\x63om.tars.lookup.v1B\x0bLookupProtoP\x01\xa2\x02\x03TLX\xaa\x02\x0eTars.Lookup.V1\xca\x02\x0eTars\\Lookup\\V1\xe2\x02\x1aTars\\Lookup\\V1\\GPBMetadata\xea\x02\x10Tars::Lookup::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.lookup.v1.lookup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.lookup.v1B\013LookupProtoP\001\242\002\003TLX\252\002\016Tars.Lookup.V1\312\002\016Tars\\Lookup\\V1\342\002\032Tars\\Lookup\\V1\\GPBMetadata\352\002\020Tars::Lookup::V1'
  _globals['_GETMCPPROFILEBYURLREQUEST'].fields_by_name['url']._loaded_options = None
  _globals['_GETMCPPROFILEBYURLREQUEST'].fields_by_name['url']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['user_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_LOOKUPSERVICE']._loaded_options = None
  _globals['_LOOKUPSERVICE']._serialized_options = b'\240\265\030\001'
  _globals['_LOOKUPSERVICE'].methods_by_name['GetMCPProfileByURL']._loaded_options = None
  _globals['_LOOKUPSERVICE'].methods_by_name['GetMCPProfileByURL']._serialized_options = b'\220\002\001\212\265\030\n\n\002\002\001\022\004read\202\323\344\223\002 \022\036/lookup/v1/mcp-profiles/by-url'
  _globals['_LOOKUPSERVICE'].methods_by_name['ResolveRouteIdentityByKey']._loaded_options = None
  _globals['_LOOKUPSERVICE'].methods_by_name['ResolveRouteIdentityByKey']._serialized_options = b'\220\002\001\212\265\030\n\n\002\002\001\022\004read\202\323\344\223\002\"\022 /lookup/v1/route-identity/by-key'
  _globals['_GETMCPPROFILEBYURLREQUEST']._serialized_start=197
  _globals['_GETMCPPROFILEBYURLREQUEST']._serialized_end=282
  _globals['_GETMCPPROFILEBYURLRESPONSE']._serialized_start=284
  _globals['_GETMCPPROFILEBYURLRESPONSE']._serialized_end=366
  _globals['_MCPPROFILE']._serialized_start=369
  _globals['_MCPPROFILE']._serialized_end=772
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST']._serialized_start=774
  _globals['_RESOLVEROUTEIDENTITYBYKEYREQUEST']._serialized_end=874
  _globals['_RESOLVEROUTEIDENTITYBYKEYRESPONSE']._serialized_start=877
  _globals['_RESOLVEROUTEIDENTITYBYKEYRESPONSE']._serialized_end=1107
  _globals['_LOOKUPSERVICE']._serialized_start=1110
  _globals['_LOOKUPSERVICE']._serialized_end=1488
# @@protoc_insertion_point(module_scope)
