# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/telemetry/v1/telemetry.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/telemetry/v1/telemetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tars/telemetry/v1/telemetry.proto\x12\x11tars.telemetry.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\xe6\x03\n\x0fTelemetryConfig\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x19\n\x08sink_url\x18\x04 \x01(\tR\x07sinkUrl\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12\x18\n\x07\x65nabled\x18\t \x01(\x08R\x07\x65nabled\x12\x42\n\x0flast_checked_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rlastCheckedAt\x12\x16\n\x06status\x18\x0b \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\xdc\x03\n\x1c\x43reateTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x1f\n\x08\x65ndpoint\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12V\n\x07headers\x18\t \x03(\x0b\x32<.tars.telemetry.v1.CreateTelemetryConfigRequest.HeadersEntryR\x07headers\x12\x18\n\x07\x65nabled\x18\n \x01(\x08R\x07\x65nabled\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa8\x01\n\x1bListTelemetryConfigsRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x18\n\x07\x65nabled\x18\x04 \x01(\tR\x07\x65nabled\"r\n\x1cListTelemetryConfigsResponse\x12<\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\".tars.telemetry.v1.TelemetryConfigR\x07\x63onfigs\x12\x14\n\x05total\x18\x02 \x01(\x05R\x05total\"\x87\x01\n\x19GetTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12 \n\tconfig_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63onfigId\"\xd6\x02\n\x1cUpdateTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12 \n\tconfig_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63onfigId\x12\x1a\n\x08\x65ndpoint\x18\x04 \x01(\tR\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12\x18\n\x07\x65nabled\x18\t \x01(\tR\x07\x65nabled\x12\x16\n\x06status\x18\n \x01(\tR\x06status\"\x8a\x01\n\x1c\x44\x65leteTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12 \n\tconfig_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63onfigId\"\xcc\x02\n SetProjectTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType\x12\x1f\n\x08\x65ndpoint\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x08\x65ndpoint\x12\x1a\n\x08protocol\x18\x05 \x01(\tR\x08protocol\x12\x1b\n\tauth_type\x18\x06 \x01(\tR\x08\x61uthType\x12\x1d\n\nauth_value\x18\x07 \x01(\tR\tauthValue\x12$\n\x0e\x61pi_key_header\x18\x08 \x01(\tR\x0c\x61piKeyHeader\x12\x18\n\x07\x65nabled\x18\t \x01(\x08R\x07\x65nabled\"\x93\x01\n GetProjectTelemetryConfigRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12%\n\x0etelemetry_type\x18\x03 \x01(\tR\rtelemetryType2\xaf\x0f\n\x10TelemetryService\x12\x85\x02\n\x15\x43reateTelemetryConfig\x12/.tars.telemetry.v1.CreateTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\x96\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x13:\ttelemetry:\x06\x63reate\xa2\xb5\x18 Create a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02@\";/v1/customers/{customer_id}/projects/{project_id}/telemetry:\x01*\x12\x8b\x02\n\x14ListTelemetryConfigs\x12..tars.telemetry.v1.ListTelemetryConfigsRequest\x1a/.tars.telemetry.v1.ListTelemetryConfigsResponse\"\x91\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x11:\ttelemetry:\x04list\xa2\xb5\x18\x1dList telemetry export configs\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02=\x12;/v1/customers/{customer_id}/projects/{project_id}/telemetry\x12\x85\x02\n\x12GetTelemetryConfig\x12,.tars.telemetry.v1.GetTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\x9c\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x10:\ttelemetry:\x03get\xa2\xb5\x18\x1dGet a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02I\x12G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}\x12\x91\x02\n\x15UpdateTelemetryConfig\x12/.tars.telemetry.v1.UpdateTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\xa2\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x13:\ttelemetry:\x06update\xa2\xb5\x18 Update a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02L2G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}:\x01*\x12\x82\x02\n\x15\x44\x65leteTelemetryConfig\x12/.tars.telemetry.v1.DeleteTelemetryConfigRequest\x1a\x16.google.protobuf.Empty\"\x9f\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x13:\ttelemetry:\x06\x64\x65lete\xa2\xb5\x18 Delete a telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02I*G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}\x12\xb0\x02\n\x19SetProjectTelemetryConfig\x12\x33.tars.telemetry.v1.SetProjectTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\xb9\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x18:\ttelemetry:\x0bset-project\xa2\xb5\x18\'Set the project telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02H\x1a\x43/v1/customers/{customer_id}/projects/{project_id}/telemetry/project:\x01*\x12\xb0\x02\n\x19GetProjectTelemetryConfig\x12\x33.tars.telemetry.v1.GetProjectTelemetryConfigRequest\x1a\".tars.telemetry.v1.TelemetryConfig\"\xb9\x01\x90\x02\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x18:\ttelemetry:\x0bget-project\xa2\xb5\x18\'Get the project telemetry export config\xaa\xb5\x18\tTelemetry\x82\xd3\xe4\x93\x02\x45\x12\x43/v1/customers/{customer_id}/projects/{project_id}/telemetry/projectB\xcc\x01\n\x15\x63om.tars.telemetry.v1B\x0eTelemetryProtoP\x01Z=github.com/tetrateio/fraser/api/tars/telemetry/v1;telemetryv1\xa2\x02\x03TTX\xaa\x02\x11Tars.Telemetry.V1\xca\x02\x11Tars\\Telemetry\\V1\xe2\x02\x1dTars\\Telemetry\\V1\\GPBMetadata\xea\x02\x13Tars::Telemetry::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.telemetry.v1.telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.tars.telemetry.v1B\016TelemetryProtoP\001Z=github.com/tetrateio/fraser/api/tars/telemetry/v1;telemetryv1\242\002\003TTX\252\002\021Tars.Telemetry.V1\312\002\021Tars\\Telemetry\\V1\342\002\035Tars\\Telemetry\\V1\\GPBMetadata\352\002\023Tars::Telemetry::V1'
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._loaded_options = None
  _globals['_CREATETELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._serialized_options = b'\340A\002'
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTTELEMETRYCONFIGSREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._loaded_options = None
  _globals['_GETTELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._serialized_options = b'\340A\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._loaded_options = None
  _globals['_UPDATETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._serialized_options = b'\340A\002'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._loaded_options = None
  _globals['_DELETETELEMETRYCONFIGREQUEST'].fields_by_name['config_id']._serialized_options = b'\340A\002'
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._loaded_options = None
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['endpoint']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_TELEMETRYSERVICE'].methods_by_name['CreateTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['CreateTelemetryConfig']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\023:\ttelemetry:\006create\242\265\030 Create a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002@\";/v1/customers/{customer_id}/projects/{project_id}/telemetry:\001*'
  _globals['_TELEMETRYSERVICE'].methods_by_name['ListTelemetryConfigs']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['ListTelemetryConfigs']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\021:\ttelemetry:\004list\242\265\030\035List telemetry export configs\252\265\030\tTelemetry\202\323\344\223\002=\022;/v1/customers/{customer_id}/projects/{project_id}/telemetry'
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetTelemetryConfig']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\020:\ttelemetry:\003get\242\265\030\035Get a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002I\022G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}'
  _globals['_TELEMETRYSERVICE'].methods_by_name['UpdateTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['UpdateTelemetryConfig']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\023:\ttelemetry:\006update\242\265\030 Update a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002L2G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}:\001*'
  _globals['_TELEMETRYSERVICE'].methods_by_name['DeleteTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['DeleteTelemetryConfig']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\023:\ttelemetry:\006delete\242\265\030 Delete a telemetry export config\252\265\030\tTelemetry\202\323\344\223\002I*G/v1/customers/{customer_id}/projects/{project_id}/telemetry/{config_id}'
  _globals['_TELEMETRYSERVICE'].methods_by_name['SetProjectTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['SetProjectTelemetryConfig']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\030:\ttelemetry:\013set-project\242\265\030\'Set the project telemetry export config\252\265\030\tTelemetry\202\323\344\223\002H\032C/v1/customers/{customer_id}/projects/{project_id}/telemetry/project:\001*'
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetProjectTelemetryConfig']._loaded_options = None
  _globals['_TELEMETRYSERVICE'].methods_by_name['GetProjectTelemetryConfig']._serialized_options = b'\220\002\001\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\030:\ttelemetry:\013get-project\242\265\030\'Get the project telemetry export config\252\265\030\tTelemetry\202\323\344\223\002E\022C/v1/customers/{customer_id}/projects/{project_id}/telemetry/project'
  _globals['_TELEMETRYCONFIG']._serialized_start=263
  _globals['_TELEMETRYCONFIG']._serialized_end=749
  _globals['_CREATETELEMETRYCONFIGREQUEST']._serialized_start=752
  _globals['_CREATETELEMETRYCONFIGREQUEST']._serialized_end=1228
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._serialized_start=1170
  _globals['_CREATETELEMETRYCONFIGREQUEST_HEADERSENTRY']._serialized_end=1228
  _globals['_LISTTELEMETRYCONFIGSREQUEST']._serialized_start=1231
  _globals['_LISTTELEMETRYCONFIGSREQUEST']._serialized_end=1399
  _globals['_LISTTELEMETRYCONFIGSRESPONSE']._serialized_start=1401
  _globals['_LISTTELEMETRYCONFIGSRESPONSE']._serialized_end=1515
  _globals['_GETTELEMETRYCONFIGREQUEST']._serialized_start=1518
  _globals['_GETTELEMETRYCONFIGREQUEST']._serialized_end=1653
  _globals['_UPDATETELEMETRYCONFIGREQUEST']._serialized_start=1656
  _globals['_UPDATETELEMETRYCONFIGREQUEST']._serialized_end=1998
  _globals['_DELETETELEMETRYCONFIGREQUEST']._serialized_start=2001
  _globals['_DELETETELEMETRYCONFIGREQUEST']._serialized_end=2139
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST']._serialized_start=2142
  _globals['_SETPROJECTTELEMETRYCONFIGREQUEST']._serialized_end=2474
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST']._serialized_start=2477
  _globals['_GETPROJECTTELEMETRYCONFIGREQUEST']._serialized_end=2624
  _globals['_TELEMETRYSERVICE']._serialized_start=2627
  _globals['_TELEMETRYSERVICE']._serialized_end=4594
# @@protoc_insertion_point(module_scope)
