# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/secret/v1/secret.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/secret/v1/secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btars/secret/v1/secret.proto\x12\x0etars.secret.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"\x8c\x02\n\x13\x43reateSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x14\n\x05value\x18\x04 \x01(\tR\x05value\x12\x41\n\x04tags\x18\x05 \x03(\x0b\x32-.tars.secret.v1.CreateSecretRequest.TagsEntryR\x04tags\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"F\n\x14\x43reateSecretResponse\x12.\n\x06secret\x18\x01 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"<\n\x10GetSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\"C\n\x11GetSecretResponse\x12.\n\x06secret\x18\x01 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"\x97\x02\n\x12ListSecretsRequest\x12\x14\n\x05realm\x18\x01 \x01(\tR\x05realm\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32\x1c.tars.secret.v1.SecretStatusR\x06status\x12@\n\x04tags\x18\x03 \x03(\x0b\x32,.tars.secret.v1.ListSecretsRequest.TagsEntryR\x04tags\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"o\n\x13ListSecretsResponse\x12\x30\n\x07secrets\x18\x01 \x03(\x0b\x32\x16.tars.secret.v1.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"?\n\x13\x44\x65leteSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\"0\n\x14\x44\x65leteSecretResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\\\n\x13RotateSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\x12\x1b\n\tnew_value\x18\x03 \x01(\tR\x08newValue\"F\n\x14RotateSecretResponse\x12.\n\x06secret\x18\x01 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"A\n\x15ValidateSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\"D\n\x16ValidateSecretResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x14\n\x05\x65rror\x18\x02 \x01(\tR\x05\x65rror\"Z\n\x15GetSecretValueRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x02 \x01(\tR\x05realm\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\"^\n\x16GetSecretValueResponse\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12.\n\x06secret\x18\x02 \x01(\x0b\x32\x16.tars.secret.v1.SecretR\x06secret\"\xb9\x03\n\x06Secret\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x14\n\x05realm\x18\x04 \x01(\tR\x05realm\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x0bkek_version\x18\x06 \x01(\tR\nkekVersion\x12\x34\n\x06status\x18\x07 \x01(\x0e\x32\x1c.tars.secret.v1.SecretStatusR\x06status\x12\x34\n\x04tags\x18\x08 \x03(\x0b\x32 .tars.secret.v1.Secret.TagsEntryR\x04tags\x12\x39\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x85\x01\n\x0cSecretStatus\x12\x1d\n\x19SECRET_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SECRET_STATUS_ACTIVE\x10\x01\x12\x19\n\x15SECRET_STATUS_REVOKED\x10\x02\x12!\n\x1dSECRET_STATUS_ROTATED_PENDING\x10\x03\x32\xa7\x08\n\rSecretService\x12\x8a\x01\n\x0c\x43reateSecret\x12#.tars.secret.v1.CreateSecretRequest\x1a$.tars.secret.v1.CreateSecretResponse\"/\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/secrets:\x01*\x12\x88\x01\n\tGetSecret\x12 .tars.secret.v1.GetSecretRequest\x1a!.tars.secret.v1.GetSecretResponse\"6\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/secrets/{name}\x12\x87\x01\n\x0bListSecrets\x12\".tars.secret.v1.ListSecretsRequest\x1a#.tars.secret.v1.ListSecretsResponse\"/\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/secrets\x12\x8e\x01\n\x0c\x44\x65leteSecret\x12#.tars.secret.v1.DeleteSecretRequest\x1a$.tars.secret.v1.DeleteSecretResponse\"3\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x14*\x12/v1/secrets/{name}\x12\x98\x01\n\x0cRotateSecret\x12#.tars.secret.v1.RotateSecretRequest\x1a$.tars.secret.v1.RotateSecretResponse\"=\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/secrets/{name}/rotate:\x01*\x12\xa3\x01\n\x0eValidateSecret\x12%.tars.secret.v1.ValidateSecretRequest\x1a&.tars.secret.v1.ValidateSecretResponse\"B\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02 \"\x1b/v1/secrets/{name}/validate:\x01*\x12\xa1\x01\n\x0eGetSecretValue\x12%.tars.secret.v1.GetSecretValueRequest\x1a&.tars.secret.v1.GetSecretValueResponse\"@\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x07Secrets\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/secrets/{name}/value:\x01*B\xb4\x01\n\x12\x63om.tars.secret.v1B\x0bSecretProtoP\x01Z7github.com/tetrateio/fraser/api/tars/secret/v1;secretv1\xa2\x02\x03TSX\xaa\x02\x0eTars.Secret.V1\xca\x02\x0eTars\\Secret\\V1\xe2\x02\x1aTars\\Secret\\V1\\GPBMetadata\xea\x02\x10Tars::Secret::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.secret.v1.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.secret.v1B\013SecretProtoP\001Z7github.com/tetrateio/fraser/api/tars/secret/v1;secretv1\242\002\003TSX\252\002\016Tars.Secret.V1\312\002\016Tars\\Secret\\V1\342\002\032Tars\\Secret\\V1\\GPBMetadata\352\002\020Tars::Secret::V1'
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SECRET_TAGSENTRY']._loaded_options = None
  _globals['_SECRET_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\020\"\013/v1/secrets:\001*'
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\024\022\022/v1/secrets/{name}'
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\r\022\013/v1/secrets'
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\024*\022/v1/secrets/{name}'
  _globals['_SECRETSERVICE'].methods_by_name['RotateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['RotateSecret']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002\036\"\031/v1/secrets/{name}/rotate:\001*'
  _globals['_SECRETSERVICE'].methods_by_name['ValidateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['ValidateSecret']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\007Secrets\202\323\344\223\002 \"\033/v1/secrets/{name}/validate:\001*'
  _globals['_SECRETSERVICE'].methods_by_name['GetSecretValue']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['GetSecretValue']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\007Secrets\202\323\344\223\002\035\"\030/v1/secrets/{name}/value:\001*'
  _globals['_SECRETSTATUS']._serialized_start=2088
  _globals['_SECRETSTATUS']._serialized_end=2221
  _globals['_CREATESECRETREQUEST']._serialized_start=169
  _globals['_CREATESECRETREQUEST']._serialized_end=437
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._serialized_start=382
  _globals['_CREATESECRETREQUEST_TAGSENTRY']._serialized_end=437
  _globals['_CREATESECRETRESPONSE']._serialized_start=439
  _globals['_CREATESECRETRESPONSE']._serialized_end=509
  _globals['_GETSECRETREQUEST']._serialized_start=511
  _globals['_GETSECRETREQUEST']._serialized_end=571
  _globals['_GETSECRETRESPONSE']._serialized_start=573
  _globals['_GETSECRETRESPONSE']._serialized_end=640
  _globals['_LISTSECRETSREQUEST']._serialized_start=643
  _globals['_LISTSECRETSREQUEST']._serialized_end=922
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._serialized_start=382
  _globals['_LISTSECRETSREQUEST_TAGSENTRY']._serialized_end=437
  _globals['_LISTSECRETSRESPONSE']._serialized_start=924
  _globals['_LISTSECRETSRESPONSE']._serialized_end=1035
  _globals['_DELETESECRETREQUEST']._serialized_start=1037
  _globals['_DELETESECRETREQUEST']._serialized_end=1100
  _globals['_DELETESECRETRESPONSE']._serialized_start=1102
  _globals['_DELETESECRETRESPONSE']._serialized_end=1150
  _globals['_ROTATESECRETREQUEST']._serialized_start=1152
  _globals['_ROTATESECRETREQUEST']._serialized_end=1244
  _globals['_ROTATESECRETRESPONSE']._serialized_start=1246
  _globals['_ROTATESECRETRESPONSE']._serialized_end=1316
  _globals['_VALIDATESECRETREQUEST']._serialized_start=1318
  _globals['_VALIDATESECRETREQUEST']._serialized_end=1383
  _globals['_VALIDATESECRETRESPONSE']._serialized_start=1385
  _globals['_VALIDATESECRETRESPONSE']._serialized_end=1453
  _globals['_GETSECRETVALUEREQUEST']._serialized_start=1455
  _globals['_GETSECRETVALUEREQUEST']._serialized_end=1545
  _globals['_GETSECRETVALUERESPONSE']._serialized_start=1547
  _globals['_GETSECRETVALUERESPONSE']._serialized_end=1641
  _globals['_SECRET']._serialized_start=1644
  _globals['_SECRET']._serialized_end=2085
  _globals['_SECRET_TAGSENTRY']._serialized_start=382
  _globals['_SECRET_TAGSENTRY']._serialized_end=437
  _globals['_SECRETSERVICE']._serialized_start=2224
  _globals['_SECRETSERVICE']._serialized_end=3287
# @@protoc_insertion_point(module_scope)
