from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ERROR_REASON_UNSPECIFIED: _ClassVar[ErrorReason]
    ERROR_REASON_INVALID_ARGUMENT: _ClassVar[ErrorReason]
    ERROR_REASON_UNAUTHENTICATED: _ClassVar[ErrorReason]
    ERROR_REASON_PERMISSION_DENIED: _ClassVar[ErrorReason]
    ERROR_REASON_NOT_FOUND: _ClassVar[ErrorReason]
    ERROR_REASON_ALREADY_EXISTS: _ClassVar[ErrorReason]
    ERROR_REASON_FAILED_PRECONDITION: _ClassVar[ErrorReason]
    ERROR_REASON_INTERNAL: _ClassVar[ErrorReason]
    ERROR_REASON_UNAVAILABLE: _ClassVar[ErrorReason]
    ERROR_REASON_MODEL_NOT_FOUND: _ClassVar[ErrorReason]
    ERROR_REASON_MODEL_AMBIGUOUS: _ClassVar[ErrorReason]
    ERROR_REASON_PROVIDER_NOT_FOUND: _ClassVar[ErrorReason]
    ERROR_REASON_CROSS_TENANT_DENIED: _ClassVar[ErrorReason]
    ERROR_REASON_SESSION_DEFAULT_UNRESOLVED: _ClassVar[ErrorReason]
ERROR_REASON_UNSPECIFIED: ErrorReason
ERROR_REASON_INVALID_ARGUMENT: ErrorReason
ERROR_REASON_UNAUTHENTICATED: ErrorReason
ERROR_REASON_PERMISSION_DENIED: ErrorReason
ERROR_REASON_NOT_FOUND: ErrorReason
ERROR_REASON_ALREADY_EXISTS: ErrorReason
ERROR_REASON_FAILED_PRECONDITION: ErrorReason
ERROR_REASON_INTERNAL: ErrorReason
ERROR_REASON_UNAVAILABLE: ErrorReason
ERROR_REASON_MODEL_NOT_FOUND: ErrorReason
ERROR_REASON_MODEL_AMBIGUOUS: ErrorReason
ERROR_REASON_PROVIDER_NOT_FOUND: ErrorReason
ERROR_REASON_CROSS_TENANT_DENIED: ErrorReason
ERROR_REASON_SESSION_DEFAULT_UNRESOLVED: ErrorReason
